// This file was generated by _tools/gen-definitions.go. DO NOT EDIT.

package definition
import "sync"

var github Emojis
var githubOnce sync.Once

func Github(opts ...EmojisOption) Emojis {
	githubOnce.Do(func() {
		github = NewEmojis(
			Emoji{Name: "grinning face", Unicode: []int32{128512}, ShortNames: []string{"grinning"}},
			Emoji{Name: "grinning face with big eyes", Unicode: []int32{128515}, ShortNames: []string{"smiley"}},
			Emoji{Name: "grinning face with smiling eyes", Unicode: []int32{128516}, ShortNames: []string{"smile"}},
			Emoji{Name: "beaming face with smiling eyes", Unicode: []int32{128513}, ShortNames: []string{"grin"}},
			Emoji{Name: "grinning squinting face", Unicode: []int32{128518}, ShortNames: []string{"laughing", "satisfied"}},
			Emoji{Name: "grinning face with sweat", Unicode: []int32{128517}, ShortNames: []string{"sweat_smile"}},
			Emoji{Name: "rolling on the floor laughing", Unicode: []int32{129315}, ShortNames: []string{"rofl"}},
			Emoji{Name: "face with tears of joy", Unicode: []int32{128514}, ShortNames: []string{"joy"}},
			Emoji{Name: "slightly smiling face", Unicode: []int32{128578}, ShortNames: []string{"slightly_smiling_face"}},
			Emoji{Name: "upside-down face", Unicode: []int32{128579}, ShortNames: []string{"upside_down_face"}},
			Emoji{Name: "melting face", Unicode: []int32{129760}, ShortNames: []string{"melting_face"}},
			Emoji{Name: "winking face", Unicode: []int32{128521}, ShortNames: []string{"wink"}},
			Emoji{Name: "smiling face with smiling eyes", Unicode: []int32{128522}, ShortNames: []string{"blush"}},
			Emoji{Name: "smiling face with halo", Unicode: []int32{128519}, ShortNames: []string{"innocent"}},
			Emoji{Name: "smiling face with hearts", Unicode: []int32{129392}, ShortNames: []string{"smiling_face_with_three_hearts"}},
			Emoji{Name: "smiling face with heart-eyes", Unicode: []int32{128525}, ShortNames: []string{"heart_eyes"}},
			Emoji{Name: "star-struck", Unicode: []int32{129321}, ShortNames: []string{"star_struck"}},
			Emoji{Name: "face blowing a kiss", Unicode: []int32{128536}, ShortNames: []string{"kissing_heart"}},
			Emoji{Name: "kissing face", Unicode: []int32{128535}, ShortNames: []string{"kissing"}},
			Emoji{Name: "smiling face", Unicode: []int32{9786, 65039}, ShortNames: []string{"relaxed"}},
			Emoji{Name: "kissing face with closed eyes", Unicode: []int32{128538}, ShortNames: []string{"kissing_closed_eyes"}},
			Emoji{Name: "kissing face with smiling eyes", Unicode: []int32{128537}, ShortNames: []string{"kissing_smiling_eyes"}},
			Emoji{Name: "smiling face with tear", Unicode: []int32{129394}, ShortNames: []string{"smiling_face_with_tear"}},
			Emoji{Name: "face savoring food", Unicode: []int32{128523}, ShortNames: []string{"yum"}},
			Emoji{Name: "face with tongue", Unicode: []int32{128539}, ShortNames: []string{"stuck_out_tongue"}},
			Emoji{Name: "winking face with tongue", Unicode: []int32{128540}, ShortNames: []string{"stuck_out_tongue_winking_eye"}},
			Emoji{Name: "zany face", Unicode: []int32{129322}, ShortNames: []string{"zany_face"}},
			Emoji{Name: "squinting face with tongue", Unicode: []int32{128541}, ShortNames: []string{"stuck_out_tongue_closed_eyes"}},
			Emoji{Name: "money-mouth face", Unicode: []int32{129297}, ShortNames: []string{"money_mouth_face"}},
			Emoji{Name: "smiling face with open hands", Unicode: []int32{129303}, ShortNames: []string{"hugs"}},
			Emoji{Name: "face with hand over mouth", Unicode: []int32{129325}, ShortNames: []string{"hand_over_mouth"}},
			Emoji{Name: "face with open eyes and hand over mouth", Unicode: []int32{129762}, ShortNames: []string{"face_with_open_eyes_and_hand_over_mouth"}},
			Emoji{Name: "face with peeking eye", Unicode: []int32{129763}, ShortNames: []string{"face_with_peeking_eye"}},
			Emoji{Name: "shushing face", Unicode: []int32{129323}, ShortNames: []string{"shushing_face"}},
			Emoji{Name: "thinking face", Unicode: []int32{129300}, ShortNames: []string{"thinking"}},
			Emoji{Name: "saluting face", Unicode: []int32{129761}, ShortNames: []string{"saluting_face"}},
			Emoji{Name: "zipper-mouth face", Unicode: []int32{129296}, ShortNames: []string{"zipper_mouth_face"}},
			Emoji{Name: "face with raised eyebrow", Unicode: []int32{129320}, ShortNames: []string{"raised_eyebrow"}},
			Emoji{Name: "neutral face", Unicode: []int32{128528}, ShortNames: []string{"neutral_face"}},
			Emoji{Name: "expressionless face", Unicode: []int32{128529}, ShortNames: []string{"expressionless"}},
			Emoji{Name: "face without mouth", Unicode: []int32{128566}, ShortNames: []string{"no_mouth"}},
			Emoji{Name: "dotted line face", Unicode: []int32{129765}, ShortNames: []string{"dotted_line_face"}},
			Emoji{Name: "face in clouds", Unicode: []int32{128566, 8205, 127787, 65039}, ShortNames: []string{"face_in_clouds"}},
			Emoji{Name: "smirking face", Unicode: []int32{128527}, ShortNames: []string{"smirk"}},
			Emoji{Name: "unamused face", Unicode: []int32{128530}, ShortNames: []string{"unamused"}},
			Emoji{Name: "face with rolling eyes", Unicode: []int32{128580}, ShortNames: []string{"roll_eyes"}},
			Emoji{Name: "grimacing face", Unicode: []int32{128556}, ShortNames: []string{"grimacing"}},
			Emoji{Name: "face exhaling", Unicode: []int32{128558, 8205, 128168}, ShortNames: []string{"face_exhaling"}},
			Emoji{Name: "lying face", Unicode: []int32{129317}, ShortNames: []string{"lying_face"}},
			Emoji{Name: "shaking face", Unicode: []int32{129768}, ShortNames: []string{"shaking_face"}},
			Emoji{Name: "relieved face", Unicode: []int32{128524}, ShortNames: []string{"relieved"}},
			Emoji{Name: "pensive face", Unicode: []int32{128532}, ShortNames: []string{"pensive"}},
			Emoji{Name: "sleepy face", Unicode: []int32{128554}, ShortNames: []string{"sleepy"}},
			Emoji{Name: "drooling face", Unicode: []int32{129316}, ShortNames: []string{"drooling_face"}},
			Emoji{Name: "sleeping face", Unicode: []int32{128564}, ShortNames: []string{"sleeping"}},
			Emoji{Name: "face with medical mask", Unicode: []int32{128567}, ShortNames: []string{"mask"}},
			Emoji{Name: "face with thermometer", Unicode: []int32{129298}, ShortNames: []string{"face_with_thermometer"}},
			Emoji{Name: "face with head-bandage", Unicode: []int32{129301}, ShortNames: []string{"face_with_head_bandage"}},
			Emoji{Name: "nauseated face", Unicode: []int32{129314}, ShortNames: []string{"nauseated_face"}},
			Emoji{Name: "face vomiting", Unicode: []int32{129326}, ShortNames: []string{"vomiting_face"}},
			Emoji{Name: "sneezing face", Unicode: []int32{129319}, ShortNames: []string{"sneezing_face"}},
			Emoji{Name: "hot face", Unicode: []int32{129397}, ShortNames: []string{"hot_face"}},
			Emoji{Name: "cold face", Unicode: []int32{129398}, ShortNames: []string{"cold_face"}},
			Emoji{Name: "woozy face", Unicode: []int32{129396}, ShortNames: []string{"woozy_face"}},
			Emoji{Name: "face with crossed-out eyes", Unicode: []int32{128565}, ShortNames: []string{"dizzy_face"}},
			Emoji{Name: "face with spiral eyes", Unicode: []int32{128565, 8205, 128171}, ShortNames: []string{"face_with_spiral_eyes"}},
			Emoji{Name: "exploding head", Unicode: []int32{129327}, ShortNames: []string{"exploding_head"}},
			Emoji{Name: "cowboy hat face", Unicode: []int32{129312}, ShortNames: []string{"cowboy_hat_face"}},
			Emoji{Name: "partying face", Unicode: []int32{129395}, ShortNames: []string{"partying_face"}},
			Emoji{Name: "disguised face", Unicode: []int32{129400}, ShortNames: []string{"disguised_face"}},
			Emoji{Name: "smiling face with sunglasses", Unicode: []int32{128526}, ShortNames: []string{"sunglasses"}},
			Emoji{Name: "nerd face", Unicode: []int32{129299}, ShortNames: []string{"nerd_face"}},
			Emoji{Name: "face with monocle", Unicode: []int32{129488}, ShortNames: []string{"monocle_face"}},
			Emoji{Name: "confused face", Unicode: []int32{128533}, ShortNames: []string{"confused"}},
			Emoji{Name: "face with diagonal mouth", Unicode: []int32{129764}, ShortNames: []string{"face_with_diagonal_mouth"}},
			Emoji{Name: "worried face", Unicode: []int32{128543}, ShortNames: []string{"worried"}},
			Emoji{Name: "slightly frowning face", Unicode: []int32{128577}, ShortNames: []string{"slightly_frowning_face"}},
			Emoji{Name: "frowning face", Unicode: []int32{9785, 65039}, ShortNames: []string{"frowning_face"}},
			Emoji{Name: "face with open mouth", Unicode: []int32{128558}, ShortNames: []string{"open_mouth"}},
			Emoji{Name: "hushed face", Unicode: []int32{128559}, ShortNames: []string{"hushed"}},
			Emoji{Name: "astonished face", Unicode: []int32{128562}, ShortNames: []string{"astonished"}},
			Emoji{Name: "flushed face", Unicode: []int32{128563}, ShortNames: []string{"flushed"}},
			Emoji{Name: "pleading face", Unicode: []int32{129402}, ShortNames: []string{"pleading_face"}},
			Emoji{Name: "face holding back tears", Unicode: []int32{129401}, ShortNames: []string{"face_holding_back_tears"}},
			Emoji{Name: "frowning face with open mouth", Unicode: []int32{128550}, ShortNames: []string{"frowning"}},
			Emoji{Name: "anguished face", Unicode: []int32{128551}, ShortNames: []string{"anguished"}},
			Emoji{Name: "fearful face", Unicode: []int32{128552}, ShortNames: []string{"fearful"}},
			Emoji{Name: "anxious face with sweat", Unicode: []int32{128560}, ShortNames: []string{"cold_sweat"}},
			Emoji{Name: "sad but relieved face", Unicode: []int32{128549}, ShortNames: []string{"disappointed_relieved"}},
			Emoji{Name: "crying face", Unicode: []int32{128546}, ShortNames: []string{"cry"}},
			Emoji{Name: "loudly crying face", Unicode: []int32{128557}, ShortNames: []string{"sob"}},
			Emoji{Name: "face screaming in fear", Unicode: []int32{128561}, ShortNames: []string{"scream"}},
			Emoji{Name: "confounded face", Unicode: []int32{128534}, ShortNames: []string{"confounded"}},
			Emoji{Name: "persevering face", Unicode: []int32{128547}, ShortNames: []string{"persevere"}},
			Emoji{Name: "disappointed face", Unicode: []int32{128542}, ShortNames: []string{"disappointed"}},
			Emoji{Name: "downcast face with sweat", Unicode: []int32{128531}, ShortNames: []string{"sweat"}},
			Emoji{Name: "weary face", Unicode: []int32{128553}, ShortNames: []string{"weary"}},
			Emoji{Name: "tired face", Unicode: []int32{128555}, ShortNames: []string{"tired_face"}},
			Emoji{Name: "yawning face", Unicode: []int32{129393}, ShortNames: []string{"yawning_face"}},
			Emoji{Name: "face with steam from nose", Unicode: []int32{128548}, ShortNames: []string{"triumph"}},
			Emoji{Name: "enraged face", Unicode: []int32{128545}, ShortNames: []string{"rage", "pout"}},
			Emoji{Name: "angry face", Unicode: []int32{128544}, ShortNames: []string{"angry"}},
			Emoji{Name: "face with symbols on mouth", Unicode: []int32{129324}, ShortNames: []string{"cursing_face"}},
			Emoji{Name: "smiling face with horns", Unicode: []int32{128520}, ShortNames: []string{"smiling_imp"}},
			Emoji{Name: "angry face with horns", Unicode: []int32{128127}, ShortNames: []string{"imp"}},
			Emoji{Name: "skull", Unicode: []int32{128128}, ShortNames: []string{"skull"}},
			Emoji{Name: "skull and crossbones", Unicode: []int32{9760, 65039}, ShortNames: []string{"skull_and_crossbones"}},
			Emoji{Name: "pile of poo", Unicode: []int32{128169}, ShortNames: []string{"hankey", "poop", "shit"}},
			Emoji{Name: "clown face", Unicode: []int32{129313}, ShortNames: []string{"clown_face"}},
			Emoji{Name: "ogre", Unicode: []int32{128121}, ShortNames: []string{"japanese_ogre"}},
			Emoji{Name: "goblin", Unicode: []int32{128122}, ShortNames: []string{"japanese_goblin"}},
			Emoji{Name: "ghost", Unicode: []int32{128123}, ShortNames: []string{"ghost"}},
			Emoji{Name: "alien", Unicode: []int32{128125}, ShortNames: []string{"alien"}},
			Emoji{Name: "alien monster", Unicode: []int32{128126}, ShortNames: []string{"space_invader"}},
			Emoji{Name: "robot", Unicode: []int32{129302}, ShortNames: []string{"robot"}},
			Emoji{Name: "grinning cat", Unicode: []int32{128570}, ShortNames: []string{"smiley_cat"}},
			Emoji{Name: "grinning cat with smiling eyes", Unicode: []int32{128568}, ShortNames: []string{"smile_cat"}},
			Emoji{Name: "cat with tears of joy", Unicode: []int32{128569}, ShortNames: []string{"joy_cat"}},
			Emoji{Name: "smiling cat with heart-eyes", Unicode: []int32{128571}, ShortNames: []string{"heart_eyes_cat"}},
			Emoji{Name: "cat with wry smile", Unicode: []int32{128572}, ShortNames: []string{"smirk_cat"}},
			Emoji{Name: "kissing cat", Unicode: []int32{128573}, ShortNames: []string{"kissing_cat"}},
			Emoji{Name: "weary cat", Unicode: []int32{128576}, ShortNames: []string{"scream_cat"}},
			Emoji{Name: "crying cat", Unicode: []int32{128575}, ShortNames: []string{"crying_cat_face"}},
			Emoji{Name: "pouting cat", Unicode: []int32{128574}, ShortNames: []string{"pouting_cat"}},
			Emoji{Name: "see-no-evil monkey", Unicode: []int32{128584}, ShortNames: []string{"see_no_evil"}},
			Emoji{Name: "hear-no-evil monkey", Unicode: []int32{128585}, ShortNames: []string{"hear_no_evil"}},
			Emoji{Name: "speak-no-evil monkey", Unicode: []int32{128586}, ShortNames: []string{"speak_no_evil"}},
			Emoji{Name: "love letter", Unicode: []int32{128140}, ShortNames: []string{"love_letter"}},
			Emoji{Name: "heart with arrow", Unicode: []int32{128152}, ShortNames: []string{"cupid"}},
			Emoji{Name: "heart with ribbon", Unicode: []int32{128157}, ShortNames: []string{"gift_heart"}},
			Emoji{Name: "sparkling heart", Unicode: []int32{128150}, ShortNames: []string{"sparkling_heart"}},
			Emoji{Name: "growing heart", Unicode: []int32{128151}, ShortNames: []string{"heartpulse"}},
			Emoji{Name: "beating heart", Unicode: []int32{128147}, ShortNames: []string{"heartbeat"}},
			Emoji{Name: "revolving hearts", Unicode: []int32{128158}, ShortNames: []string{"revolving_hearts"}},
			Emoji{Name: "two hearts", Unicode: []int32{128149}, ShortNames: []string{"two_hearts"}},
			Emoji{Name: "heart decoration", Unicode: []int32{128159}, ShortNames: []string{"heart_decoration"}},
			Emoji{Name: "heart exclamation", Unicode: []int32{10083, 65039}, ShortNames: []string{"heavy_heart_exclamation"}},
			Emoji{Name: "broken heart", Unicode: []int32{128148}, ShortNames: []string{"broken_heart"}},
			Emoji{Name: "heart on fire", Unicode: []int32{10084, 65039, 8205, 128293}, ShortNames: []string{"heart_on_fire"}},
			Emoji{Name: "mending heart", Unicode: []int32{10084, 65039, 8205, 129657}, ShortNames: []string{"mending_heart"}},
			Emoji{Name: "red heart", Unicode: []int32{10084, 65039}, ShortNames: []string{"heart"}},
			Emoji{Name: "pink heart", Unicode: []int32{129655}, ShortNames: []string{"pink_heart"}},
			Emoji{Name: "orange heart", Unicode: []int32{129505}, ShortNames: []string{"orange_heart"}},
			Emoji{Name: "yellow heart", Unicode: []int32{128155}, ShortNames: []string{"yellow_heart"}},
			Emoji{Name: "green heart", Unicode: []int32{128154}, ShortNames: []string{"green_heart"}},
			Emoji{Name: "blue heart", Unicode: []int32{128153}, ShortNames: []string{"blue_heart"}},
			Emoji{Name: "light blue heart", Unicode: []int32{129653}, ShortNames: []string{"light_blue_heart"}},
			Emoji{Name: "purple heart", Unicode: []int32{128156}, ShortNames: []string{"purple_heart"}},
			Emoji{Name: "brown heart", Unicode: []int32{129294}, ShortNames: []string{"brown_heart"}},
			Emoji{Name: "black heart", Unicode: []int32{128420}, ShortNames: []string{"black_heart"}},
			Emoji{Name: "grey heart", Unicode: []int32{129654}, ShortNames: []string{"grey_heart"}},
			Emoji{Name: "white heart", Unicode: []int32{129293}, ShortNames: []string{"white_heart"}},
			Emoji{Name: "kiss mark", Unicode: []int32{128139}, ShortNames: []string{"kiss"}},
			Emoji{Name: "hundred points", Unicode: []int32{128175}, ShortNames: []string{"100"}},
			Emoji{Name: "anger symbol", Unicode: []int32{128162}, ShortNames: []string{"anger"}},
			Emoji{Name: "collision", Unicode: []int32{128165}, ShortNames: []string{"boom", "collision"}},
			Emoji{Name: "dizzy", Unicode: []int32{128171}, ShortNames: []string{"dizzy"}},
			Emoji{Name: "sweat droplets", Unicode: []int32{128166}, ShortNames: []string{"sweat_drops"}},
			Emoji{Name: "dashing away", Unicode: []int32{128168}, ShortNames: []string{"dash"}},
			Emoji{Name: "hole", Unicode: []int32{128371, 65039}, ShortNames: []string{"hole"}},
			Emoji{Name: "speech balloon", Unicode: []int32{128172}, ShortNames: []string{"speech_balloon"}},
			Emoji{Name: "eye in speech bubble", Unicode: []int32{128065, 65039, 8205, 128488, 65039}, ShortNames: []string{"eye_speech_bubble"}},
			Emoji{Name: "left speech bubble", Unicode: []int32{128488, 65039}, ShortNames: []string{"left_speech_bubble"}},
			Emoji{Name: "right anger bubble", Unicode: []int32{128495, 65039}, ShortNames: []string{"right_anger_bubble"}},
			Emoji{Name: "thought balloon", Unicode: []int32{128173}, ShortNames: []string{"thought_balloon"}},
			Emoji{Name: "ZZZ", Unicode: []int32{128164}, ShortNames: []string{"zzz"}},
			Emoji{Name: "waving hand", Unicode: []int32{128075}, ShortNames: []string{"wave"}},
			Emoji{Name: "raised back of hand", Unicode: []int32{129306}, ShortNames: []string{"raised_back_of_hand"}},
			Emoji{Name: "hand with fingers splayed", Unicode: []int32{128400, 65039}, ShortNames: []string{"raised_hand_with_fingers_splayed"}},
			Emoji{Name: "raised hand", Unicode: []int32{9995}, ShortNames: []string{"hand", "raised_hand"}},
			Emoji{Name: "vulcan salute", Unicode: []int32{128406}, ShortNames: []string{"vulcan_salute"}},
			Emoji{Name: "rightwards hand", Unicode: []int32{129777}, ShortNames: []string{"rightwards_hand"}},
			Emoji{Name: "leftwards hand", Unicode: []int32{129778}, ShortNames: []string{"leftwards_hand"}},
			Emoji{Name: "palm down hand", Unicode: []int32{129779}, ShortNames: []string{"palm_down_hand"}},
			Emoji{Name: "palm up hand", Unicode: []int32{129780}, ShortNames: []string{"palm_up_hand"}},
			Emoji{Name: "leftwards pushing hand", Unicode: []int32{129783}, ShortNames: []string{"leftwards_pushing_hand"}},
			Emoji{Name: "rightwards pushing hand", Unicode: []int32{129784}, ShortNames: []string{"rightwards_pushing_hand"}},
			Emoji{Name: "OK hand", Unicode: []int32{128076}, ShortNames: []string{"ok_hand"}},
			Emoji{Name: "pinched fingers", Unicode: []int32{129292}, ShortNames: []string{"pinched_fingers"}},
			Emoji{Name: "pinching hand", Unicode: []int32{129295}, ShortNames: []string{"pinching_hand"}},
			Emoji{Name: "victory hand", Unicode: []int32{9996, 65039}, ShortNames: []string{"v"}},
			Emoji{Name: "crossed fingers", Unicode: []int32{129310}, ShortNames: []string{"crossed_fingers"}},
			Emoji{Name: "hand with index finger and thumb crossed", Unicode: []int32{129776}, ShortNames: []string{"hand_with_index_finger_and_thumb_crossed"}},
			Emoji{Name: "love-you gesture", Unicode: []int32{129311}, ShortNames: []string{"love_you_gesture"}},
			Emoji{Name: "sign of the horns", Unicode: []int32{129304}, ShortNames: []string{"metal"}},
			Emoji{Name: "call me hand", Unicode: []int32{129305}, ShortNames: []string{"call_me_hand"}},
			Emoji{Name: "backhand index pointing left", Unicode: []int32{128072}, ShortNames: []string{"point_left"}},
			Emoji{Name: "backhand index pointing right", Unicode: []int32{128073}, ShortNames: []string{"point_right"}},
			Emoji{Name: "backhand index pointing up", Unicode: []int32{128070}, ShortNames: []string{"point_up_2"}},
			Emoji{Name: "middle finger", Unicode: []int32{128405}, ShortNames: []string{"middle_finger", "fu"}},
			Emoji{Name: "backhand index pointing down", Unicode: []int32{128071}, ShortNames: []string{"point_down"}},
			Emoji{Name: "index pointing up", Unicode: []int32{9757, 65039}, ShortNames: []string{"point_up"}},
			Emoji{Name: "index pointing at the viewer", Unicode: []int32{129781}, ShortNames: []string{"index_pointing_at_the_viewer"}},
			Emoji{Name: "thumbs up", Unicode: []int32{128077}, ShortNames: []string{"+1", "thumbsup"}},
			Emoji{Name: "thumbs down", Unicode: []int32{128078}, ShortNames: []string{"-1", "thumbsdown"}},
			Emoji{Name: "raised fist", Unicode: []int32{9994}, ShortNames: []string{"fist_raised", "fist"}},
			Emoji{Name: "oncoming fist", Unicode: []int32{128074}, ShortNames: []string{"fist_oncoming", "facepunch", "punch"}},
			Emoji{Name: "left-facing fist", Unicode: []int32{129307}, ShortNames: []string{"fist_left"}},
			Emoji{Name: "right-facing fist", Unicode: []int32{129308}, ShortNames: []string{"fist_right"}},
			Emoji{Name: "clapping hands", Unicode: []int32{128079}, ShortNames: []string{"clap"}},
			Emoji{Name: "raising hands", Unicode: []int32{128588}, ShortNames: []string{"raised_hands"}},
			Emoji{Name: "heart hands", Unicode: []int32{129782}, ShortNames: []string{"heart_hands"}},
			Emoji{Name: "open hands", Unicode: []int32{128080}, ShortNames: []string{"open_hands"}},
			Emoji{Name: "palms up together", Unicode: []int32{129330}, ShortNames: []string{"palms_up_together"}},
			Emoji{Name: "handshake", Unicode: []int32{129309}, ShortNames: []string{"handshake"}},
			Emoji{Name: "folded hands", Unicode: []int32{128591}, ShortNames: []string{"pray"}},
			Emoji{Name: "writing hand", Unicode: []int32{9997, 65039}, ShortNames: []string{"writing_hand"}},
			Emoji{Name: "nail polish", Unicode: []int32{128133}, ShortNames: []string{"nail_care"}},
			Emoji{Name: "selfie", Unicode: []int32{129331}, ShortNames: []string{"selfie"}},
			Emoji{Name: "flexed biceps", Unicode: []int32{128170}, ShortNames: []string{"muscle"}},
			Emoji{Name: "mechanical arm", Unicode: []int32{129470}, ShortNames: []string{"mechanical_arm"}},
			Emoji{Name: "mechanical leg", Unicode: []int32{129471}, ShortNames: []string{"mechanical_leg"}},
			Emoji{Name: "leg", Unicode: []int32{129461}, ShortNames: []string{"leg"}},
			Emoji{Name: "foot", Unicode: []int32{129462}, ShortNames: []string{"foot"}},
			Emoji{Name: "ear", Unicode: []int32{128066}, ShortNames: []string{"ear"}},
			Emoji{Name: "ear with hearing aid", Unicode: []int32{129467}, ShortNames: []string{"ear_with_hearing_aid"}},
			Emoji{Name: "nose", Unicode: []int32{128067}, ShortNames: []string{"nose"}},
			Emoji{Name: "brain", Unicode: []int32{129504}, ShortNames: []string{"brain"}},
			Emoji{Name: "anatomical heart", Unicode: []int32{129728}, ShortNames: []string{"anatomical_heart"}},
			Emoji{Name: "lungs", Unicode: []int32{129729}, ShortNames: []string{"lungs"}},
			Emoji{Name: "tooth", Unicode: []int32{129463}, ShortNames: []string{"tooth"}},
			Emoji{Name: "bone", Unicode: []int32{129460}, ShortNames: []string{"bone"}},
			Emoji{Name: "eyes", Unicode: []int32{128064}, ShortNames: []string{"eyes"}},
			Emoji{Name: "eye", Unicode: []int32{128065, 65039}, ShortNames: []string{"eye"}},
			Emoji{Name: "tongue", Unicode: []int32{128069}, ShortNames: []string{"tongue"}},
			Emoji{Name: "mouth", Unicode: []int32{128068}, ShortNames: []string{"lips"}},
			Emoji{Name: "biting lip", Unicode: []int32{129766}, ShortNames: []string{"biting_lip"}},
			Emoji{Name: "baby", Unicode: []int32{128118}, ShortNames: []string{"baby"}},
			Emoji{Name: "child", Unicode: []int32{129490}, ShortNames: []string{"child"}},
			Emoji{Name: "boy", Unicode: []int32{128102}, ShortNames: []string{"boy"}},
			Emoji{Name: "girl", Unicode: []int32{128103}, ShortNames: []string{"girl"}},
			Emoji{Name: "person", Unicode: []int32{129489}, ShortNames: []string{"adult"}},
			Emoji{Name: "person: blond hair", Unicode: []int32{128113}, ShortNames: []string{"blond_haired_person"}},
			Emoji{Name: "man", Unicode: []int32{128104}, ShortNames: []string{"man"}},
			Emoji{Name: "person: beard", Unicode: []int32{129492}, ShortNames: []string{"bearded_person"}},
			Emoji{Name: "man: beard", Unicode: []int32{129492, 8205, 9794, 65039}, ShortNames: []string{"man_beard"}},
			Emoji{Name: "woman: beard", Unicode: []int32{129492, 8205, 9792, 65039}, ShortNames: []string{"woman_beard"}},
			Emoji{Name: "man: red hair", Unicode: []int32{128104, 8205, 129456}, ShortNames: []string{"red_haired_man"}},
			Emoji{Name: "man: curly hair", Unicode: []int32{128104, 8205, 129457}, ShortNames: []string{"curly_haired_man"}},
			Emoji{Name: "man: white hair", Unicode: []int32{128104, 8205, 129459}, ShortNames: []string{"white_haired_man"}},
			Emoji{Name: "man: bald", Unicode: []int32{128104, 8205, 129458}, ShortNames: []string{"bald_man"}},
			Emoji{Name: "woman", Unicode: []int32{128105}, ShortNames: []string{"woman"}},
			Emoji{Name: "woman: red hair", Unicode: []int32{128105, 8205, 129456}, ShortNames: []string{"red_haired_woman"}},
			Emoji{Name: "person: red hair", Unicode: []int32{129489, 8205, 129456}, ShortNames: []string{"person_red_hair"}},
			Emoji{Name: "woman: curly hair", Unicode: []int32{128105, 8205, 129457}, ShortNames: []string{"curly_haired_woman"}},
			Emoji{Name: "person: curly hair", Unicode: []int32{129489, 8205, 129457}, ShortNames: []string{"person_curly_hair"}},
			Emoji{Name: "woman: white hair", Unicode: []int32{128105, 8205, 129459}, ShortNames: []string{"white_haired_woman"}},
			Emoji{Name: "person: white hair", Unicode: []int32{129489, 8205, 129459}, ShortNames: []string{"person_white_hair"}},
			Emoji{Name: "woman: bald", Unicode: []int32{128105, 8205, 129458}, ShortNames: []string{"bald_woman"}},
			Emoji{Name: "person: bald", Unicode: []int32{129489, 8205, 129458}, ShortNames: []string{"person_bald"}},
			Emoji{Name: "woman: blond hair", Unicode: []int32{128113, 8205, 9792, 65039}, ShortNames: []string{"blond_haired_woman", "blonde_woman"}},
			Emoji{Name: "man: blond hair", Unicode: []int32{128113, 8205, 9794, 65039}, ShortNames: []string{"blond_haired_man"}},
			Emoji{Name: "older person", Unicode: []int32{129491}, ShortNames: []string{"older_adult"}},
			Emoji{Name: "old man", Unicode: []int32{128116}, ShortNames: []string{"older_man"}},
			Emoji{Name: "old woman", Unicode: []int32{128117}, ShortNames: []string{"older_woman"}},
			Emoji{Name: "person frowning", Unicode: []int32{128589}, ShortNames: []string{"frowning_person"}},
			Emoji{Name: "man frowning", Unicode: []int32{128589, 8205, 9794, 65039}, ShortNames: []string{"frowning_man"}},
			Emoji{Name: "woman frowning", Unicode: []int32{128589, 8205, 9792, 65039}, ShortNames: []string{"frowning_woman"}},
			Emoji{Name: "person pouting", Unicode: []int32{128590}, ShortNames: []string{"pouting_face"}},
			Emoji{Name: "man pouting", Unicode: []int32{128590, 8205, 9794, 65039}, ShortNames: []string{"pouting_man"}},
			Emoji{Name: "woman pouting", Unicode: []int32{128590, 8205, 9792, 65039}, ShortNames: []string{"pouting_woman"}},
			Emoji{Name: "person gesturing NO", Unicode: []int32{128581}, ShortNames: []string{"no_good"}},
			Emoji{Name: "man gesturing NO", Unicode: []int32{128581, 8205, 9794, 65039}, ShortNames: []string{"no_good_man", "ng_man"}},
			Emoji{Name: "woman gesturing NO", Unicode: []int32{128581, 8205, 9792, 65039}, ShortNames: []string{"no_good_woman", "ng_woman"}},
			Emoji{Name: "person gesturing OK", Unicode: []int32{128582}, ShortNames: []string{"ok_person"}},
			Emoji{Name: "man gesturing OK", Unicode: []int32{128582, 8205, 9794, 65039}, ShortNames: []string{"ok_man"}},
			Emoji{Name: "woman gesturing OK", Unicode: []int32{128582, 8205, 9792, 65039}, ShortNames: []string{"ok_woman"}},
			Emoji{Name: "person tipping hand", Unicode: []int32{128129}, ShortNames: []string{"tipping_hand_person", "information_desk_person"}},
			Emoji{Name: "man tipping hand", Unicode: []int32{128129, 8205, 9794, 65039}, ShortNames: []string{"tipping_hand_man", "sassy_man"}},
			Emoji{Name: "woman tipping hand", Unicode: []int32{128129, 8205, 9792, 65039}, ShortNames: []string{"tipping_hand_woman", "sassy_woman"}},
			Emoji{Name: "person raising hand", Unicode: []int32{128587}, ShortNames: []string{"raising_hand"}},
			Emoji{Name: "man raising hand", Unicode: []int32{128587, 8205, 9794, 65039}, ShortNames: []string{"raising_hand_man"}},
			Emoji{Name: "woman raising hand", Unicode: []int32{128587, 8205, 9792, 65039}, ShortNames: []string{"raising_hand_woman"}},
			Emoji{Name: "deaf person", Unicode: []int32{129487}, ShortNames: []string{"deaf_person"}},
			Emoji{Name: "deaf man", Unicode: []int32{129487, 8205, 9794, 65039}, ShortNames: []string{"deaf_man"}},
			Emoji{Name: "deaf woman", Unicode: []int32{129487, 8205, 9792, 65039}, ShortNames: []string{"deaf_woman"}},
			Emoji{Name: "person bowing", Unicode: []int32{128583}, ShortNames: []string{"bow"}},
			Emoji{Name: "man bowing", Unicode: []int32{128583, 8205, 9794, 65039}, ShortNames: []string{"bowing_man"}},
			Emoji{Name: "woman bowing", Unicode: []int32{128583, 8205, 9792, 65039}, ShortNames: []string{"bowing_woman"}},
			Emoji{Name: "person facepalming", Unicode: []int32{129318}, ShortNames: []string{"facepalm"}},
			Emoji{Name: "man facepalming", Unicode: []int32{129318, 8205, 9794, 65039}, ShortNames: []string{"man_facepalming"}},
			Emoji{Name: "woman facepalming", Unicode: []int32{129318, 8205, 9792, 65039}, ShortNames: []string{"woman_facepalming"}},
			Emoji{Name: "person shrugging", Unicode: []int32{129335}, ShortNames: []string{"shrug"}},
			Emoji{Name: "man shrugging", Unicode: []int32{129335, 8205, 9794, 65039}, ShortNames: []string{"man_shrugging"}},
			Emoji{Name: "woman shrugging", Unicode: []int32{129335, 8205, 9792, 65039}, ShortNames: []string{"woman_shrugging"}},
			Emoji{Name: "health worker", Unicode: []int32{129489, 8205, 9877, 65039}, ShortNames: []string{"health_worker"}},
			Emoji{Name: "man health worker", Unicode: []int32{128104, 8205, 9877, 65039}, ShortNames: []string{"man_health_worker"}},
			Emoji{Name: "woman health worker", Unicode: []int32{128105, 8205, 9877, 65039}, ShortNames: []string{"woman_health_worker"}},
			Emoji{Name: "student", Unicode: []int32{129489, 8205, 127891}, ShortNames: []string{"student"}},
			Emoji{Name: "man student", Unicode: []int32{128104, 8205, 127891}, ShortNames: []string{"man_student"}},
			Emoji{Name: "woman student", Unicode: []int32{128105, 8205, 127891}, ShortNames: []string{"woman_student"}},
			Emoji{Name: "teacher", Unicode: []int32{129489, 8205, 127979}, ShortNames: []string{"teacher"}},
			Emoji{Name: "man teacher", Unicode: []int32{128104, 8205, 127979}, ShortNames: []string{"man_teacher"}},
			Emoji{Name: "woman teacher", Unicode: []int32{128105, 8205, 127979}, ShortNames: []string{"woman_teacher"}},
			Emoji{Name: "judge", Unicode: []int32{129489, 8205, 9878, 65039}, ShortNames: []string{"judge"}},
			Emoji{Name: "man judge", Unicode: []int32{128104, 8205, 9878, 65039}, ShortNames: []string{"man_judge"}},
			Emoji{Name: "woman judge", Unicode: []int32{128105, 8205, 9878, 65039}, ShortNames: []string{"woman_judge"}},
			Emoji{Name: "farmer", Unicode: []int32{129489, 8205, 127806}, ShortNames: []string{"farmer"}},
			Emoji{Name: "man farmer", Unicode: []int32{128104, 8205, 127806}, ShortNames: []string{"man_farmer"}},
			Emoji{Name: "woman farmer", Unicode: []int32{128105, 8205, 127806}, ShortNames: []string{"woman_farmer"}},
			Emoji{Name: "cook", Unicode: []int32{129489, 8205, 127859}, ShortNames: []string{"cook"}},
			Emoji{Name: "man cook", Unicode: []int32{128104, 8205, 127859}, ShortNames: []string{"man_cook"}},
			Emoji{Name: "woman cook", Unicode: []int32{128105, 8205, 127859}, ShortNames: []string{"woman_cook"}},
			Emoji{Name: "mechanic", Unicode: []int32{129489, 8205, 128295}, ShortNames: []string{"mechanic"}},
			Emoji{Name: "man mechanic", Unicode: []int32{128104, 8205, 128295}, ShortNames: []string{"man_mechanic"}},
			Emoji{Name: "woman mechanic", Unicode: []int32{128105, 8205, 128295}, ShortNames: []string{"woman_mechanic"}},
			Emoji{Name: "factory worker", Unicode: []int32{129489, 8205, 127981}, ShortNames: []string{"factory_worker"}},
			Emoji{Name: "man factory worker", Unicode: []int32{128104, 8205, 127981}, ShortNames: []string{"man_factory_worker"}},
			Emoji{Name: "woman factory worker", Unicode: []int32{128105, 8205, 127981}, ShortNames: []string{"woman_factory_worker"}},
			Emoji{Name: "office worker", Unicode: []int32{129489, 8205, 128188}, ShortNames: []string{"office_worker"}},
			Emoji{Name: "man office worker", Unicode: []int32{128104, 8205, 128188}, ShortNames: []string{"man_office_worker"}},
			Emoji{Name: "woman office worker", Unicode: []int32{128105, 8205, 128188}, ShortNames: []string{"woman_office_worker"}},
			Emoji{Name: "scientist", Unicode: []int32{129489, 8205, 128300}, ShortNames: []string{"scientist"}},
			Emoji{Name: "man scientist", Unicode: []int32{128104, 8205, 128300}, ShortNames: []string{"man_scientist"}},
			Emoji{Name: "woman scientist", Unicode: []int32{128105, 8205, 128300}, ShortNames: []string{"woman_scientist"}},
			Emoji{Name: "technologist", Unicode: []int32{129489, 8205, 128187}, ShortNames: []string{"technologist"}},
			Emoji{Name: "man technologist", Unicode: []int32{128104, 8205, 128187}, ShortNames: []string{"man_technologist"}},
			Emoji{Name: "woman technologist", Unicode: []int32{128105, 8205, 128187}, ShortNames: []string{"woman_technologist"}},
			Emoji{Name: "singer", Unicode: []int32{129489, 8205, 127908}, ShortNames: []string{"singer"}},
			Emoji{Name: "man singer", Unicode: []int32{128104, 8205, 127908}, ShortNames: []string{"man_singer"}},
			Emoji{Name: "woman singer", Unicode: []int32{128105, 8205, 127908}, ShortNames: []string{"woman_singer"}},
			Emoji{Name: "artist", Unicode: []int32{129489, 8205, 127912}, ShortNames: []string{"artist"}},
			Emoji{Name: "man artist", Unicode: []int32{128104, 8205, 127912}, ShortNames: []string{"man_artist"}},
			Emoji{Name: "woman artist", Unicode: []int32{128105, 8205, 127912}, ShortNames: []string{"woman_artist"}},
			Emoji{Name: "pilot", Unicode: []int32{129489, 8205, 9992, 65039}, ShortNames: []string{"pilot"}},
			Emoji{Name: "man pilot", Unicode: []int32{128104, 8205, 9992, 65039}, ShortNames: []string{"man_pilot"}},
			Emoji{Name: "woman pilot", Unicode: []int32{128105, 8205, 9992, 65039}, ShortNames: []string{"woman_pilot"}},
			Emoji{Name: "astronaut", Unicode: []int32{129489, 8205, 128640}, ShortNames: []string{"astronaut"}},
			Emoji{Name: "man astronaut", Unicode: []int32{128104, 8205, 128640}, ShortNames: []string{"man_astronaut"}},
			Emoji{Name: "woman astronaut", Unicode: []int32{128105, 8205, 128640}, ShortNames: []string{"woman_astronaut"}},
			Emoji{Name: "firefighter", Unicode: []int32{129489, 8205, 128658}, ShortNames: []string{"firefighter"}},
			Emoji{Name: "man firefighter", Unicode: []int32{128104, 8205, 128658}, ShortNames: []string{"man_firefighter"}},
			Emoji{Name: "woman firefighter", Unicode: []int32{128105, 8205, 128658}, ShortNames: []string{"woman_firefighter"}},
			Emoji{Name: "police officer", Unicode: []int32{128110}, ShortNames: []string{"police_officer", "cop"}},
			Emoji{Name: "man police officer", Unicode: []int32{128110, 8205, 9794, 65039}, ShortNames: []string{"policeman"}},
			Emoji{Name: "woman police officer", Unicode: []int32{128110, 8205, 9792, 65039}, ShortNames: []string{"policewoman"}},
			Emoji{Name: "detective", Unicode: []int32{128373, 65039}, ShortNames: []string{"detective"}},
			Emoji{Name: "man detective", Unicode: []int32{128373, 65039, 8205, 9794, 65039}, ShortNames: []string{"male_detective"}},
			Emoji{Name: "woman detective", Unicode: []int32{128373, 65039, 8205, 9792, 65039}, ShortNames: []string{"female_detective"}},
			Emoji{Name: "guard", Unicode: []int32{128130}, ShortNames: []string{"guard"}},
			Emoji{Name: "man guard", Unicode: []int32{128130, 8205, 9794, 65039}, ShortNames: []string{"guardsman"}},
			Emoji{Name: "woman guard", Unicode: []int32{128130, 8205, 9792, 65039}, ShortNames: []string{"guardswoman"}},
			Emoji{Name: "ninja", Unicode: []int32{129399}, ShortNames: []string{"ninja"}},
			Emoji{Name: "construction worker", Unicode: []int32{128119}, ShortNames: []string{"construction_worker"}},
			Emoji{Name: "man construction worker", Unicode: []int32{128119, 8205, 9794, 65039}, ShortNames: []string{"construction_worker_man"}},
			Emoji{Name: "woman construction worker", Unicode: []int32{128119, 8205, 9792, 65039}, ShortNames: []string{"construction_worker_woman"}},
			Emoji{Name: "person with crown", Unicode: []int32{129733}, ShortNames: []string{"person_with_crown"}},
			Emoji{Name: "prince", Unicode: []int32{129332}, ShortNames: []string{"prince"}},
			Emoji{Name: "princess", Unicode: []int32{128120}, ShortNames: []string{"princess"}},
			Emoji{Name: "person wearing turban", Unicode: []int32{128115}, ShortNames: []string{"person_with_turban"}},
			Emoji{Name: "man wearing turban", Unicode: []int32{128115, 8205, 9794, 65039}, ShortNames: []string{"man_with_turban"}},
			Emoji{Name: "woman wearing turban", Unicode: []int32{128115, 8205, 9792, 65039}, ShortNames: []string{"woman_with_turban"}},
			Emoji{Name: "person with skullcap", Unicode: []int32{128114}, ShortNames: []string{"man_with_gua_pi_mao"}},
			Emoji{Name: "woman with headscarf", Unicode: []int32{129493}, ShortNames: []string{"woman_with_headscarf"}},
			Emoji{Name: "person in tuxedo", Unicode: []int32{129333}, ShortNames: []string{"person_in_tuxedo"}},
			Emoji{Name: "man in tuxedo", Unicode: []int32{129333, 8205, 9794, 65039}, ShortNames: []string{"man_in_tuxedo"}},
			Emoji{Name: "woman in tuxedo", Unicode: []int32{129333, 8205, 9792, 65039}, ShortNames: []string{"woman_in_tuxedo"}},
			Emoji{Name: "person with veil", Unicode: []int32{128112}, ShortNames: []string{"person_with_veil"}},
			Emoji{Name: "man with veil", Unicode: []int32{128112, 8205, 9794, 65039}, ShortNames: []string{"man_with_veil"}},
			Emoji{Name: "woman with veil", Unicode: []int32{128112, 8205, 9792, 65039}, ShortNames: []string{"woman_with_veil", "bride_with_veil"}},
			Emoji{Name: "pregnant woman", Unicode: []int32{129328}, ShortNames: []string{"pregnant_woman"}},
			Emoji{Name: "pregnant man", Unicode: []int32{129731}, ShortNames: []string{"pregnant_man"}},
			Emoji{Name: "pregnant person", Unicode: []int32{129732}, ShortNames: []string{"pregnant_person"}},
			Emoji{Name: "breast-feeding", Unicode: []int32{129329}, ShortNames: []string{"breast_feeding"}},
			Emoji{Name: "woman feeding baby", Unicode: []int32{128105, 8205, 127868}, ShortNames: []string{"woman_feeding_baby"}},
			Emoji{Name: "man feeding baby", Unicode: []int32{128104, 8205, 127868}, ShortNames: []string{"man_feeding_baby"}},
			Emoji{Name: "person feeding baby", Unicode: []int32{129489, 8205, 127868}, ShortNames: []string{"person_feeding_baby"}},
			Emoji{Name: "baby angel", Unicode: []int32{128124}, ShortNames: []string{"angel"}},
			Emoji{Name: "Santa Claus", Unicode: []int32{127877}, ShortNames: []string{"santa"}},
			Emoji{Name: "Mrs. Claus", Unicode: []int32{129334}, ShortNames: []string{"mrs_claus"}},
			Emoji{Name: "mx claus", Unicode: []int32{129489, 8205, 127876}, ShortNames: []string{"mx_claus"}},
			Emoji{Name: "superhero", Unicode: []int32{129464}, ShortNames: []string{"superhero"}},
			Emoji{Name: "man superhero", Unicode: []int32{129464, 8205, 9794, 65039}, ShortNames: []string{"superhero_man"}},
			Emoji{Name: "woman superhero", Unicode: []int32{129464, 8205, 9792, 65039}, ShortNames: []string{"superhero_woman"}},
			Emoji{Name: "supervillain", Unicode: []int32{129465}, ShortNames: []string{"supervillain"}},
			Emoji{Name: "man supervillain", Unicode: []int32{129465, 8205, 9794, 65039}, ShortNames: []string{"supervillain_man"}},
			Emoji{Name: "woman supervillain", Unicode: []int32{129465, 8205, 9792, 65039}, ShortNames: []string{"supervillain_woman"}},
			Emoji{Name: "mage", Unicode: []int32{129497}, ShortNames: []string{"mage"}},
			Emoji{Name: "man mage", Unicode: []int32{129497, 8205, 9794, 65039}, ShortNames: []string{"mage_man"}},
			Emoji{Name: "woman mage", Unicode: []int32{129497, 8205, 9792, 65039}, ShortNames: []string{"mage_woman"}},
			Emoji{Name: "fairy", Unicode: []int32{129498}, ShortNames: []string{"fairy"}},
			Emoji{Name: "man fairy", Unicode: []int32{129498, 8205, 9794, 65039}, ShortNames: []string{"fairy_man"}},
			Emoji{Name: "woman fairy", Unicode: []int32{129498, 8205, 9792, 65039}, ShortNames: []string{"fairy_woman"}},
			Emoji{Name: "vampire", Unicode: []int32{129499}, ShortNames: []string{"vampire"}},
			Emoji{Name: "man vampire", Unicode: []int32{129499, 8205, 9794, 65039}, ShortNames: []string{"vampire_man"}},
			Emoji{Name: "woman vampire", Unicode: []int32{129499, 8205, 9792, 65039}, ShortNames: []string{"vampire_woman"}},
			Emoji{Name: "merperson", Unicode: []int32{129500}, ShortNames: []string{"merperson"}},
			Emoji{Name: "merman", Unicode: []int32{129500, 8205, 9794, 65039}, ShortNames: []string{"merman"}},
			Emoji{Name: "mermaid", Unicode: []int32{129500, 8205, 9792, 65039}, ShortNames: []string{"mermaid"}},
			Emoji{Name: "elf", Unicode: []int32{129501}, ShortNames: []string{"elf"}},
			Emoji{Name: "man elf", Unicode: []int32{129501, 8205, 9794, 65039}, ShortNames: []string{"elf_man"}},
			Emoji{Name: "woman elf", Unicode: []int32{129501, 8205, 9792, 65039}, ShortNames: []string{"elf_woman"}},
			Emoji{Name: "genie", Unicode: []int32{129502}, ShortNames: []string{"genie"}},
			Emoji{Name: "man genie", Unicode: []int32{129502, 8205, 9794, 65039}, ShortNames: []string{"genie_man"}},
			Emoji{Name: "woman genie", Unicode: []int32{129502, 8205, 9792, 65039}, ShortNames: []string{"genie_woman"}},
			Emoji{Name: "zombie", Unicode: []int32{129503}, ShortNames: []string{"zombie"}},
			Emoji{Name: "man zombie", Unicode: []int32{129503, 8205, 9794, 65039}, ShortNames: []string{"zombie_man"}},
			Emoji{Name: "woman zombie", Unicode: []int32{129503, 8205, 9792, 65039}, ShortNames: []string{"zombie_woman"}},
			Emoji{Name: "troll", Unicode: []int32{129484}, ShortNames: []string{"troll"}},
			Emoji{Name: "person getting massage", Unicode: []int32{128134}, ShortNames: []string{"massage"}},
			Emoji{Name: "man getting massage", Unicode: []int32{128134, 8205, 9794, 65039}, ShortNames: []string{"massage_man"}},
			Emoji{Name: "woman getting massage", Unicode: []int32{128134, 8205, 9792, 65039}, ShortNames: []string{"massage_woman"}},
			Emoji{Name: "person getting haircut", Unicode: []int32{128135}, ShortNames: []string{"haircut"}},
			Emoji{Name: "man getting haircut", Unicode: []int32{128135, 8205, 9794, 65039}, ShortNames: []string{"haircut_man"}},
			Emoji{Name: "woman getting haircut", Unicode: []int32{128135, 8205, 9792, 65039}, ShortNames: []string{"haircut_woman"}},
			Emoji{Name: "person walking", Unicode: []int32{128694}, ShortNames: []string{"walking"}},
			Emoji{Name: "man walking", Unicode: []int32{128694, 8205, 9794, 65039}, ShortNames: []string{"walking_man"}},
			Emoji{Name: "woman walking", Unicode: []int32{128694, 8205, 9792, 65039}, ShortNames: []string{"walking_woman"}},
			Emoji{Name: "person standing", Unicode: []int32{129485}, ShortNames: []string{"standing_person"}},
			Emoji{Name: "man standing", Unicode: []int32{129485, 8205, 9794, 65039}, ShortNames: []string{"standing_man"}},
			Emoji{Name: "woman standing", Unicode: []int32{129485, 8205, 9792, 65039}, ShortNames: []string{"standing_woman"}},
			Emoji{Name: "person kneeling", Unicode: []int32{129486}, ShortNames: []string{"kneeling_person"}},
			Emoji{Name: "man kneeling", Unicode: []int32{129486, 8205, 9794, 65039}, ShortNames: []string{"kneeling_man"}},
			Emoji{Name: "woman kneeling", Unicode: []int32{129486, 8205, 9792, 65039}, ShortNames: []string{"kneeling_woman"}},
			Emoji{Name: "person with white cane", Unicode: []int32{129489, 8205, 129455}, ShortNames: []string{"person_with_probing_cane"}},
			Emoji{Name: "man with white cane", Unicode: []int32{128104, 8205, 129455}, ShortNames: []string{"man_with_probing_cane"}},
			Emoji{Name: "woman with white cane", Unicode: []int32{128105, 8205, 129455}, ShortNames: []string{"woman_with_probing_cane"}},
			Emoji{Name: "person in motorized wheelchair", Unicode: []int32{129489, 8205, 129468}, ShortNames: []string{"person_in_motorized_wheelchair"}},
			Emoji{Name: "man in motorized wheelchair", Unicode: []int32{128104, 8205, 129468}, ShortNames: []string{"man_in_motorized_wheelchair"}},
			Emoji{Name: "woman in motorized wheelchair", Unicode: []int32{128105, 8205, 129468}, ShortNames: []string{"woman_in_motorized_wheelchair"}},
			Emoji{Name: "person in manual wheelchair", Unicode: []int32{129489, 8205, 129469}, ShortNames: []string{"person_in_manual_wheelchair"}},
			Emoji{Name: "man in manual wheelchair", Unicode: []int32{128104, 8205, 129469}, ShortNames: []string{"man_in_manual_wheelchair"}},
			Emoji{Name: "woman in manual wheelchair", Unicode: []int32{128105, 8205, 129469}, ShortNames: []string{"woman_in_manual_wheelchair"}},
			Emoji{Name: "person running", Unicode: []int32{127939}, ShortNames: []string{"runner", "running"}},
			Emoji{Name: "man running", Unicode: []int32{127939, 8205, 9794, 65039}, ShortNames: []string{"running_man"}},
			Emoji{Name: "woman running", Unicode: []int32{127939, 8205, 9792, 65039}, ShortNames: []string{"running_woman"}},
			Emoji{Name: "woman dancing", Unicode: []int32{128131}, ShortNames: []string{"woman_dancing", "dancer"}},
			Emoji{Name: "man dancing", Unicode: []int32{128378}, ShortNames: []string{"man_dancing"}},
			Emoji{Name: "person in suit levitating", Unicode: []int32{128372, 65039}, ShortNames: []string{"business_suit_levitating"}},
			Emoji{Name: "people with bunny ears", Unicode: []int32{128111}, ShortNames: []string{"dancers"}},
			Emoji{Name: "men with bunny ears", Unicode: []int32{128111, 8205, 9794, 65039}, ShortNames: []string{"dancing_men"}},
			Emoji{Name: "women with bunny ears", Unicode: []int32{128111, 8205, 9792, 65039}, ShortNames: []string{"dancing_women"}},
			Emoji{Name: "person in steamy room", Unicode: []int32{129494}, ShortNames: []string{"sauna_person"}},
			Emoji{Name: "man in steamy room", Unicode: []int32{129494, 8205, 9794, 65039}, ShortNames: []string{"sauna_man"}},
			Emoji{Name: "woman in steamy room", Unicode: []int32{129494, 8205, 9792, 65039}, ShortNames: []string{"sauna_woman"}},
			Emoji{Name: "person climbing", Unicode: []int32{129495}, ShortNames: []string{"climbing"}},
			Emoji{Name: "man climbing", Unicode: []int32{129495, 8205, 9794, 65039}, ShortNames: []string{"climbing_man"}},
			Emoji{Name: "woman climbing", Unicode: []int32{129495, 8205, 9792, 65039}, ShortNames: []string{"climbing_woman"}},
			Emoji{Name: "person fencing", Unicode: []int32{129338}, ShortNames: []string{"person_fencing"}},
			Emoji{Name: "horse racing", Unicode: []int32{127943}, ShortNames: []string{"horse_racing"}},
			Emoji{Name: "skier", Unicode: []int32{9975, 65039}, ShortNames: []string{"skier"}},
			Emoji{Name: "snowboarder", Unicode: []int32{127938}, ShortNames: []string{"snowboarder"}},
			Emoji{Name: "person golfing", Unicode: []int32{127948, 65039}, ShortNames: []string{"golfing"}},
			Emoji{Name: "man golfing", Unicode: []int32{127948, 65039, 8205, 9794, 65039}, ShortNames: []string{"golfing_man"}},
			Emoji{Name: "woman golfing", Unicode: []int32{127948, 65039, 8205, 9792, 65039}, ShortNames: []string{"golfing_woman"}},
			Emoji{Name: "person surfing", Unicode: []int32{127940}, ShortNames: []string{"surfer"}},
			Emoji{Name: "man surfing", Unicode: []int32{127940, 8205, 9794, 65039}, ShortNames: []string{"surfing_man"}},
			Emoji{Name: "woman surfing", Unicode: []int32{127940, 8205, 9792, 65039}, ShortNames: []string{"surfing_woman"}},
			Emoji{Name: "person rowing boat", Unicode: []int32{128675}, ShortNames: []string{"rowboat"}},
			Emoji{Name: "man rowing boat", Unicode: []int32{128675, 8205, 9794, 65039}, ShortNames: []string{"rowing_man"}},
			Emoji{Name: "woman rowing boat", Unicode: []int32{128675, 8205, 9792, 65039}, ShortNames: []string{"rowing_woman"}},
			Emoji{Name: "person swimming", Unicode: []int32{127946}, ShortNames: []string{"swimmer"}},
			Emoji{Name: "man swimming", Unicode: []int32{127946, 8205, 9794, 65039}, ShortNames: []string{"swimming_man"}},
			Emoji{Name: "woman swimming", Unicode: []int32{127946, 8205, 9792, 65039}, ShortNames: []string{"swimming_woman"}},
			Emoji{Name: "person bouncing ball", Unicode: []int32{9977, 65039}, ShortNames: []string{"bouncing_ball_person"}},
			Emoji{Name: "man bouncing ball", Unicode: []int32{9977, 65039, 8205, 9794, 65039}, ShortNames: []string{"bouncing_ball_man", "basketball_man"}},
			Emoji{Name: "woman bouncing ball", Unicode: []int32{9977, 65039, 8205, 9792, 65039}, ShortNames: []string{"bouncing_ball_woman", "basketball_woman"}},
			Emoji{Name: "person lifting weights", Unicode: []int32{127947, 65039}, ShortNames: []string{"weight_lifting"}},
			Emoji{Name: "man lifting weights", Unicode: []int32{127947, 65039, 8205, 9794, 65039}, ShortNames: []string{"weight_lifting_man"}},
			Emoji{Name: "woman lifting weights", Unicode: []int32{127947, 65039, 8205, 9792, 65039}, ShortNames: []string{"weight_lifting_woman"}},
			Emoji{Name: "person biking", Unicode: []int32{128692}, ShortNames: []string{"bicyclist"}},
			Emoji{Name: "man biking", Unicode: []int32{128692, 8205, 9794, 65039}, ShortNames: []string{"biking_man"}},
			Emoji{Name: "woman biking", Unicode: []int32{128692, 8205, 9792, 65039}, ShortNames: []string{"biking_woman"}},
			Emoji{Name: "person mountain biking", Unicode: []int32{128693}, ShortNames: []string{"mountain_bicyclist"}},
			Emoji{Name: "man mountain biking", Unicode: []int32{128693, 8205, 9794, 65039}, ShortNames: []string{"mountain_biking_man"}},
			Emoji{Name: "woman mountain biking", Unicode: []int32{128693, 8205, 9792, 65039}, ShortNames: []string{"mountain_biking_woman"}},
			Emoji{Name: "person cartwheeling", Unicode: []int32{129336}, ShortNames: []string{"cartwheeling"}},
			Emoji{Name: "man cartwheeling", Unicode: []int32{129336, 8205, 9794, 65039}, ShortNames: []string{"man_cartwheeling"}},
			Emoji{Name: "woman cartwheeling", Unicode: []int32{129336, 8205, 9792, 65039}, ShortNames: []string{"woman_cartwheeling"}},
			Emoji{Name: "people wrestling", Unicode: []int32{129340}, ShortNames: []string{"wrestling"}},
			Emoji{Name: "men wrestling", Unicode: []int32{129340, 8205, 9794, 65039}, ShortNames: []string{"men_wrestling"}},
			Emoji{Name: "women wrestling", Unicode: []int32{129340, 8205, 9792, 65039}, ShortNames: []string{"women_wrestling"}},
			Emoji{Name: "person playing water polo", Unicode: []int32{129341}, ShortNames: []string{"water_polo"}},
			Emoji{Name: "man playing water polo", Unicode: []int32{129341, 8205, 9794, 65039}, ShortNames: []string{"man_playing_water_polo"}},
			Emoji{Name: "woman playing water polo", Unicode: []int32{129341, 8205, 9792, 65039}, ShortNames: []string{"woman_playing_water_polo"}},
			Emoji{Name: "person playing handball", Unicode: []int32{129342}, ShortNames: []string{"handball_person"}},
			Emoji{Name: "man playing handball", Unicode: []int32{129342, 8205, 9794, 65039}, ShortNames: []string{"man_playing_handball"}},
			Emoji{Name: "woman playing handball", Unicode: []int32{129342, 8205, 9792, 65039}, ShortNames: []string{"woman_playing_handball"}},
			Emoji{Name: "person juggling", Unicode: []int32{129337}, ShortNames: []string{"juggling_person"}},
			Emoji{Name: "man juggling", Unicode: []int32{129337, 8205, 9794, 65039}, ShortNames: []string{"man_juggling"}},
			Emoji{Name: "woman juggling", Unicode: []int32{129337, 8205, 9792, 65039}, ShortNames: []string{"woman_juggling"}},
			Emoji{Name: "person in lotus position", Unicode: []int32{129496}, ShortNames: []string{"lotus_position"}},
			Emoji{Name: "man in lotus position", Unicode: []int32{129496, 8205, 9794, 65039}, ShortNames: []string{"lotus_position_man"}},
			Emoji{Name: "woman in lotus position", Unicode: []int32{129496, 8205, 9792, 65039}, ShortNames: []string{"lotus_position_woman"}},
			Emoji{Name: "person taking bath", Unicode: []int32{128704}, ShortNames: []string{"bath"}},
			Emoji{Name: "person in bed", Unicode: []int32{128716}, ShortNames: []string{"sleeping_bed"}},
			Emoji{Name: "people holding hands", Unicode: []int32{129489, 8205, 129309, 8205, 129489}, ShortNames: []string{"people_holding_hands"}},
			Emoji{Name: "women holding hands", Unicode: []int32{128109}, ShortNames: []string{"two_women_holding_hands"}},
			Emoji{Name: "woman and man holding hands", Unicode: []int32{128107}, ShortNames: []string{"couple"}},
			Emoji{Name: "men holding hands", Unicode: []int32{128108}, ShortNames: []string{"two_men_holding_hands"}},
			Emoji{Name: "kiss", Unicode: []int32{128143}, ShortNames: []string{"couplekiss"}},
			Emoji{Name: "kiss: woman, man", Unicode: []int32{128105, 8205, 10084, 65039, 8205, 128139, 8205, 128104}, ShortNames: []string{"couplekiss_man_woman"}},
			Emoji{Name: "kiss: man, man", Unicode: []int32{128104, 8205, 10084, 65039, 8205, 128139, 8205, 128104}, ShortNames: []string{"couplekiss_man_man"}},
			Emoji{Name: "kiss: woman, woman", Unicode: []int32{128105, 8205, 10084, 65039, 8205, 128139, 8205, 128105}, ShortNames: []string{"couplekiss_woman_woman"}},
			Emoji{Name: "couple with heart", Unicode: []int32{128145}, ShortNames: []string{"couple_with_heart"}},
			Emoji{Name: "couple with heart: woman, man", Unicode: []int32{128105, 8205, 10084, 65039, 8205, 128104}, ShortNames: []string{"couple_with_heart_woman_man"}},
			Emoji{Name: "couple with heart: man, man", Unicode: []int32{128104, 8205, 10084, 65039, 8205, 128104}, ShortNames: []string{"couple_with_heart_man_man"}},
			Emoji{Name: "couple with heart: woman, woman", Unicode: []int32{128105, 8205, 10084, 65039, 8205, 128105}, ShortNames: []string{"couple_with_heart_woman_woman"}},
			Emoji{Name: "family", Unicode: []int32{128106}, ShortNames: []string{"family"}},
			Emoji{Name: "family: man, woman, boy", Unicode: []int32{128104, 8205, 128105, 8205, 128102}, ShortNames: []string{"family_man_woman_boy"}},
			Emoji{Name: "family: man, woman, girl", Unicode: []int32{128104, 8205, 128105, 8205, 128103}, ShortNames: []string{"family_man_woman_girl"}},
			Emoji{Name: "family: man, woman, girl, boy", Unicode: []int32{128104, 8205, 128105, 8205, 128103, 8205, 128102}, ShortNames: []string{"family_man_woman_girl_boy"}},
			Emoji{Name: "family: man, woman, boy, boy", Unicode: []int32{128104, 8205, 128105, 8205, 128102, 8205, 128102}, ShortNames: []string{"family_man_woman_boy_boy"}},
			Emoji{Name: "family: man, woman, girl, girl", Unicode: []int32{128104, 8205, 128105, 8205, 128103, 8205, 128103}, ShortNames: []string{"family_man_woman_girl_girl"}},
			Emoji{Name: "family: man, man, boy", Unicode: []int32{128104, 8205, 128104, 8205, 128102}, ShortNames: []string{"family_man_man_boy"}},
			Emoji{Name: "family: man, man, girl", Unicode: []int32{128104, 8205, 128104, 8205, 128103}, ShortNames: []string{"family_man_man_girl"}},
			Emoji{Name: "family: man, man, girl, boy", Unicode: []int32{128104, 8205, 128104, 8205, 128103, 8205, 128102}, ShortNames: []string{"family_man_man_girl_boy"}},
			Emoji{Name: "family: man, man, boy, boy", Unicode: []int32{128104, 8205, 128104, 8205, 128102, 8205, 128102}, ShortNames: []string{"family_man_man_boy_boy"}},
			Emoji{Name: "family: man, man, girl, girl", Unicode: []int32{128104, 8205, 128104, 8205, 128103, 8205, 128103}, ShortNames: []string{"family_man_man_girl_girl"}},
			Emoji{Name: "family: woman, woman, boy", Unicode: []int32{128105, 8205, 128105, 8205, 128102}, ShortNames: []string{"family_woman_woman_boy"}},
			Emoji{Name: "family: woman, woman, girl", Unicode: []int32{128105, 8205, 128105, 8205, 128103}, ShortNames: []string{"family_woman_woman_girl"}},
			Emoji{Name: "family: woman, woman, girl, boy", Unicode: []int32{128105, 8205, 128105, 8205, 128103, 8205, 128102}, ShortNames: []string{"family_woman_woman_girl_boy"}},
			Emoji{Name: "family: woman, woman, boy, boy", Unicode: []int32{128105, 8205, 128105, 8205, 128102, 8205, 128102}, ShortNames: []string{"family_woman_woman_boy_boy"}},
			Emoji{Name: "family: woman, woman, girl, girl", Unicode: []int32{128105, 8205, 128105, 8205, 128103, 8205, 128103}, ShortNames: []string{"family_woman_woman_girl_girl"}},
			Emoji{Name: "family: man, boy", Unicode: []int32{128104, 8205, 128102}, ShortNames: []string{"family_man_boy"}},
			Emoji{Name: "family: man, boy, boy", Unicode: []int32{128104, 8205, 128102, 8205, 128102}, ShortNames: []string{"family_man_boy_boy"}},
			Emoji{Name: "family: man, girl", Unicode: []int32{128104, 8205, 128103}, ShortNames: []string{"family_man_girl"}},
			Emoji{Name: "family: man, girl, boy", Unicode: []int32{128104, 8205, 128103, 8205, 128102}, ShortNames: []string{"family_man_girl_boy"}},
			Emoji{Name: "family: man, girl, girl", Unicode: []int32{128104, 8205, 128103, 8205, 128103}, ShortNames: []string{"family_man_girl_girl"}},
			Emoji{Name: "family: woman, boy", Unicode: []int32{128105, 8205, 128102}, ShortNames: []string{"family_woman_boy"}},
			Emoji{Name: "family: woman, boy, boy", Unicode: []int32{128105, 8205, 128102, 8205, 128102}, ShortNames: []string{"family_woman_boy_boy"}},
			Emoji{Name: "family: woman, girl", Unicode: []int32{128105, 8205, 128103}, ShortNames: []string{"family_woman_girl"}},
			Emoji{Name: "family: woman, girl, boy", Unicode: []int32{128105, 8205, 128103, 8205, 128102}, ShortNames: []string{"family_woman_girl_boy"}},
			Emoji{Name: "family: woman, girl, girl", Unicode: []int32{128105, 8205, 128103, 8205, 128103}, ShortNames: []string{"family_woman_girl_girl"}},
			Emoji{Name: "speaking head", Unicode: []int32{128483, 65039}, ShortNames: []string{"speaking_head"}},
			Emoji{Name: "bust in silhouette", Unicode: []int32{128100}, ShortNames: []string{"bust_in_silhouette"}},
			Emoji{Name: "busts in silhouette", Unicode: []int32{128101}, ShortNames: []string{"busts_in_silhouette"}},
			Emoji{Name: "people hugging", Unicode: []int32{129730}, ShortNames: []string{"people_hugging"}},
			Emoji{Name: "footprints", Unicode: []int32{128099}, ShortNames: []string{"footprints"}},
			Emoji{Name: "monkey face", Unicode: []int32{128053}, ShortNames: []string{"monkey_face"}},
			Emoji{Name: "monkey", Unicode: []int32{128018}, ShortNames: []string{"monkey"}},
			Emoji{Name: "gorilla", Unicode: []int32{129421}, ShortNames: []string{"gorilla"}},
			Emoji{Name: "orangutan", Unicode: []int32{129447}, ShortNames: []string{"orangutan"}},
			Emoji{Name: "dog face", Unicode: []int32{128054}, ShortNames: []string{"dog"}},
			Emoji{Name: "dog", Unicode: []int32{128021}, ShortNames: []string{"dog2"}},
			Emoji{Name: "guide dog", Unicode: []int32{129454}, ShortNames: []string{"guide_dog"}},
			Emoji{Name: "service dog", Unicode: []int32{128021, 8205, 129466}, ShortNames: []string{"service_dog"}},
			Emoji{Name: "poodle", Unicode: []int32{128041}, ShortNames: []string{"poodle"}},
			Emoji{Name: "wolf", Unicode: []int32{128058}, ShortNames: []string{"wolf"}},
			Emoji{Name: "fox", Unicode: []int32{129418}, ShortNames: []string{"fox_face"}},
			Emoji{Name: "raccoon", Unicode: []int32{129437}, ShortNames: []string{"raccoon"}},
			Emoji{Name: "cat face", Unicode: []int32{128049}, ShortNames: []string{"cat"}},
			Emoji{Name: "cat", Unicode: []int32{128008}, ShortNames: []string{"cat2"}},
			Emoji{Name: "black cat", Unicode: []int32{128008, 8205, 11035}, ShortNames: []string{"black_cat"}},
			Emoji{Name: "lion", Unicode: []int32{129409}, ShortNames: []string{"lion"}},
			Emoji{Name: "tiger face", Unicode: []int32{128047}, ShortNames: []string{"tiger"}},
			Emoji{Name: "tiger", Unicode: []int32{128005}, ShortNames: []string{"tiger2"}},
			Emoji{Name: "leopard", Unicode: []int32{128006}, ShortNames: []string{"leopard"}},
			Emoji{Name: "horse face", Unicode: []int32{128052}, ShortNames: []string{"horse"}},
			Emoji{Name: "moose", Unicode: []int32{129742}, ShortNames: []string{"moose"}},
			Emoji{Name: "donkey", Unicode: []int32{129743}, ShortNames: []string{"donkey"}},
			Emoji{Name: "horse", Unicode: []int32{128014}, ShortNames: []string{"racehorse"}},
			Emoji{Name: "unicorn", Unicode: []int32{129412}, ShortNames: []string{"unicorn"}},
			Emoji{Name: "zebra", Unicode: []int32{129427}, ShortNames: []string{"zebra"}},
			Emoji{Name: "deer", Unicode: []int32{129420}, ShortNames: []string{"deer"}},
			Emoji{Name: "bison", Unicode: []int32{129452}, ShortNames: []string{"bison"}},
			Emoji{Name: "cow face", Unicode: []int32{128046}, ShortNames: []string{"cow"}},
			Emoji{Name: "ox", Unicode: []int32{128002}, ShortNames: []string{"ox"}},
			Emoji{Name: "water buffalo", Unicode: []int32{128003}, ShortNames: []string{"water_buffalo"}},
			Emoji{Name: "cow", Unicode: []int32{128004}, ShortNames: []string{"cow2"}},
			Emoji{Name: "pig face", Unicode: []int32{128055}, ShortNames: []string{"pig"}},
			Emoji{Name: "pig", Unicode: []int32{128022}, ShortNames: []string{"pig2"}},
			Emoji{Name: "boar", Unicode: []int32{128023}, ShortNames: []string{"boar"}},
			Emoji{Name: "pig nose", Unicode: []int32{128061}, ShortNames: []string{"pig_nose"}},
			Emoji{Name: "ram", Unicode: []int32{128015}, ShortNames: []string{"ram"}},
			Emoji{Name: "ewe", Unicode: []int32{128017}, ShortNames: []string{"sheep"}},
			Emoji{Name: "goat", Unicode: []int32{128016}, ShortNames: []string{"goat"}},
			Emoji{Name: "camel", Unicode: []int32{128042}, ShortNames: []string{"dromedary_camel"}},
			Emoji{Name: "two-hump camel", Unicode: []int32{128043}, ShortNames: []string{"camel"}},
			Emoji{Name: "llama", Unicode: []int32{129433}, ShortNames: []string{"llama"}},
			Emoji{Name: "giraffe", Unicode: []int32{129426}, ShortNames: []string{"giraffe"}},
			Emoji{Name: "elephant", Unicode: []int32{128024}, ShortNames: []string{"elephant"}},
			Emoji{Name: "mammoth", Unicode: []int32{129443}, ShortNames: []string{"mammoth"}},
			Emoji{Name: "rhinoceros", Unicode: []int32{129423}, ShortNames: []string{"rhinoceros"}},
			Emoji{Name: "hippopotamus", Unicode: []int32{129435}, ShortNames: []string{"hippopotamus"}},
			Emoji{Name: "mouse face", Unicode: []int32{128045}, ShortNames: []string{"mouse"}},
			Emoji{Name: "mouse", Unicode: []int32{128001}, ShortNames: []string{"mouse2"}},
			Emoji{Name: "rat", Unicode: []int32{128000}, ShortNames: []string{"rat"}},
			Emoji{Name: "hamster", Unicode: []int32{128057}, ShortNames: []string{"hamster"}},
			Emoji{Name: "rabbit face", Unicode: []int32{128048}, ShortNames: []string{"rabbit"}},
			Emoji{Name: "rabbit", Unicode: []int32{128007}, ShortNames: []string{"rabbit2"}},
			Emoji{Name: "chipmunk", Unicode: []int32{128063, 65039}, ShortNames: []string{"chipmunk"}},
			Emoji{Name: "beaver", Unicode: []int32{129451}, ShortNames: []string{"beaver"}},
			Emoji{Name: "hedgehog", Unicode: []int32{129428}, ShortNames: []string{"hedgehog"}},
			Emoji{Name: "bat", Unicode: []int32{129415}, ShortNames: []string{"bat"}},
			Emoji{Name: "bear", Unicode: []int32{128059}, ShortNames: []string{"bear"}},
			Emoji{Name: "polar bear", Unicode: []int32{128059, 8205, 10052, 65039}, ShortNames: []string{"polar_bear"}},
			Emoji{Name: "koala", Unicode: []int32{128040}, ShortNames: []string{"koala"}},
			Emoji{Name: "panda", Unicode: []int32{128060}, ShortNames: []string{"panda_face"}},
			Emoji{Name: "sloth", Unicode: []int32{129445}, ShortNames: []string{"sloth"}},
			Emoji{Name: "otter", Unicode: []int32{129446}, ShortNames: []string{"otter"}},
			Emoji{Name: "skunk", Unicode: []int32{129448}, ShortNames: []string{"skunk"}},
			Emoji{Name: "kangaroo", Unicode: []int32{129432}, ShortNames: []string{"kangaroo"}},
			Emoji{Name: "badger", Unicode: []int32{129441}, ShortNames: []string{"badger"}},
			Emoji{Name: "paw prints", Unicode: []int32{128062}, ShortNames: []string{"feet", "paw_prints"}},
			Emoji{Name: "turkey", Unicode: []int32{129411}, ShortNames: []string{"turkey"}},
			Emoji{Name: "chicken", Unicode: []int32{128020}, ShortNames: []string{"chicken"}},
			Emoji{Name: "rooster", Unicode: []int32{128019}, ShortNames: []string{"rooster"}},
			Emoji{Name: "hatching chick", Unicode: []int32{128035}, ShortNames: []string{"hatching_chick"}},
			Emoji{Name: "baby chick", Unicode: []int32{128036}, ShortNames: []string{"baby_chick"}},
			Emoji{Name: "front-facing baby chick", Unicode: []int32{128037}, ShortNames: []string{"hatched_chick"}},
			Emoji{Name: "bird", Unicode: []int32{128038}, ShortNames: []string{"bird"}},
			Emoji{Name: "penguin", Unicode: []int32{128039}, ShortNames: []string{"penguin"}},
			Emoji{Name: "dove", Unicode: []int32{128330, 65039}, ShortNames: []string{"dove"}},
			Emoji{Name: "eagle", Unicode: []int32{129413}, ShortNames: []string{"eagle"}},
			Emoji{Name: "duck", Unicode: []int32{129414}, ShortNames: []string{"duck"}},
			Emoji{Name: "swan", Unicode: []int32{129442}, ShortNames: []string{"swan"}},
			Emoji{Name: "owl", Unicode: []int32{129417}, ShortNames: []string{"owl"}},
			Emoji{Name: "dodo", Unicode: []int32{129444}, ShortNames: []string{"dodo"}},
			Emoji{Name: "feather", Unicode: []int32{129718}, ShortNames: []string{"feather"}},
			Emoji{Name: "flamingo", Unicode: []int32{129449}, ShortNames: []string{"flamingo"}},
			Emoji{Name: "peacock", Unicode: []int32{129434}, ShortNames: []string{"peacock"}},
			Emoji{Name: "parrot", Unicode: []int32{129436}, ShortNames: []string{"parrot"}},
			Emoji{Name: "wing", Unicode: []int32{129725}, ShortNames: []string{"wing"}},
			Emoji{Name: "black bird", Unicode: []int32{128038, 8205, 11035}, ShortNames: []string{"black_bird"}},
			Emoji{Name: "goose", Unicode: []int32{129727}, ShortNames: []string{"goose"}},
			Emoji{Name: "frog", Unicode: []int32{128056}, ShortNames: []string{"frog"}},
			Emoji{Name: "crocodile", Unicode: []int32{128010}, ShortNames: []string{"crocodile"}},
			Emoji{Name: "turtle", Unicode: []int32{128034}, ShortNames: []string{"turtle"}},
			Emoji{Name: "lizard", Unicode: []int32{129422}, ShortNames: []string{"lizard"}},
			Emoji{Name: "snake", Unicode: []int32{128013}, ShortNames: []string{"snake"}},
			Emoji{Name: "dragon face", Unicode: []int32{128050}, ShortNames: []string{"dragon_face"}},
			Emoji{Name: "dragon", Unicode: []int32{128009}, ShortNames: []string{"dragon"}},
			Emoji{Name: "sauropod", Unicode: []int32{129429}, ShortNames: []string{"sauropod"}},
			Emoji{Name: "T-Rex", Unicode: []int32{129430}, ShortNames: []string{"t-rex"}},
			Emoji{Name: "spouting whale", Unicode: []int32{128051}, ShortNames: []string{"whale"}},
			Emoji{Name: "whale", Unicode: []int32{128011}, ShortNames: []string{"whale2"}},
			Emoji{Name: "dolphin", Unicode: []int32{128044}, ShortNames: []string{"dolphin", "flipper"}},
			Emoji{Name: "seal", Unicode: []int32{129453}, ShortNames: []string{"seal"}},
			Emoji{Name: "fish", Unicode: []int32{128031}, ShortNames: []string{"fish"}},
			Emoji{Name: "tropical fish", Unicode: []int32{128032}, ShortNames: []string{"tropical_fish"}},
			Emoji{Name: "blowfish", Unicode: []int32{128033}, ShortNames: []string{"blowfish"}},
			Emoji{Name: "shark", Unicode: []int32{129416}, ShortNames: []string{"shark"}},
			Emoji{Name: "octopus", Unicode: []int32{128025}, ShortNames: []string{"octopus"}},
			Emoji{Name: "spiral shell", Unicode: []int32{128026}, ShortNames: []string{"shell"}},
			Emoji{Name: "coral", Unicode: []int32{129720}, ShortNames: []string{"coral"}},
			Emoji{Name: "jellyfish", Unicode: []int32{129724}, ShortNames: []string{"jellyfish"}},
			Emoji{Name: "snail", Unicode: []int32{128012}, ShortNames: []string{"snail"}},
			Emoji{Name: "butterfly", Unicode: []int32{129419}, ShortNames: []string{"butterfly"}},
			Emoji{Name: "bug", Unicode: []int32{128027}, ShortNames: []string{"bug"}},
			Emoji{Name: "ant", Unicode: []int32{128028}, ShortNames: []string{"ant"}},
			Emoji{Name: "honeybee", Unicode: []int32{128029}, ShortNames: []string{"bee", "honeybee"}},
			Emoji{Name: "beetle", Unicode: []int32{129714}, ShortNames: []string{"beetle"}},
			Emoji{Name: "lady beetle", Unicode: []int32{128030}, ShortNames: []string{"lady_beetle"}},
			Emoji{Name: "cricket", Unicode: []int32{129431}, ShortNames: []string{"cricket"}},
			Emoji{Name: "cockroach", Unicode: []int32{129715}, ShortNames: []string{"cockroach"}},
			Emoji{Name: "spider", Unicode: []int32{128375, 65039}, ShortNames: []string{"spider"}},
			Emoji{Name: "spider web", Unicode: []int32{128376, 65039}, ShortNames: []string{"spider_web"}},
			Emoji{Name: "scorpion", Unicode: []int32{129410}, ShortNames: []string{"scorpion"}},
			Emoji{Name: "mosquito", Unicode: []int32{129439}, ShortNames: []string{"mosquito"}},
			Emoji{Name: "fly", Unicode: []int32{129712}, ShortNames: []string{"fly"}},
			Emoji{Name: "worm", Unicode: []int32{129713}, ShortNames: []string{"worm"}},
			Emoji{Name: "microbe", Unicode: []int32{129440}, ShortNames: []string{"microbe"}},
			Emoji{Name: "bouquet", Unicode: []int32{128144}, ShortNames: []string{"bouquet"}},
			Emoji{Name: "cherry blossom", Unicode: []int32{127800}, ShortNames: []string{"cherry_blossom"}},
			Emoji{Name: "white flower", Unicode: []int32{128174}, ShortNames: []string{"white_flower"}},
			Emoji{Name: "lotus", Unicode: []int32{129719}, ShortNames: []string{"lotus"}},
			Emoji{Name: "rosette", Unicode: []int32{127989, 65039}, ShortNames: []string{"rosette"}},
			Emoji{Name: "rose", Unicode: []int32{127801}, ShortNames: []string{"rose"}},
			Emoji{Name: "wilted flower", Unicode: []int32{129344}, ShortNames: []string{"wilted_flower"}},
			Emoji{Name: "hibiscus", Unicode: []int32{127802}, ShortNames: []string{"hibiscus"}},
			Emoji{Name: "sunflower", Unicode: []int32{127803}, ShortNames: []string{"sunflower"}},
			Emoji{Name: "blossom", Unicode: []int32{127804}, ShortNames: []string{"blossom"}},
			Emoji{Name: "tulip", Unicode: []int32{127799}, ShortNames: []string{"tulip"}},
			Emoji{Name: "hyacinth", Unicode: []int32{129723}, ShortNames: []string{"hyacinth"}},
			Emoji{Name: "seedling", Unicode: []int32{127793}, ShortNames: []string{"seedling"}},
			Emoji{Name: "potted plant", Unicode: []int32{129716}, ShortNames: []string{"potted_plant"}},
			Emoji{Name: "evergreen tree", Unicode: []int32{127794}, ShortNames: []string{"evergreen_tree"}},
			Emoji{Name: "deciduous tree", Unicode: []int32{127795}, ShortNames: []string{"deciduous_tree"}},
			Emoji{Name: "palm tree", Unicode: []int32{127796}, ShortNames: []string{"palm_tree"}},
			Emoji{Name: "cactus", Unicode: []int32{127797}, ShortNames: []string{"cactus"}},
			Emoji{Name: "sheaf of rice", Unicode: []int32{127806}, ShortNames: []string{"ear_of_rice"}},
			Emoji{Name: "herb", Unicode: []int32{127807}, ShortNames: []string{"herb"}},
			Emoji{Name: "shamrock", Unicode: []int32{9752, 65039}, ShortNames: []string{"shamrock"}},
			Emoji{Name: "four leaf clover", Unicode: []int32{127808}, ShortNames: []string{"four_leaf_clover"}},
			Emoji{Name: "maple leaf", Unicode: []int32{127809}, ShortNames: []string{"maple_leaf"}},
			Emoji{Name: "fallen leaf", Unicode: []int32{127810}, ShortNames: []string{"fallen_leaf"}},
			Emoji{Name: "leaf fluttering in wind", Unicode: []int32{127811}, ShortNames: []string{"leaves"}},
			Emoji{Name: "empty nest", Unicode: []int32{129721}, ShortNames: []string{"empty_nest"}},
			Emoji{Name: "nest with eggs", Unicode: []int32{129722}, ShortNames: []string{"nest_with_eggs"}},
			Emoji{Name: "mushroom", Unicode: []int32{127812}, ShortNames: []string{"mushroom"}},
			Emoji{Name: "grapes", Unicode: []int32{127815}, ShortNames: []string{"grapes"}},
			Emoji{Name: "melon", Unicode: []int32{127816}, ShortNames: []string{"melon"}},
			Emoji{Name: "watermelon", Unicode: []int32{127817}, ShortNames: []string{"watermelon"}},
			Emoji{Name: "tangerine", Unicode: []int32{127818}, ShortNames: []string{"tangerine", "orange", "mandarin"}},
			Emoji{Name: "lemon", Unicode: []int32{127819}, ShortNames: []string{"lemon"}},
			Emoji{Name: "banana", Unicode: []int32{127820}, ShortNames: []string{"banana"}},
			Emoji{Name: "pineapple", Unicode: []int32{127821}, ShortNames: []string{"pineapple"}},
			Emoji{Name: "mango", Unicode: []int32{129389}, ShortNames: []string{"mango"}},
			Emoji{Name: "red apple", Unicode: []int32{127822}, ShortNames: []string{"apple"}},
			Emoji{Name: "green apple", Unicode: []int32{127823}, ShortNames: []string{"green_apple"}},
			Emoji{Name: "pear", Unicode: []int32{127824}, ShortNames: []string{"pear"}},
			Emoji{Name: "peach", Unicode: []int32{127825}, ShortNames: []string{"peach"}},
			Emoji{Name: "cherries", Unicode: []int32{127826}, ShortNames: []string{"cherries"}},
			Emoji{Name: "strawberry", Unicode: []int32{127827}, ShortNames: []string{"strawberry"}},
			Emoji{Name: "blueberries", Unicode: []int32{129744}, ShortNames: []string{"blueberries"}},
			Emoji{Name: "kiwi fruit", Unicode: []int32{129373}, ShortNames: []string{"kiwi_fruit"}},
			Emoji{Name: "tomato", Unicode: []int32{127813}, ShortNames: []string{"tomato"}},
			Emoji{Name: "olive", Unicode: []int32{129746}, ShortNames: []string{"olive"}},
			Emoji{Name: "coconut", Unicode: []int32{129381}, ShortNames: []string{"coconut"}},
			Emoji{Name: "avocado", Unicode: []int32{129361}, ShortNames: []string{"avocado"}},
			Emoji{Name: "eggplant", Unicode: []int32{127814}, ShortNames: []string{"eggplant"}},
			Emoji{Name: "potato", Unicode: []int32{129364}, ShortNames: []string{"potato"}},
			Emoji{Name: "carrot", Unicode: []int32{129365}, ShortNames: []string{"carrot"}},
			Emoji{Name: "ear of corn", Unicode: []int32{127805}, ShortNames: []string{"corn"}},
			Emoji{Name: "hot pepper", Unicode: []int32{127798, 65039}, ShortNames: []string{"hot_pepper"}},
			Emoji{Name: "bell pepper", Unicode: []int32{129745}, ShortNames: []string{"bell_pepper"}},
			Emoji{Name: "cucumber", Unicode: []int32{129362}, ShortNames: []string{"cucumber"}},
			Emoji{Name: "leafy green", Unicode: []int32{129388}, ShortNames: []string{"leafy_green"}},
			Emoji{Name: "broccoli", Unicode: []int32{129382}, ShortNames: []string{"broccoli"}},
			Emoji{Name: "garlic", Unicode: []int32{129476}, ShortNames: []string{"garlic"}},
			Emoji{Name: "onion", Unicode: []int32{129477}, ShortNames: []string{"onion"}},
			Emoji{Name: "peanuts", Unicode: []int32{129372}, ShortNames: []string{"peanuts"}},
			Emoji{Name: "beans", Unicode: []int32{129752}, ShortNames: []string{"beans"}},
			Emoji{Name: "chestnut", Unicode: []int32{127792}, ShortNames: []string{"chestnut"}},
			Emoji{Name: "ginger root", Unicode: []int32{129754}, ShortNames: []string{"ginger_root"}},
			Emoji{Name: "pea pod", Unicode: []int32{129755}, ShortNames: []string{"pea_pod"}},
			Emoji{Name: "bread", Unicode: []int32{127838}, ShortNames: []string{"bread"}},
			Emoji{Name: "croissant", Unicode: []int32{129360}, ShortNames: []string{"croissant"}},
			Emoji{Name: "baguette bread", Unicode: []int32{129366}, ShortNames: []string{"baguette_bread"}},
			Emoji{Name: "flatbread", Unicode: []int32{129747}, ShortNames: []string{"flatbread"}},
			Emoji{Name: "pretzel", Unicode: []int32{129384}, ShortNames: []string{"pretzel"}},
			Emoji{Name: "bagel", Unicode: []int32{129391}, ShortNames: []string{"bagel"}},
			Emoji{Name: "pancakes", Unicode: []int32{129374}, ShortNames: []string{"pancakes"}},
			Emoji{Name: "waffle", Unicode: []int32{129479}, ShortNames: []string{"waffle"}},
			Emoji{Name: "cheese wedge", Unicode: []int32{129472}, ShortNames: []string{"cheese"}},
			Emoji{Name: "meat on bone", Unicode: []int32{127830}, ShortNames: []string{"meat_on_bone"}},
			Emoji{Name: "poultry leg", Unicode: []int32{127831}, ShortNames: []string{"poultry_leg"}},
			Emoji{Name: "cut of meat", Unicode: []int32{129385}, ShortNames: []string{"cut_of_meat"}},
			Emoji{Name: "bacon", Unicode: []int32{129363}, ShortNames: []string{"bacon"}},
			Emoji{Name: "hamburger", Unicode: []int32{127828}, ShortNames: []string{"hamburger"}},
			Emoji{Name: "french fries", Unicode: []int32{127839}, ShortNames: []string{"fries"}},
			Emoji{Name: "pizza", Unicode: []int32{127829}, ShortNames: []string{"pizza"}},
			Emoji{Name: "hot dog", Unicode: []int32{127789}, ShortNames: []string{"hotdog"}},
			Emoji{Name: "sandwich", Unicode: []int32{129386}, ShortNames: []string{"sandwich"}},
			Emoji{Name: "taco", Unicode: []int32{127790}, ShortNames: []string{"taco"}},
			Emoji{Name: "burrito", Unicode: []int32{127791}, ShortNames: []string{"burrito"}},
			Emoji{Name: "tamale", Unicode: []int32{129748}, ShortNames: []string{"tamale"}},
			Emoji{Name: "stuffed flatbread", Unicode: []int32{129369}, ShortNames: []string{"stuffed_flatbread"}},
			Emoji{Name: "falafel", Unicode: []int32{129478}, ShortNames: []string{"falafel"}},
			Emoji{Name: "egg", Unicode: []int32{129370}, ShortNames: []string{"egg"}},
			Emoji{Name: "cooking", Unicode: []int32{127859}, ShortNames: []string{"fried_egg"}},
			Emoji{Name: "shallow pan of food", Unicode: []int32{129368}, ShortNames: []string{"shallow_pan_of_food"}},
			Emoji{Name: "pot of food", Unicode: []int32{127858}, ShortNames: []string{"stew"}},
			Emoji{Name: "fondue", Unicode: []int32{129749}, ShortNames: []string{"fondue"}},
			Emoji{Name: "bowl with spoon", Unicode: []int32{129379}, ShortNames: []string{"bowl_with_spoon"}},
			Emoji{Name: "green salad", Unicode: []int32{129367}, ShortNames: []string{"green_salad"}},
			Emoji{Name: "popcorn", Unicode: []int32{127871}, ShortNames: []string{"popcorn"}},
			Emoji{Name: "butter", Unicode: []int32{129480}, ShortNames: []string{"butter"}},
			Emoji{Name: "salt", Unicode: []int32{129474}, ShortNames: []string{"salt"}},
			Emoji{Name: "canned food", Unicode: []int32{129387}, ShortNames: []string{"canned_food"}},
			Emoji{Name: "bento box", Unicode: []int32{127857}, ShortNames: []string{"bento"}},
			Emoji{Name: "rice cracker", Unicode: []int32{127832}, ShortNames: []string{"rice_cracker"}},
			Emoji{Name: "rice ball", Unicode: []int32{127833}, ShortNames: []string{"rice_ball"}},
			Emoji{Name: "cooked rice", Unicode: []int32{127834}, ShortNames: []string{"rice"}},
			Emoji{Name: "curry rice", Unicode: []int32{127835}, ShortNames: []string{"curry"}},
			Emoji{Name: "steaming bowl", Unicode: []int32{127836}, ShortNames: []string{"ramen"}},
			Emoji{Name: "spaghetti", Unicode: []int32{127837}, ShortNames: []string{"spaghetti"}},
			Emoji{Name: "roasted sweet potato", Unicode: []int32{127840}, ShortNames: []string{"sweet_potato"}},
			Emoji{Name: "oden", Unicode: []int32{127842}, ShortNames: []string{"oden"}},
			Emoji{Name: "sushi", Unicode: []int32{127843}, ShortNames: []string{"sushi"}},
			Emoji{Name: "fried shrimp", Unicode: []int32{127844}, ShortNames: []string{"fried_shrimp"}},
			Emoji{Name: "fish cake with swirl", Unicode: []int32{127845}, ShortNames: []string{"fish_cake"}},
			Emoji{Name: "moon cake", Unicode: []int32{129390}, ShortNames: []string{"moon_cake"}},
			Emoji{Name: "dango", Unicode: []int32{127841}, ShortNames: []string{"dango"}},
			Emoji{Name: "dumpling", Unicode: []int32{129375}, ShortNames: []string{"dumpling"}},
			Emoji{Name: "fortune cookie", Unicode: []int32{129376}, ShortNames: []string{"fortune_cookie"}},
			Emoji{Name: "takeout box", Unicode: []int32{129377}, ShortNames: []string{"takeout_box"}},
			Emoji{Name: "crab", Unicode: []int32{129408}, ShortNames: []string{"crab"}},
			Emoji{Name: "lobster", Unicode: []int32{129438}, ShortNames: []string{"lobster"}},
			Emoji{Name: "shrimp", Unicode: []int32{129424}, ShortNames: []string{"shrimp"}},
			Emoji{Name: "squid", Unicode: []int32{129425}, ShortNames: []string{"squid"}},
			Emoji{Name: "oyster", Unicode: []int32{129450}, ShortNames: []string{"oyster"}},
			Emoji{Name: "soft ice cream", Unicode: []int32{127846}, ShortNames: []string{"icecream"}},
			Emoji{Name: "shaved ice", Unicode: []int32{127847}, ShortNames: []string{"shaved_ice"}},
			Emoji{Name: "ice cream", Unicode: []int32{127848}, ShortNames: []string{"ice_cream"}},
			Emoji{Name: "doughnut", Unicode: []int32{127849}, ShortNames: []string{"doughnut"}},
			Emoji{Name: "cookie", Unicode: []int32{127850}, ShortNames: []string{"cookie"}},
			Emoji{Name: "birthday cake", Unicode: []int32{127874}, ShortNames: []string{"birthday"}},
			Emoji{Name: "shortcake", Unicode: []int32{127856}, ShortNames: []string{"cake"}},
			Emoji{Name: "cupcake", Unicode: []int32{129473}, ShortNames: []string{"cupcake"}},
			Emoji{Name: "pie", Unicode: []int32{129383}, ShortNames: []string{"pie"}},
			Emoji{Name: "chocolate bar", Unicode: []int32{127851}, ShortNames: []string{"chocolate_bar"}},
			Emoji{Name: "candy", Unicode: []int32{127852}, ShortNames: []string{"candy"}},
			Emoji{Name: "lollipop", Unicode: []int32{127853}, ShortNames: []string{"lollipop"}},
			Emoji{Name: "custard", Unicode: []int32{127854}, ShortNames: []string{"custard"}},
			Emoji{Name: "honey pot", Unicode: []int32{127855}, ShortNames: []string{"honey_pot"}},
			Emoji{Name: "baby bottle", Unicode: []int32{127868}, ShortNames: []string{"baby_bottle"}},
			Emoji{Name: "glass of milk", Unicode: []int32{129371}, ShortNames: []string{"milk_glass"}},
			Emoji{Name: "hot beverage", Unicode: []int32{9749}, ShortNames: []string{"coffee"}},
			Emoji{Name: "teapot", Unicode: []int32{129750}, ShortNames: []string{"teapot"}},
			Emoji{Name: "teacup without handle", Unicode: []int32{127861}, ShortNames: []string{"tea"}},
			Emoji{Name: "sake", Unicode: []int32{127862}, ShortNames: []string{"sake"}},
			Emoji{Name: "bottle with popping cork", Unicode: []int32{127870}, ShortNames: []string{"champagne"}},
			Emoji{Name: "wine glass", Unicode: []int32{127863}, ShortNames: []string{"wine_glass"}},
			Emoji{Name: "cocktail glass", Unicode: []int32{127864}, ShortNames: []string{"cocktail"}},
			Emoji{Name: "tropical drink", Unicode: []int32{127865}, ShortNames: []string{"tropical_drink"}},
			Emoji{Name: "beer mug", Unicode: []int32{127866}, ShortNames: []string{"beer"}},
			Emoji{Name: "clinking beer mugs", Unicode: []int32{127867}, ShortNames: []string{"beers"}},
			Emoji{Name: "clinking glasses", Unicode: []int32{129346}, ShortNames: []string{"clinking_glasses"}},
			Emoji{Name: "tumbler glass", Unicode: []int32{129347}, ShortNames: []string{"tumbler_glass"}},
			Emoji{Name: "pouring liquid", Unicode: []int32{129751}, ShortNames: []string{"pouring_liquid"}},
			Emoji{Name: "cup with straw", Unicode: []int32{129380}, ShortNames: []string{"cup_with_straw"}},
			Emoji{Name: "bubble tea", Unicode: []int32{129483}, ShortNames: []string{"bubble_tea"}},
			Emoji{Name: "beverage box", Unicode: []int32{129475}, ShortNames: []string{"beverage_box"}},
			Emoji{Name: "mate", Unicode: []int32{129481}, ShortNames: []string{"mate"}},
			Emoji{Name: "ice", Unicode: []int32{129482}, ShortNames: []string{"ice_cube"}},
			Emoji{Name: "chopsticks", Unicode: []int32{129378}, ShortNames: []string{"chopsticks"}},
			Emoji{Name: "fork and knife with plate", Unicode: []int32{127869, 65039}, ShortNames: []string{"plate_with_cutlery"}},
			Emoji{Name: "fork and knife", Unicode: []int32{127860}, ShortNames: []string{"fork_and_knife"}},
			Emoji{Name: "spoon", Unicode: []int32{129348}, ShortNames: []string{"spoon"}},
			Emoji{Name: "kitchen knife", Unicode: []int32{128298}, ShortNames: []string{"hocho", "knife"}},
			Emoji{Name: "jar", Unicode: []int32{129753}, ShortNames: []string{"jar"}},
			Emoji{Name: "amphora", Unicode: []int32{127994}, ShortNames: []string{"amphora"}},
			Emoji{Name: "globe showing Europe-Africa", Unicode: []int32{127757}, ShortNames: []string{"earth_africa"}},
			Emoji{Name: "globe showing Americas", Unicode: []int32{127758}, ShortNames: []string{"earth_americas"}},
			Emoji{Name: "globe showing Asia-Australia", Unicode: []int32{127759}, ShortNames: []string{"earth_asia"}},
			Emoji{Name: "globe with meridians", Unicode: []int32{127760}, ShortNames: []string{"globe_with_meridians"}},
			Emoji{Name: "world map", Unicode: []int32{128506, 65039}, ShortNames: []string{"world_map"}},
			Emoji{Name: "map of Japan", Unicode: []int32{128510}, ShortNames: []string{"japan"}},
			Emoji{Name: "compass", Unicode: []int32{129517}, ShortNames: []string{"compass"}},
			Emoji{Name: "snow-capped mountain", Unicode: []int32{127956, 65039}, ShortNames: []string{"mountain_snow"}},
			Emoji{Name: "mountain", Unicode: []int32{9968, 65039}, ShortNames: []string{"mountain"}},
			Emoji{Name: "volcano", Unicode: []int32{127755}, ShortNames: []string{"volcano"}},
			Emoji{Name: "mount fuji", Unicode: []int32{128507}, ShortNames: []string{"mount_fuji"}},
			Emoji{Name: "camping", Unicode: []int32{127957, 65039}, ShortNames: []string{"camping"}},
			Emoji{Name: "beach with umbrella", Unicode: []int32{127958, 65039}, ShortNames: []string{"beach_umbrella"}},
			Emoji{Name: "desert", Unicode: []int32{127964, 65039}, ShortNames: []string{"desert"}},
			Emoji{Name: "desert island", Unicode: []int32{127965, 65039}, ShortNames: []string{"desert_island"}},
			Emoji{Name: "national park", Unicode: []int32{127966, 65039}, ShortNames: []string{"national_park"}},
			Emoji{Name: "stadium", Unicode: []int32{127967, 65039}, ShortNames: []string{"stadium"}},
			Emoji{Name: "classical building", Unicode: []int32{127963, 65039}, ShortNames: []string{"classical_building"}},
			Emoji{Name: "building construction", Unicode: []int32{127959, 65039}, ShortNames: []string{"building_construction"}},
			Emoji{Name: "brick", Unicode: []int32{129521}, ShortNames: []string{"bricks"}},
			Emoji{Name: "rock", Unicode: []int32{129704}, ShortNames: []string{"rock"}},
			Emoji{Name: "wood", Unicode: []int32{129717}, ShortNames: []string{"wood"}},
			Emoji{Name: "hut", Unicode: []int32{128726}, ShortNames: []string{"hut"}},
			Emoji{Name: "houses", Unicode: []int32{127960, 65039}, ShortNames: []string{"houses"}},
			Emoji{Name: "derelict house", Unicode: []int32{127962, 65039}, ShortNames: []string{"derelict_house"}},
			Emoji{Name: "house", Unicode: []int32{127968}, ShortNames: []string{"house"}},
			Emoji{Name: "house with garden", Unicode: []int32{127969}, ShortNames: []string{"house_with_garden"}},
			Emoji{Name: "office building", Unicode: []int32{127970}, ShortNames: []string{"office"}},
			Emoji{Name: "Japanese post office", Unicode: []int32{127971}, ShortNames: []string{"post_office"}},
			Emoji{Name: "post office", Unicode: []int32{127972}, ShortNames: []string{"european_post_office"}},
			Emoji{Name: "hospital", Unicode: []int32{127973}, ShortNames: []string{"hospital"}},
			Emoji{Name: "bank", Unicode: []int32{127974}, ShortNames: []string{"bank"}},
			Emoji{Name: "hotel", Unicode: []int32{127976}, ShortNames: []string{"hotel"}},
			Emoji{Name: "love hotel", Unicode: []int32{127977}, ShortNames: []string{"love_hotel"}},
			Emoji{Name: "convenience store", Unicode: []int32{127978}, ShortNames: []string{"convenience_store"}},
			Emoji{Name: "school", Unicode: []int32{127979}, ShortNames: []string{"school"}},
			Emoji{Name: "department store", Unicode: []int32{127980}, ShortNames: []string{"department_store"}},
			Emoji{Name: "factory", Unicode: []int32{127981}, ShortNames: []string{"factory"}},
			Emoji{Name: "Japanese castle", Unicode: []int32{127983}, ShortNames: []string{"japanese_castle"}},
			Emoji{Name: "castle", Unicode: []int32{127984}, ShortNames: []string{"european_castle"}},
			Emoji{Name: "wedding", Unicode: []int32{128146}, ShortNames: []string{"wedding"}},
			Emoji{Name: "Tokyo tower", Unicode: []int32{128508}, ShortNames: []string{"tokyo_tower"}},
			Emoji{Name: "Statue of Liberty", Unicode: []int32{128509}, ShortNames: []string{"statue_of_liberty"}},
			Emoji{Name: "church", Unicode: []int32{9962}, ShortNames: []string{"church"}},
			Emoji{Name: "mosque", Unicode: []int32{128332}, ShortNames: []string{"mosque"}},
			Emoji{Name: "hindu temple", Unicode: []int32{128725}, ShortNames: []string{"hindu_temple"}},
			Emoji{Name: "synagogue", Unicode: []int32{128333}, ShortNames: []string{"synagogue"}},
			Emoji{Name: "shinto shrine", Unicode: []int32{9961, 65039}, ShortNames: []string{"shinto_shrine"}},
			Emoji{Name: "kaaba", Unicode: []int32{128331}, ShortNames: []string{"kaaba"}},
			Emoji{Name: "fountain", Unicode: []int32{9970}, ShortNames: []string{"fountain"}},
			Emoji{Name: "tent", Unicode: []int32{9978}, ShortNames: []string{"tent"}},
			Emoji{Name: "foggy", Unicode: []int32{127745}, ShortNames: []string{"foggy"}},
			Emoji{Name: "night with stars", Unicode: []int32{127747}, ShortNames: []string{"night_with_stars"}},
			Emoji{Name: "cityscape", Unicode: []int32{127961, 65039}, ShortNames: []string{"cityscape"}},
			Emoji{Name: "sunrise over mountains", Unicode: []int32{127748}, ShortNames: []string{"sunrise_over_mountains"}},
			Emoji{Name: "sunrise", Unicode: []int32{127749}, ShortNames: []string{"sunrise"}},
			Emoji{Name: "cityscape at dusk", Unicode: []int32{127750}, ShortNames: []string{"city_sunset"}},
			Emoji{Name: "sunset", Unicode: []int32{127751}, ShortNames: []string{"city_sunrise"}},
			Emoji{Name: "bridge at night", Unicode: []int32{127753}, ShortNames: []string{"bridge_at_night"}},
			Emoji{Name: "hot springs", Unicode: []int32{9832, 65039}, ShortNames: []string{"hotsprings"}},
			Emoji{Name: "carousel horse", Unicode: []int32{127904}, ShortNames: []string{"carousel_horse"}},
			Emoji{Name: "playground slide", Unicode: []int32{128733}, ShortNames: []string{"playground_slide"}},
			Emoji{Name: "ferris wheel", Unicode: []int32{127905}, ShortNames: []string{"ferris_wheel"}},
			Emoji{Name: "roller coaster", Unicode: []int32{127906}, ShortNames: []string{"roller_coaster"}},
			Emoji{Name: "barber pole", Unicode: []int32{128136}, ShortNames: []string{"barber"}},
			Emoji{Name: "circus tent", Unicode: []int32{127914}, ShortNames: []string{"circus_tent"}},
			Emoji{Name: "locomotive", Unicode: []int32{128642}, ShortNames: []string{"steam_locomotive"}},
			Emoji{Name: "railway car", Unicode: []int32{128643}, ShortNames: []string{"railway_car"}},
			Emoji{Name: "high-speed train", Unicode: []int32{128644}, ShortNames: []string{"bullettrain_side"}},
			Emoji{Name: "bullet train", Unicode: []int32{128645}, ShortNames: []string{"bullettrain_front"}},
			Emoji{Name: "train", Unicode: []int32{128646}, ShortNames: []string{"train2"}},
			Emoji{Name: "metro", Unicode: []int32{128647}, ShortNames: []string{"metro"}},
			Emoji{Name: "light rail", Unicode: []int32{128648}, ShortNames: []string{"light_rail"}},
			Emoji{Name: "station", Unicode: []int32{128649}, ShortNames: []string{"station"}},
			Emoji{Name: "tram", Unicode: []int32{128650}, ShortNames: []string{"tram"}},
			Emoji{Name: "monorail", Unicode: []int32{128669}, ShortNames: []string{"monorail"}},
			Emoji{Name: "mountain railway", Unicode: []int32{128670}, ShortNames: []string{"mountain_railway"}},
			Emoji{Name: "tram car", Unicode: []int32{128651}, ShortNames: []string{"train"}},
			Emoji{Name: "bus", Unicode: []int32{128652}, ShortNames: []string{"bus"}},
			Emoji{Name: "oncoming bus", Unicode: []int32{128653}, ShortNames: []string{"oncoming_bus"}},
			Emoji{Name: "trolleybus", Unicode: []int32{128654}, ShortNames: []string{"trolleybus"}},
			Emoji{Name: "minibus", Unicode: []int32{128656}, ShortNames: []string{"minibus"}},
			Emoji{Name: "ambulance", Unicode: []int32{128657}, ShortNames: []string{"ambulance"}},
			Emoji{Name: "fire engine", Unicode: []int32{128658}, ShortNames: []string{"fire_engine"}},
			Emoji{Name: "police car", Unicode: []int32{128659}, ShortNames: []string{"police_car"}},
			Emoji{Name: "oncoming police car", Unicode: []int32{128660}, ShortNames: []string{"oncoming_police_car"}},
			Emoji{Name: "taxi", Unicode: []int32{128661}, ShortNames: []string{"taxi"}},
			Emoji{Name: "oncoming taxi", Unicode: []int32{128662}, ShortNames: []string{"oncoming_taxi"}},
			Emoji{Name: "automobile", Unicode: []int32{128663}, ShortNames: []string{"car", "red_car"}},
			Emoji{Name: "oncoming automobile", Unicode: []int32{128664}, ShortNames: []string{"oncoming_automobile"}},
			Emoji{Name: "sport utility vehicle", Unicode: []int32{128665}, ShortNames: []string{"blue_car"}},
			Emoji{Name: "pickup truck", Unicode: []int32{128763}, ShortNames: []string{"pickup_truck"}},
			Emoji{Name: "delivery truck", Unicode: []int32{128666}, ShortNames: []string{"truck"}},
			Emoji{Name: "articulated lorry", Unicode: []int32{128667}, ShortNames: []string{"articulated_lorry"}},
			Emoji{Name: "tractor", Unicode: []int32{128668}, ShortNames: []string{"tractor"}},
			Emoji{Name: "racing car", Unicode: []int32{127950, 65039}, ShortNames: []string{"racing_car"}},
			Emoji{Name: "motorcycle", Unicode: []int32{127949, 65039}, ShortNames: []string{"motorcycle"}},
			Emoji{Name: "motor scooter", Unicode: []int32{128757}, ShortNames: []string{"motor_scooter"}},
			Emoji{Name: "manual wheelchair", Unicode: []int32{129469}, ShortNames: []string{"manual_wheelchair"}},
			Emoji{Name: "motorized wheelchair", Unicode: []int32{129468}, ShortNames: []string{"motorized_wheelchair"}},
			Emoji{Name: "auto rickshaw", Unicode: []int32{128762}, ShortNames: []string{"auto_rickshaw"}},
			Emoji{Name: "bicycle", Unicode: []int32{128690}, ShortNames: []string{"bike"}},
			Emoji{Name: "kick scooter", Unicode: []int32{128756}, ShortNames: []string{"kick_scooter"}},
			Emoji{Name: "skateboard", Unicode: []int32{128761}, ShortNames: []string{"skateboard"}},
			Emoji{Name: "roller skate", Unicode: []int32{128764}, ShortNames: []string{"roller_skate"}},
			Emoji{Name: "bus stop", Unicode: []int32{128655}, ShortNames: []string{"busstop"}},
			Emoji{Name: "motorway", Unicode: []int32{128739, 65039}, ShortNames: []string{"motorway"}},
			Emoji{Name: "railway track", Unicode: []int32{128740, 65039}, ShortNames: []string{"railway_track"}},
			Emoji{Name: "oil drum", Unicode: []int32{128738, 65039}, ShortNames: []string{"oil_drum"}},
			Emoji{Name: "fuel pump", Unicode: []int32{9981}, ShortNames: []string{"fuelpump"}},
			Emoji{Name: "wheel", Unicode: []int32{128734}, ShortNames: []string{"wheel"}},
			Emoji{Name: "police car light", Unicode: []int32{128680}, ShortNames: []string{"rotating_light"}},
			Emoji{Name: "horizontal traffic light", Unicode: []int32{128677}, ShortNames: []string{"traffic_light"}},
			Emoji{Name: "vertical traffic light", Unicode: []int32{128678}, ShortNames: []string{"vertical_traffic_light"}},
			Emoji{Name: "stop sign", Unicode: []int32{128721}, ShortNames: []string{"stop_sign"}},
			Emoji{Name: "construction", Unicode: []int32{128679}, ShortNames: []string{"construction"}},
			Emoji{Name: "anchor", Unicode: []int32{9875}, ShortNames: []string{"anchor"}},
			Emoji{Name: "ring buoy", Unicode: []int32{128735}, ShortNames: []string{"ring_buoy"}},
			Emoji{Name: "sailboat", Unicode: []int32{9973}, ShortNames: []string{"boat", "sailboat"}},
			Emoji{Name: "canoe", Unicode: []int32{128758}, ShortNames: []string{"canoe"}},
			Emoji{Name: "speedboat", Unicode: []int32{128676}, ShortNames: []string{"speedboat"}},
			Emoji{Name: "passenger ship", Unicode: []int32{128755, 65039}, ShortNames: []string{"passenger_ship"}},
			Emoji{Name: "ferry", Unicode: []int32{9972, 65039}, ShortNames: []string{"ferry"}},
			Emoji{Name: "motor boat", Unicode: []int32{128741, 65039}, ShortNames: []string{"motor_boat"}},
			Emoji{Name: "ship", Unicode: []int32{128674}, ShortNames: []string{"ship"}},
			Emoji{Name: "airplane", Unicode: []int32{9992, 65039}, ShortNames: []string{"airplane"}},
			Emoji{Name: "small airplane", Unicode: []int32{128745, 65039}, ShortNames: []string{"small_airplane"}},
			Emoji{Name: "airplane departure", Unicode: []int32{128747}, ShortNames: []string{"flight_departure"}},
			Emoji{Name: "airplane arrival", Unicode: []int32{128748}, ShortNames: []string{"flight_arrival"}},
			Emoji{Name: "parachute", Unicode: []int32{129666}, ShortNames: []string{"parachute"}},
			Emoji{Name: "seat", Unicode: []int32{128186}, ShortNames: []string{"seat"}},
			Emoji{Name: "helicopter", Unicode: []int32{128641}, ShortNames: []string{"helicopter"}},
			Emoji{Name: "suspension railway", Unicode: []int32{128671}, ShortNames: []string{"suspension_railway"}},
			Emoji{Name: "mountain cableway", Unicode: []int32{128672}, ShortNames: []string{"mountain_cableway"}},
			Emoji{Name: "aerial tramway", Unicode: []int32{128673}, ShortNames: []string{"aerial_tramway"}},
			Emoji{Name: "satellite", Unicode: []int32{128752, 65039}, ShortNames: []string{"artificial_satellite"}},
			Emoji{Name: "rocket", Unicode: []int32{128640}, ShortNames: []string{"rocket"}},
			Emoji{Name: "flying saucer", Unicode: []int32{128760}, ShortNames: []string{"flying_saucer"}},
			Emoji{Name: "bellhop bell", Unicode: []int32{128718, 65039}, ShortNames: []string{"bellhop_bell"}},
			Emoji{Name: "luggage", Unicode: []int32{129523}, ShortNames: []string{"luggage"}},
			Emoji{Name: "hourglass done", Unicode: []int32{8987}, ShortNames: []string{"hourglass"}},
			Emoji{Name: "hourglass not done", Unicode: []int32{9203}, ShortNames: []string{"hourglass_flowing_sand"}},
			Emoji{Name: "watch", Unicode: []int32{8986}, ShortNames: []string{"watch"}},
			Emoji{Name: "alarm clock", Unicode: []int32{9200}, ShortNames: []string{"alarm_clock"}},
			Emoji{Name: "stopwatch", Unicode: []int32{9201, 65039}, ShortNames: []string{"stopwatch"}},
			Emoji{Name: "timer clock", Unicode: []int32{9202, 65039}, ShortNames: []string{"timer_clock"}},
			Emoji{Name: "mantelpiece clock", Unicode: []int32{128368, 65039}, ShortNames: []string{"mantelpiece_clock"}},
			Emoji{Name: "twelve o’clock", Unicode: []int32{128347}, ShortNames: []string{"clock12"}},
			Emoji{Name: "twelve-thirty", Unicode: []int32{128359}, ShortNames: []string{"clock1230"}},
			Emoji{Name: "one o’clock", Unicode: []int32{128336}, ShortNames: []string{"clock1"}},
			Emoji{Name: "one-thirty", Unicode: []int32{128348}, ShortNames: []string{"clock130"}},
			Emoji{Name: "two o’clock", Unicode: []int32{128337}, ShortNames: []string{"clock2"}},
			Emoji{Name: "two-thirty", Unicode: []int32{128349}, ShortNames: []string{"clock230"}},
			Emoji{Name: "three o’clock", Unicode: []int32{128338}, ShortNames: []string{"clock3"}},
			Emoji{Name: "three-thirty", Unicode: []int32{128350}, ShortNames: []string{"clock330"}},
			Emoji{Name: "four o’clock", Unicode: []int32{128339}, ShortNames: []string{"clock4"}},
			Emoji{Name: "four-thirty", Unicode: []int32{128351}, ShortNames: []string{"clock430"}},
			Emoji{Name: "five o’clock", Unicode: []int32{128340}, ShortNames: []string{"clock5"}},
			Emoji{Name: "five-thirty", Unicode: []int32{128352}, ShortNames: []string{"clock530"}},
			Emoji{Name: "six o’clock", Unicode: []int32{128341}, ShortNames: []string{"clock6"}},
			Emoji{Name: "six-thirty", Unicode: []int32{128353}, ShortNames: []string{"clock630"}},
			Emoji{Name: "seven o’clock", Unicode: []int32{128342}, ShortNames: []string{"clock7"}},
			Emoji{Name: "seven-thirty", Unicode: []int32{128354}, ShortNames: []string{"clock730"}},
			Emoji{Name: "eight o’clock", Unicode: []int32{128343}, ShortNames: []string{"clock8"}},
			Emoji{Name: "eight-thirty", Unicode: []int32{128355}, ShortNames: []string{"clock830"}},
			Emoji{Name: "nine o’clock", Unicode: []int32{128344}, ShortNames: []string{"clock9"}},
			Emoji{Name: "nine-thirty", Unicode: []int32{128356}, ShortNames: []string{"clock930"}},
			Emoji{Name: "ten o’clock", Unicode: []int32{128345}, ShortNames: []string{"clock10"}},
			Emoji{Name: "ten-thirty", Unicode: []int32{128357}, ShortNames: []string{"clock1030"}},
			Emoji{Name: "eleven o’clock", Unicode: []int32{128346}, ShortNames: []string{"clock11"}},
			Emoji{Name: "eleven-thirty", Unicode: []int32{128358}, ShortNames: []string{"clock1130"}},
			Emoji{Name: "new moon", Unicode: []int32{127761}, ShortNames: []string{"new_moon"}},
			Emoji{Name: "waxing crescent moon", Unicode: []int32{127762}, ShortNames: []string{"waxing_crescent_moon"}},
			Emoji{Name: "first quarter moon", Unicode: []int32{127763}, ShortNames: []string{"first_quarter_moon"}},
			Emoji{Name: "waxing gibbous moon", Unicode: []int32{127764}, ShortNames: []string{"moon", "waxing_gibbous_moon"}},
			Emoji{Name: "full moon", Unicode: []int32{127765}, ShortNames: []string{"full_moon"}},
			Emoji{Name: "waning gibbous moon", Unicode: []int32{127766}, ShortNames: []string{"waning_gibbous_moon"}},
			Emoji{Name: "last quarter moon", Unicode: []int32{127767}, ShortNames: []string{"last_quarter_moon"}},
			Emoji{Name: "waning crescent moon", Unicode: []int32{127768}, ShortNames: []string{"waning_crescent_moon"}},
			Emoji{Name: "crescent moon", Unicode: []int32{127769}, ShortNames: []string{"crescent_moon"}},
			Emoji{Name: "new moon face", Unicode: []int32{127770}, ShortNames: []string{"new_moon_with_face"}},
			Emoji{Name: "first quarter moon face", Unicode: []int32{127771}, ShortNames: []string{"first_quarter_moon_with_face"}},
			Emoji{Name: "last quarter moon face", Unicode: []int32{127772}, ShortNames: []string{"last_quarter_moon_with_face"}},
			Emoji{Name: "thermometer", Unicode: []int32{127777, 65039}, ShortNames: []string{"thermometer"}},
			Emoji{Name: "sun", Unicode: []int32{9728, 65039}, ShortNames: []string{"sunny"}},
			Emoji{Name: "full moon face", Unicode: []int32{127773}, ShortNames: []string{"full_moon_with_face"}},
			Emoji{Name: "sun with face", Unicode: []int32{127774}, ShortNames: []string{"sun_with_face"}},
			Emoji{Name: "ringed planet", Unicode: []int32{129680}, ShortNames: []string{"ringed_planet"}},
			Emoji{Name: "star", Unicode: []int32{11088}, ShortNames: []string{"star"}},
			Emoji{Name: "glowing star", Unicode: []int32{127775}, ShortNames: []string{"star2"}},
			Emoji{Name: "shooting star", Unicode: []int32{127776}, ShortNames: []string{"stars"}},
			Emoji{Name: "milky way", Unicode: []int32{127756}, ShortNames: []string{"milky_way"}},
			Emoji{Name: "cloud", Unicode: []int32{9729, 65039}, ShortNames: []string{"cloud"}},
			Emoji{Name: "sun behind cloud", Unicode: []int32{9925}, ShortNames: []string{"partly_sunny"}},
			Emoji{Name: "cloud with lightning and rain", Unicode: []int32{9928, 65039}, ShortNames: []string{"cloud_with_lightning_and_rain"}},
			Emoji{Name: "sun behind small cloud", Unicode: []int32{127780, 65039}, ShortNames: []string{"sun_behind_small_cloud"}},
			Emoji{Name: "sun behind large cloud", Unicode: []int32{127781, 65039}, ShortNames: []string{"sun_behind_large_cloud"}},
			Emoji{Name: "sun behind rain cloud", Unicode: []int32{127782, 65039}, ShortNames: []string{"sun_behind_rain_cloud"}},
			Emoji{Name: "cloud with rain", Unicode: []int32{127783, 65039}, ShortNames: []string{"cloud_with_rain"}},
			Emoji{Name: "cloud with snow", Unicode: []int32{127784, 65039}, ShortNames: []string{"cloud_with_snow"}},
			Emoji{Name: "cloud with lightning", Unicode: []int32{127785, 65039}, ShortNames: []string{"cloud_with_lightning"}},
			Emoji{Name: "tornado", Unicode: []int32{127786, 65039}, ShortNames: []string{"tornado"}},
			Emoji{Name: "fog", Unicode: []int32{127787, 65039}, ShortNames: []string{"fog"}},
			Emoji{Name: "wind face", Unicode: []int32{127788, 65039}, ShortNames: []string{"wind_face"}},
			Emoji{Name: "cyclone", Unicode: []int32{127744}, ShortNames: []string{"cyclone"}},
			Emoji{Name: "rainbow", Unicode: []int32{127752}, ShortNames: []string{"rainbow"}},
			Emoji{Name: "closed umbrella", Unicode: []int32{127746}, ShortNames: []string{"closed_umbrella"}},
			Emoji{Name: "umbrella", Unicode: []int32{9730, 65039}, ShortNames: []string{"open_umbrella"}},
			Emoji{Name: "umbrella with rain drops", Unicode: []int32{9748}, ShortNames: []string{"umbrella"}},
			Emoji{Name: "umbrella on ground", Unicode: []int32{9969, 65039}, ShortNames: []string{"parasol_on_ground"}},
			Emoji{Name: "high voltage", Unicode: []int32{9889}, ShortNames: []string{"zap"}},
			Emoji{Name: "snowflake", Unicode: []int32{10052, 65039}, ShortNames: []string{"snowflake"}},
			Emoji{Name: "snowman", Unicode: []int32{9731, 65039}, ShortNames: []string{"snowman_with_snow"}},
			Emoji{Name: "snowman without snow", Unicode: []int32{9924}, ShortNames: []string{"snowman"}},
			Emoji{Name: "comet", Unicode: []int32{9732, 65039}, ShortNames: []string{"comet"}},
			Emoji{Name: "fire", Unicode: []int32{128293}, ShortNames: []string{"fire"}},
			Emoji{Name: "droplet", Unicode: []int32{128167}, ShortNames: []string{"droplet"}},
			Emoji{Name: "water wave", Unicode: []int32{127754}, ShortNames: []string{"ocean"}},
			Emoji{Name: "jack-o-lantern", Unicode: []int32{127875}, ShortNames: []string{"jack_o_lantern"}},
			Emoji{Name: "Christmas tree", Unicode: []int32{127876}, ShortNames: []string{"christmas_tree"}},
			Emoji{Name: "fireworks", Unicode: []int32{127878}, ShortNames: []string{"fireworks"}},
			Emoji{Name: "sparkler", Unicode: []int32{127879}, ShortNames: []string{"sparkler"}},
			Emoji{Name: "firecracker", Unicode: []int32{129512}, ShortNames: []string{"firecracker"}},
			Emoji{Name: "sparkles", Unicode: []int32{10024}, ShortNames: []string{"sparkles"}},
			Emoji{Name: "balloon", Unicode: []int32{127880}, ShortNames: []string{"balloon"}},
			Emoji{Name: "party popper", Unicode: []int32{127881}, ShortNames: []string{"tada"}},
			Emoji{Name: "confetti ball", Unicode: []int32{127882}, ShortNames: []string{"confetti_ball"}},
			Emoji{Name: "tanabata tree", Unicode: []int32{127883}, ShortNames: []string{"tanabata_tree"}},
			Emoji{Name: "pine decoration", Unicode: []int32{127885}, ShortNames: []string{"bamboo"}},
			Emoji{Name: "Japanese dolls", Unicode: []int32{127886}, ShortNames: []string{"dolls"}},
			Emoji{Name: "carp streamer", Unicode: []int32{127887}, ShortNames: []string{"flags"}},
			Emoji{Name: "wind chime", Unicode: []int32{127888}, ShortNames: []string{"wind_chime"}},
			Emoji{Name: "moon viewing ceremony", Unicode: []int32{127889}, ShortNames: []string{"rice_scene"}},
			Emoji{Name: "red envelope", Unicode: []int32{129511}, ShortNames: []string{"red_envelope"}},
			Emoji{Name: "ribbon", Unicode: []int32{127872}, ShortNames: []string{"ribbon"}},
			Emoji{Name: "wrapped gift", Unicode: []int32{127873}, ShortNames: []string{"gift"}},
			Emoji{Name: "reminder ribbon", Unicode: []int32{127895, 65039}, ShortNames: []string{"reminder_ribbon"}},
			Emoji{Name: "admission tickets", Unicode: []int32{127903, 65039}, ShortNames: []string{"tickets"}},
			Emoji{Name: "ticket", Unicode: []int32{127915}, ShortNames: []string{"ticket"}},
			Emoji{Name: "military medal", Unicode: []int32{127894, 65039}, ShortNames: []string{"medal_military"}},
			Emoji{Name: "trophy", Unicode: []int32{127942}, ShortNames: []string{"trophy"}},
			Emoji{Name: "sports medal", Unicode: []int32{127941}, ShortNames: []string{"medal_sports"}},
			Emoji{Name: "1st place medal", Unicode: []int32{129351}, ShortNames: []string{"1st_place_medal"}},
			Emoji{Name: "2nd place medal", Unicode: []int32{129352}, ShortNames: []string{"2nd_place_medal"}},
			Emoji{Name: "3rd place medal", Unicode: []int32{129353}, ShortNames: []string{"3rd_place_medal"}},
			Emoji{Name: "soccer ball", Unicode: []int32{9917}, ShortNames: []string{"soccer"}},
			Emoji{Name: "baseball", Unicode: []int32{9918}, ShortNames: []string{"baseball"}},
			Emoji{Name: "softball", Unicode: []int32{129358}, ShortNames: []string{"softball"}},
			Emoji{Name: "basketball", Unicode: []int32{127936}, ShortNames: []string{"basketball"}},
			Emoji{Name: "volleyball", Unicode: []int32{127952}, ShortNames: []string{"volleyball"}},
			Emoji{Name: "american football", Unicode: []int32{127944}, ShortNames: []string{"football"}},
			Emoji{Name: "rugby football", Unicode: []int32{127945}, ShortNames: []string{"rugby_football"}},
			Emoji{Name: "tennis", Unicode: []int32{127934}, ShortNames: []string{"tennis"}},
			Emoji{Name: "flying disc", Unicode: []int32{129359}, ShortNames: []string{"flying_disc"}},
			Emoji{Name: "bowling", Unicode: []int32{127923}, ShortNames: []string{"bowling"}},
			Emoji{Name: "cricket game", Unicode: []int32{127951}, ShortNames: []string{"cricket_game"}},
			Emoji{Name: "field hockey", Unicode: []int32{127953}, ShortNames: []string{"field_hockey"}},
			Emoji{Name: "ice hockey", Unicode: []int32{127954}, ShortNames: []string{"ice_hockey"}},
			Emoji{Name: "lacrosse", Unicode: []int32{129357}, ShortNames: []string{"lacrosse"}},
			Emoji{Name: "ping pong", Unicode: []int32{127955}, ShortNames: []string{"ping_pong"}},
			Emoji{Name: "badminton", Unicode: []int32{127992}, ShortNames: []string{"badminton"}},
			Emoji{Name: "boxing glove", Unicode: []int32{129354}, ShortNames: []string{"boxing_glove"}},
			Emoji{Name: "martial arts uniform", Unicode: []int32{129355}, ShortNames: []string{"martial_arts_uniform"}},
			Emoji{Name: "goal net", Unicode: []int32{129349}, ShortNames: []string{"goal_net"}},
			Emoji{Name: "flag in hole", Unicode: []int32{9971}, ShortNames: []string{"golf"}},
			Emoji{Name: "ice skate", Unicode: []int32{9976, 65039}, ShortNames: []string{"ice_skate"}},
			Emoji{Name: "fishing pole", Unicode: []int32{127907}, ShortNames: []string{"fishing_pole_and_fish"}},
			Emoji{Name: "diving mask", Unicode: []int32{129343}, ShortNames: []string{"diving_mask"}},
			Emoji{Name: "running shirt", Unicode: []int32{127933}, ShortNames: []string{"running_shirt_with_sash"}},
			Emoji{Name: "skis", Unicode: []int32{127935}, ShortNames: []string{"ski"}},
			Emoji{Name: "sled", Unicode: []int32{128759}, ShortNames: []string{"sled"}},
			Emoji{Name: "curling stone", Unicode: []int32{129356}, ShortNames: []string{"curling_stone"}},
			Emoji{Name: "bullseye", Unicode: []int32{127919}, ShortNames: []string{"dart"}},
			Emoji{Name: "yo-yo", Unicode: []int32{129664}, ShortNames: []string{"yo_yo"}},
			Emoji{Name: "kite", Unicode: []int32{129665}, ShortNames: []string{"kite"}},
			Emoji{Name: "water pistol", Unicode: []int32{128299}, ShortNames: []string{"gun"}},
			Emoji{Name: "pool 8 ball", Unicode: []int32{127921}, ShortNames: []string{"8ball"}},
			Emoji{Name: "crystal ball", Unicode: []int32{128302}, ShortNames: []string{"crystal_ball"}},
			Emoji{Name: "magic wand", Unicode: []int32{129668}, ShortNames: []string{"magic_wand"}},
			Emoji{Name: "video game", Unicode: []int32{127918}, ShortNames: []string{"video_game"}},
			Emoji{Name: "joystick", Unicode: []int32{128377, 65039}, ShortNames: []string{"joystick"}},
			Emoji{Name: "slot machine", Unicode: []int32{127920}, ShortNames: []string{"slot_machine"}},
			Emoji{Name: "game die", Unicode: []int32{127922}, ShortNames: []string{"game_die"}},
			Emoji{Name: "puzzle piece", Unicode: []int32{129513}, ShortNames: []string{"jigsaw"}},
			Emoji{Name: "teddy bear", Unicode: []int32{129528}, ShortNames: []string{"teddy_bear"}},
			Emoji{Name: "piñata", Unicode: []int32{129669}, ShortNames: []string{"pinata"}},
			Emoji{Name: "mirror ball", Unicode: []int32{129705}, ShortNames: []string{"mirror_ball"}},
			Emoji{Name: "nesting dolls", Unicode: []int32{129670}, ShortNames: []string{"nesting_dolls"}},
			Emoji{Name: "spade suit", Unicode: []int32{9824, 65039}, ShortNames: []string{"spades"}},
			Emoji{Name: "heart suit", Unicode: []int32{9829, 65039}, ShortNames: []string{"hearts"}},
			Emoji{Name: "diamond suit", Unicode: []int32{9830, 65039}, ShortNames: []string{"diamonds"}},
			Emoji{Name: "club suit", Unicode: []int32{9827, 65039}, ShortNames: []string{"clubs"}},
			Emoji{Name: "chess pawn", Unicode: []int32{9823, 65039}, ShortNames: []string{"chess_pawn"}},
			Emoji{Name: "joker", Unicode: []int32{127183}, ShortNames: []string{"black_joker"}},
			Emoji{Name: "mahjong red dragon", Unicode: []int32{126980}, ShortNames: []string{"mahjong"}},
			Emoji{Name: "flower playing cards", Unicode: []int32{127924}, ShortNames: []string{"flower_playing_cards"}},
			Emoji{Name: "performing arts", Unicode: []int32{127917}, ShortNames: []string{"performing_arts"}},
			Emoji{Name: "framed picture", Unicode: []int32{128444, 65039}, ShortNames: []string{"framed_picture"}},
			Emoji{Name: "artist palette", Unicode: []int32{127912}, ShortNames: []string{"art"}},
			Emoji{Name: "thread", Unicode: []int32{129525}, ShortNames: []string{"thread"}},
			Emoji{Name: "sewing needle", Unicode: []int32{129697}, ShortNames: []string{"sewing_needle"}},
			Emoji{Name: "yarn", Unicode: []int32{129526}, ShortNames: []string{"yarn"}},
			Emoji{Name: "knot", Unicode: []int32{129698}, ShortNames: []string{"knot"}},
			Emoji{Name: "glasses", Unicode: []int32{128083}, ShortNames: []string{"eyeglasses"}},
			Emoji{Name: "sunglasses", Unicode: []int32{128374, 65039}, ShortNames: []string{"dark_sunglasses"}},
			Emoji{Name: "goggles", Unicode: []int32{129405}, ShortNames: []string{"goggles"}},
			Emoji{Name: "lab coat", Unicode: []int32{129404}, ShortNames: []string{"lab_coat"}},
			Emoji{Name: "safety vest", Unicode: []int32{129466}, ShortNames: []string{"safety_vest"}},
			Emoji{Name: "necktie", Unicode: []int32{128084}, ShortNames: []string{"necktie"}},
			Emoji{Name: "t-shirt", Unicode: []int32{128085}, ShortNames: []string{"shirt", "tshirt"}},
			Emoji{Name: "jeans", Unicode: []int32{128086}, ShortNames: []string{"jeans"}},
			Emoji{Name: "scarf", Unicode: []int32{129507}, ShortNames: []string{"scarf"}},
			Emoji{Name: "gloves", Unicode: []int32{129508}, ShortNames: []string{"gloves"}},
			Emoji{Name: "coat", Unicode: []int32{129509}, ShortNames: []string{"coat"}},
			Emoji{Name: "socks", Unicode: []int32{129510}, ShortNames: []string{"socks"}},
			Emoji{Name: "dress", Unicode: []int32{128087}, ShortNames: []string{"dress"}},
			Emoji{Name: "kimono", Unicode: []int32{128088}, ShortNames: []string{"kimono"}},
			Emoji{Name: "sari", Unicode: []int32{129403}, ShortNames: []string{"sari"}},
			Emoji{Name: "one-piece swimsuit", Unicode: []int32{129649}, ShortNames: []string{"one_piece_swimsuit"}},
			Emoji{Name: "briefs", Unicode: []int32{129650}, ShortNames: []string{"swim_brief"}},
			Emoji{Name: "shorts", Unicode: []int32{129651}, ShortNames: []string{"shorts"}},
			Emoji{Name: "bikini", Unicode: []int32{128089}, ShortNames: []string{"bikini"}},
			Emoji{Name: "woman’s clothes", Unicode: []int32{128090}, ShortNames: []string{"womans_clothes"}},
			Emoji{Name: "folding hand fan", Unicode: []int32{129709}, ShortNames: []string{"folding_hand_fan"}},
			Emoji{Name: "purse", Unicode: []int32{128091}, ShortNames: []string{"purse"}},
			Emoji{Name: "handbag", Unicode: []int32{128092}, ShortNames: []string{"handbag"}},
			Emoji{Name: "clutch bag", Unicode: []int32{128093}, ShortNames: []string{"pouch"}},
			Emoji{Name: "shopping bags", Unicode: []int32{128717, 65039}, ShortNames: []string{"shopping"}},
			Emoji{Name: "backpack", Unicode: []int32{127890}, ShortNames: []string{"school_satchel"}},
			Emoji{Name: "thong sandal", Unicode: []int32{129652}, ShortNames: []string{"thong_sandal"}},
			Emoji{Name: "man’s shoe", Unicode: []int32{128094}, ShortNames: []string{"mans_shoe", "shoe"}},
			Emoji{Name: "running shoe", Unicode: []int32{128095}, ShortNames: []string{"athletic_shoe"}},
			Emoji{Name: "hiking boot", Unicode: []int32{129406}, ShortNames: []string{"hiking_boot"}},
			Emoji{Name: "flat shoe", Unicode: []int32{129407}, ShortNames: []string{"flat_shoe"}},
			Emoji{Name: "high-heeled shoe", Unicode: []int32{128096}, ShortNames: []string{"high_heel"}},
			Emoji{Name: "woman’s sandal", Unicode: []int32{128097}, ShortNames: []string{"sandal"}},
			Emoji{Name: "ballet shoes", Unicode: []int32{129648}, ShortNames: []string{"ballet_shoes"}},
			Emoji{Name: "woman’s boot", Unicode: []int32{128098}, ShortNames: []string{"boot"}},
			Emoji{Name: "hair pick", Unicode: []int32{129710}, ShortNames: []string{"hair_pick"}},
			Emoji{Name: "crown", Unicode: []int32{128081}, ShortNames: []string{"crown"}},
			Emoji{Name: "woman’s hat", Unicode: []int32{128082}, ShortNames: []string{"womans_hat"}},
			Emoji{Name: "top hat", Unicode: []int32{127913}, ShortNames: []string{"tophat"}},
			Emoji{Name: "graduation cap", Unicode: []int32{127891}, ShortNames: []string{"mortar_board"}},
			Emoji{Name: "billed cap", Unicode: []int32{129506}, ShortNames: []string{"billed_cap"}},
			Emoji{Name: "military helmet", Unicode: []int32{129686}, ShortNames: []string{"military_helmet"}},
			Emoji{Name: "rescue worker’s helmet", Unicode: []int32{9937, 65039}, ShortNames: []string{"rescue_worker_helmet"}},
			Emoji{Name: "prayer beads", Unicode: []int32{128255}, ShortNames: []string{"prayer_beads"}},
			Emoji{Name: "lipstick", Unicode: []int32{128132}, ShortNames: []string{"lipstick"}},
			Emoji{Name: "ring", Unicode: []int32{128141}, ShortNames: []string{"ring"}},
			Emoji{Name: "gem stone", Unicode: []int32{128142}, ShortNames: []string{"gem"}},
			Emoji{Name: "muted speaker", Unicode: []int32{128263}, ShortNames: []string{"mute"}},
			Emoji{Name: "speaker low volume", Unicode: []int32{128264}, ShortNames: []string{"speaker"}},
			Emoji{Name: "speaker medium volume", Unicode: []int32{128265}, ShortNames: []string{"sound"}},
			Emoji{Name: "speaker high volume", Unicode: []int32{128266}, ShortNames: []string{"loud_sound"}},
			Emoji{Name: "loudspeaker", Unicode: []int32{128226}, ShortNames: []string{"loudspeaker"}},
			Emoji{Name: "megaphone", Unicode: []int32{128227}, ShortNames: []string{"mega"}},
			Emoji{Name: "postal horn", Unicode: []int32{128239}, ShortNames: []string{"postal_horn"}},
			Emoji{Name: "bell", Unicode: []int32{128276}, ShortNames: []string{"bell"}},
			Emoji{Name: "bell with slash", Unicode: []int32{128277}, ShortNames: []string{"no_bell"}},
			Emoji{Name: "musical score", Unicode: []int32{127932}, ShortNames: []string{"musical_score"}},
			Emoji{Name: "musical note", Unicode: []int32{127925}, ShortNames: []string{"musical_note"}},
			Emoji{Name: "musical notes", Unicode: []int32{127926}, ShortNames: []string{"notes"}},
			Emoji{Name: "studio microphone", Unicode: []int32{127897, 65039}, ShortNames: []string{"studio_microphone"}},
			Emoji{Name: "level slider", Unicode: []int32{127898, 65039}, ShortNames: []string{"level_slider"}},
			Emoji{Name: "control knobs", Unicode: []int32{127899, 65039}, ShortNames: []string{"control_knobs"}},
			Emoji{Name: "microphone", Unicode: []int32{127908}, ShortNames: []string{"microphone"}},
			Emoji{Name: "headphone", Unicode: []int32{127911}, ShortNames: []string{"headphones"}},
			Emoji{Name: "radio", Unicode: []int32{128251}, ShortNames: []string{"radio"}},
			Emoji{Name: "saxophone", Unicode: []int32{127927}, ShortNames: []string{"saxophone"}},
			Emoji{Name: "accordion", Unicode: []int32{129687}, ShortNames: []string{"accordion"}},
			Emoji{Name: "guitar", Unicode: []int32{127928}, ShortNames: []string{"guitar"}},
			Emoji{Name: "musical keyboard", Unicode: []int32{127929}, ShortNames: []string{"musical_keyboard"}},
			Emoji{Name: "trumpet", Unicode: []int32{127930}, ShortNames: []string{"trumpet"}},
			Emoji{Name: "violin", Unicode: []int32{127931}, ShortNames: []string{"violin"}},
			Emoji{Name: "banjo", Unicode: []int32{129685}, ShortNames: []string{"banjo"}},
			Emoji{Name: "drum", Unicode: []int32{129345}, ShortNames: []string{"drum"}},
			Emoji{Name: "long drum", Unicode: []int32{129688}, ShortNames: []string{"long_drum"}},
			Emoji{Name: "maracas", Unicode: []int32{129671}, ShortNames: []string{"maracas"}},
			Emoji{Name: "flute", Unicode: []int32{129672}, ShortNames: []string{"flute"}},
			Emoji{Name: "mobile phone", Unicode: []int32{128241}, ShortNames: []string{"iphone"}},
			Emoji{Name: "mobile phone with arrow", Unicode: []int32{128242}, ShortNames: []string{"calling"}},
			Emoji{Name: "telephone", Unicode: []int32{9742, 65039}, ShortNames: []string{"phone", "telephone"}},
			Emoji{Name: "telephone receiver", Unicode: []int32{128222}, ShortNames: []string{"telephone_receiver"}},
			Emoji{Name: "pager", Unicode: []int32{128223}, ShortNames: []string{"pager"}},
			Emoji{Name: "fax machine", Unicode: []int32{128224}, ShortNames: []string{"fax"}},
			Emoji{Name: "battery", Unicode: []int32{128267}, ShortNames: []string{"battery"}},
			Emoji{Name: "low battery", Unicode: []int32{129707}, ShortNames: []string{"low_battery"}},
			Emoji{Name: "electric plug", Unicode: []int32{128268}, ShortNames: []string{"electric_plug"}},
			Emoji{Name: "laptop", Unicode: []int32{128187}, ShortNames: []string{"computer"}},
			Emoji{Name: "desktop computer", Unicode: []int32{128421, 65039}, ShortNames: []string{"desktop_computer"}},
			Emoji{Name: "printer", Unicode: []int32{128424, 65039}, ShortNames: []string{"printer"}},
			Emoji{Name: "keyboard", Unicode: []int32{9000, 65039}, ShortNames: []string{"keyboard"}},
			Emoji{Name: "computer mouse", Unicode: []int32{128433, 65039}, ShortNames: []string{"computer_mouse"}},
			Emoji{Name: "trackball", Unicode: []int32{128434, 65039}, ShortNames: []string{"trackball"}},
			Emoji{Name: "computer disk", Unicode: []int32{128189}, ShortNames: []string{"minidisc"}},
			Emoji{Name: "floppy disk", Unicode: []int32{128190}, ShortNames: []string{"floppy_disk"}},
			Emoji{Name: "optical disk", Unicode: []int32{128191}, ShortNames: []string{"cd"}},
			Emoji{Name: "dvd", Unicode: []int32{128192}, ShortNames: []string{"dvd"}},
			Emoji{Name: "abacus", Unicode: []int32{129518}, ShortNames: []string{"abacus"}},
			Emoji{Name: "movie camera", Unicode: []int32{127909}, ShortNames: []string{"movie_camera"}},
			Emoji{Name: "film frames", Unicode: []int32{127902, 65039}, ShortNames: []string{"film_strip"}},
			Emoji{Name: "film projector", Unicode: []int32{128253, 65039}, ShortNames: []string{"film_projector"}},
			Emoji{Name: "clapper board", Unicode: []int32{127916}, ShortNames: []string{"clapper"}},
			Emoji{Name: "television", Unicode: []int32{128250}, ShortNames: []string{"tv"}},
			Emoji{Name: "camera", Unicode: []int32{128247}, ShortNames: []string{"camera"}},
			Emoji{Name: "camera with flash", Unicode: []int32{128248}, ShortNames: []string{"camera_flash"}},
			Emoji{Name: "video camera", Unicode: []int32{128249}, ShortNames: []string{"video_camera"}},
			Emoji{Name: "videocassette", Unicode: []int32{128252}, ShortNames: []string{"vhs"}},
			Emoji{Name: "magnifying glass tilted left", Unicode: []int32{128269}, ShortNames: []string{"mag"}},
			Emoji{Name: "magnifying glass tilted right", Unicode: []int32{128270}, ShortNames: []string{"mag_right"}},
			Emoji{Name: "candle", Unicode: []int32{128367, 65039}, ShortNames: []string{"candle"}},
			Emoji{Name: "light bulb", Unicode: []int32{128161}, ShortNames: []string{"bulb"}},
			Emoji{Name: "flashlight", Unicode: []int32{128294}, ShortNames: []string{"flashlight"}},
			Emoji{Name: "red paper lantern", Unicode: []int32{127982}, ShortNames: []string{"izakaya_lantern", "lantern"}},
			Emoji{Name: "diya lamp", Unicode: []int32{129684}, ShortNames: []string{"diya_lamp"}},
			Emoji{Name: "notebook with decorative cover", Unicode: []int32{128212}, ShortNames: []string{"notebook_with_decorative_cover"}},
			Emoji{Name: "closed book", Unicode: []int32{128213}, ShortNames: []string{"closed_book"}},
			Emoji{Name: "open book", Unicode: []int32{128214}, ShortNames: []string{"book", "open_book"}},
			Emoji{Name: "green book", Unicode: []int32{128215}, ShortNames: []string{"green_book"}},
			Emoji{Name: "blue book", Unicode: []int32{128216}, ShortNames: []string{"blue_book"}},
			Emoji{Name: "orange book", Unicode: []int32{128217}, ShortNames: []string{"orange_book"}},
			Emoji{Name: "books", Unicode: []int32{128218}, ShortNames: []string{"books"}},
			Emoji{Name: "notebook", Unicode: []int32{128211}, ShortNames: []string{"notebook"}},
			Emoji{Name: "ledger", Unicode: []int32{128210}, ShortNames: []string{"ledger"}},
			Emoji{Name: "page with curl", Unicode: []int32{128195}, ShortNames: []string{"page_with_curl"}},
			Emoji{Name: "scroll", Unicode: []int32{128220}, ShortNames: []string{"scroll"}},
			Emoji{Name: "page facing up", Unicode: []int32{128196}, ShortNames: []string{"page_facing_up"}},
			Emoji{Name: "newspaper", Unicode: []int32{128240}, ShortNames: []string{"newspaper"}},
			Emoji{Name: "rolled-up newspaper", Unicode: []int32{128478, 65039}, ShortNames: []string{"newspaper_roll"}},
			Emoji{Name: "bookmark tabs", Unicode: []int32{128209}, ShortNames: []string{"bookmark_tabs"}},
			Emoji{Name: "bookmark", Unicode: []int32{128278}, ShortNames: []string{"bookmark"}},
			Emoji{Name: "label", Unicode: []int32{127991, 65039}, ShortNames: []string{"label"}},
			Emoji{Name: "money bag", Unicode: []int32{128176}, ShortNames: []string{"moneybag"}},
			Emoji{Name: "coin", Unicode: []int32{129689}, ShortNames: []string{"coin"}},
			Emoji{Name: "yen banknote", Unicode: []int32{128180}, ShortNames: []string{"yen"}},
			Emoji{Name: "dollar banknote", Unicode: []int32{128181}, ShortNames: []string{"dollar"}},
			Emoji{Name: "euro banknote", Unicode: []int32{128182}, ShortNames: []string{"euro"}},
			Emoji{Name: "pound banknote", Unicode: []int32{128183}, ShortNames: []string{"pound"}},
			Emoji{Name: "money with wings", Unicode: []int32{128184}, ShortNames: []string{"money_with_wings"}},
			Emoji{Name: "credit card", Unicode: []int32{128179}, ShortNames: []string{"credit_card"}},
			Emoji{Name: "receipt", Unicode: []int32{129534}, ShortNames: []string{"receipt"}},
			Emoji{Name: "chart increasing with yen", Unicode: []int32{128185}, ShortNames: []string{"chart"}},
			Emoji{Name: "envelope", Unicode: []int32{9993, 65039}, ShortNames: []string{"envelope"}},
			Emoji{Name: "e-mail", Unicode: []int32{128231}, ShortNames: []string{"email", "e-mail"}},
			Emoji{Name: "incoming envelope", Unicode: []int32{128232}, ShortNames: []string{"incoming_envelope"}},
			Emoji{Name: "envelope with arrow", Unicode: []int32{128233}, ShortNames: []string{"envelope_with_arrow"}},
			Emoji{Name: "outbox tray", Unicode: []int32{128228}, ShortNames: []string{"outbox_tray"}},
			Emoji{Name: "inbox tray", Unicode: []int32{128229}, ShortNames: []string{"inbox_tray"}},
			Emoji{Name: "package", Unicode: []int32{128230}, ShortNames: []string{"package"}},
			Emoji{Name: "closed mailbox with raised flag", Unicode: []int32{128235}, ShortNames: []string{"mailbox"}},
			Emoji{Name: "closed mailbox with lowered flag", Unicode: []int32{128234}, ShortNames: []string{"mailbox_closed"}},
			Emoji{Name: "open mailbox with raised flag", Unicode: []int32{128236}, ShortNames: []string{"mailbox_with_mail"}},
			Emoji{Name: "open mailbox with lowered flag", Unicode: []int32{128237}, ShortNames: []string{"mailbox_with_no_mail"}},
			Emoji{Name: "postbox", Unicode: []int32{128238}, ShortNames: []string{"postbox"}},
			Emoji{Name: "ballot box with ballot", Unicode: []int32{128499, 65039}, ShortNames: []string{"ballot_box"}},
			Emoji{Name: "pencil", Unicode: []int32{9999, 65039}, ShortNames: []string{"pencil2"}},
			Emoji{Name: "black nib", Unicode: []int32{10002, 65039}, ShortNames: []string{"black_nib"}},
			Emoji{Name: "fountain pen", Unicode: []int32{128395, 65039}, ShortNames: []string{"fountain_pen"}},
			Emoji{Name: "pen", Unicode: []int32{128394, 65039}, ShortNames: []string{"pen"}},
			Emoji{Name: "paintbrush", Unicode: []int32{128396, 65039}, ShortNames: []string{"paintbrush"}},
			Emoji{Name: "crayon", Unicode: []int32{128397, 65039}, ShortNames: []string{"crayon"}},
			Emoji{Name: "memo", Unicode: []int32{128221}, ShortNames: []string{"memo", "pencil"}},
			Emoji{Name: "briefcase", Unicode: []int32{128188}, ShortNames: []string{"briefcase"}},
			Emoji{Name: "file folder", Unicode: []int32{128193}, ShortNames: []string{"file_folder"}},
			Emoji{Name: "open file folder", Unicode: []int32{128194}, ShortNames: []string{"open_file_folder"}},
			Emoji{Name: "card index dividers", Unicode: []int32{128450, 65039}, ShortNames: []string{"card_index_dividers"}},
			Emoji{Name: "calendar", Unicode: []int32{128197}, ShortNames: []string{"date"}},
			Emoji{Name: "tear-off calendar", Unicode: []int32{128198}, ShortNames: []string{"calendar"}},
			Emoji{Name: "spiral notepad", Unicode: []int32{128466, 65039}, ShortNames: []string{"spiral_notepad"}},
			Emoji{Name: "spiral calendar", Unicode: []int32{128467, 65039}, ShortNames: []string{"spiral_calendar"}},
			Emoji{Name: "card index", Unicode: []int32{128199}, ShortNames: []string{"card_index"}},
			Emoji{Name: "chart increasing", Unicode: []int32{128200}, ShortNames: []string{"chart_with_upwards_trend"}},
			Emoji{Name: "chart decreasing", Unicode: []int32{128201}, ShortNames: []string{"chart_with_downwards_trend"}},
			Emoji{Name: "bar chart", Unicode: []int32{128202}, ShortNames: []string{"bar_chart"}},
			Emoji{Name: "clipboard", Unicode: []int32{128203}, ShortNames: []string{"clipboard"}},
			Emoji{Name: "pushpin", Unicode: []int32{128204}, ShortNames: []string{"pushpin"}},
			Emoji{Name: "round pushpin", Unicode: []int32{128205}, ShortNames: []string{"round_pushpin"}},
			Emoji{Name: "paperclip", Unicode: []int32{128206}, ShortNames: []string{"paperclip"}},
			Emoji{Name: "linked paperclips", Unicode: []int32{128391, 65039}, ShortNames: []string{"paperclips"}},
			Emoji{Name: "straight ruler", Unicode: []int32{128207}, ShortNames: []string{"straight_ruler"}},
			Emoji{Name: "triangular ruler", Unicode: []int32{128208}, ShortNames: []string{"triangular_ruler"}},
			Emoji{Name: "scissors", Unicode: []int32{9986, 65039}, ShortNames: []string{"scissors"}},
			Emoji{Name: "card file box", Unicode: []int32{128451, 65039}, ShortNames: []string{"card_file_box"}},
			Emoji{Name: "file cabinet", Unicode: []int32{128452, 65039}, ShortNames: []string{"file_cabinet"}},
			Emoji{Name: "wastebasket", Unicode: []int32{128465, 65039}, ShortNames: []string{"wastebasket"}},
			Emoji{Name: "locked", Unicode: []int32{128274}, ShortNames: []string{"lock"}},
			Emoji{Name: "unlocked", Unicode: []int32{128275}, ShortNames: []string{"unlock"}},
			Emoji{Name: "locked with pen", Unicode: []int32{128271}, ShortNames: []string{"lock_with_ink_pen"}},
			Emoji{Name: "locked with key", Unicode: []int32{128272}, ShortNames: []string{"closed_lock_with_key"}},
			Emoji{Name: "key", Unicode: []int32{128273}, ShortNames: []string{"key"}},
			Emoji{Name: "old key", Unicode: []int32{128477, 65039}, ShortNames: []string{"old_key"}},
			Emoji{Name: "hammer", Unicode: []int32{128296}, ShortNames: []string{"hammer"}},
			Emoji{Name: "axe", Unicode: []int32{129683}, ShortNames: []string{"axe"}},
			Emoji{Name: "pick", Unicode: []int32{9935, 65039}, ShortNames: []string{"pick"}},
			Emoji{Name: "hammer and pick", Unicode: []int32{9874, 65039}, ShortNames: []string{"hammer_and_pick"}},
			Emoji{Name: "hammer and wrench", Unicode: []int32{128736, 65039}, ShortNames: []string{"hammer_and_wrench"}},
			Emoji{Name: "dagger", Unicode: []int32{128481, 65039}, ShortNames: []string{"dagger"}},
			Emoji{Name: "crossed swords", Unicode: []int32{9876, 65039}, ShortNames: []string{"crossed_swords"}},
			Emoji{Name: "bomb", Unicode: []int32{128163}, ShortNames: []string{"bomb"}},
			Emoji{Name: "boomerang", Unicode: []int32{129667}, ShortNames: []string{"boomerang"}},
			Emoji{Name: "bow and arrow", Unicode: []int32{127993}, ShortNames: []string{"bow_and_arrow"}},
			Emoji{Name: "shield", Unicode: []int32{128737, 65039}, ShortNames: []string{"shield"}},
			Emoji{Name: "carpentry saw", Unicode: []int32{129690}, ShortNames: []string{"carpentry_saw"}},
			Emoji{Name: "wrench", Unicode: []int32{128295}, ShortNames: []string{"wrench"}},
			Emoji{Name: "screwdriver", Unicode: []int32{129691}, ShortNames: []string{"screwdriver"}},
			Emoji{Name: "nut and bolt", Unicode: []int32{128297}, ShortNames: []string{"nut_and_bolt"}},
			Emoji{Name: "gear", Unicode: []int32{9881, 65039}, ShortNames: []string{"gear"}},
			Emoji{Name: "clamp", Unicode: []int32{128476, 65039}, ShortNames: []string{"clamp"}},
			Emoji{Name: "balance scale", Unicode: []int32{9878, 65039}, ShortNames: []string{"balance_scale"}},
			Emoji{Name: "white cane", Unicode: []int32{129455}, ShortNames: []string{"probing_cane"}},
			Emoji{Name: "link", Unicode: []int32{128279}, ShortNames: []string{"link"}},
			Emoji{Name: "chains", Unicode: []int32{9939, 65039}, ShortNames: []string{"chains"}},
			Emoji{Name: "hook", Unicode: []int32{129693}, ShortNames: []string{"hook"}},
			Emoji{Name: "toolbox", Unicode: []int32{129520}, ShortNames: []string{"toolbox"}},
			Emoji{Name: "magnet", Unicode: []int32{129522}, ShortNames: []string{"magnet"}},
			Emoji{Name: "ladder", Unicode: []int32{129692}, ShortNames: []string{"ladder"}},
			Emoji{Name: "alembic", Unicode: []int32{9879, 65039}, ShortNames: []string{"alembic"}},
			Emoji{Name: "test tube", Unicode: []int32{129514}, ShortNames: []string{"test_tube"}},
			Emoji{Name: "petri dish", Unicode: []int32{129515}, ShortNames: []string{"petri_dish"}},
			Emoji{Name: "dna", Unicode: []int32{129516}, ShortNames: []string{"dna"}},
			Emoji{Name: "microscope", Unicode: []int32{128300}, ShortNames: []string{"microscope"}},
			Emoji{Name: "telescope", Unicode: []int32{128301}, ShortNames: []string{"telescope"}},
			Emoji{Name: "satellite antenna", Unicode: []int32{128225}, ShortNames: []string{"satellite"}},
			Emoji{Name: "syringe", Unicode: []int32{128137}, ShortNames: []string{"syringe"}},
			Emoji{Name: "drop of blood", Unicode: []int32{129656}, ShortNames: []string{"drop_of_blood"}},
			Emoji{Name: "pill", Unicode: []int32{128138}, ShortNames: []string{"pill"}},
			Emoji{Name: "adhesive bandage", Unicode: []int32{129657}, ShortNames: []string{"adhesive_bandage"}},
			Emoji{Name: "crutch", Unicode: []int32{129660}, ShortNames: []string{"crutch"}},
			Emoji{Name: "stethoscope", Unicode: []int32{129658}, ShortNames: []string{"stethoscope"}},
			Emoji{Name: "x-ray", Unicode: []int32{129659}, ShortNames: []string{"x_ray"}},
			Emoji{Name: "door", Unicode: []int32{128682}, ShortNames: []string{"door"}},
			Emoji{Name: "elevator", Unicode: []int32{128727}, ShortNames: []string{"elevator"}},
			Emoji{Name: "mirror", Unicode: []int32{129694}, ShortNames: []string{"mirror"}},
			Emoji{Name: "window", Unicode: []int32{129695}, ShortNames: []string{"window"}},
			Emoji{Name: "bed", Unicode: []int32{128719, 65039}, ShortNames: []string{"bed"}},
			Emoji{Name: "couch and lamp", Unicode: []int32{128715, 65039}, ShortNames: []string{"couch_and_lamp"}},
			Emoji{Name: "chair", Unicode: []int32{129681}, ShortNames: []string{"chair"}},
			Emoji{Name: "toilet", Unicode: []int32{128701}, ShortNames: []string{"toilet"}},
			Emoji{Name: "plunger", Unicode: []int32{129696}, ShortNames: []string{"plunger"}},
			Emoji{Name: "shower", Unicode: []int32{128703}, ShortNames: []string{"shower"}},
			Emoji{Name: "bathtub", Unicode: []int32{128705}, ShortNames: []string{"bathtub"}},
			Emoji{Name: "mouse trap", Unicode: []int32{129700}, ShortNames: []string{"mouse_trap"}},
			Emoji{Name: "razor", Unicode: []int32{129682}, ShortNames: []string{"razor"}},
			Emoji{Name: "lotion bottle", Unicode: []int32{129524}, ShortNames: []string{"lotion_bottle"}},
			Emoji{Name: "safety pin", Unicode: []int32{129527}, ShortNames: []string{"safety_pin"}},
			Emoji{Name: "broom", Unicode: []int32{129529}, ShortNames: []string{"broom"}},
			Emoji{Name: "basket", Unicode: []int32{129530}, ShortNames: []string{"basket"}},
			Emoji{Name: "roll of paper", Unicode: []int32{129531}, ShortNames: []string{"roll_of_paper"}},
			Emoji{Name: "bucket", Unicode: []int32{129699}, ShortNames: []string{"bucket"}},
			Emoji{Name: "soap", Unicode: []int32{129532}, ShortNames: []string{"soap"}},
			Emoji{Name: "bubbles", Unicode: []int32{129767}, ShortNames: []string{"bubbles"}},
			Emoji{Name: "toothbrush", Unicode: []int32{129701}, ShortNames: []string{"toothbrush"}},
			Emoji{Name: "sponge", Unicode: []int32{129533}, ShortNames: []string{"sponge"}},
			Emoji{Name: "fire extinguisher", Unicode: []int32{129519}, ShortNames: []string{"fire_extinguisher"}},
			Emoji{Name: "shopping cart", Unicode: []int32{128722}, ShortNames: []string{"shopping_cart"}},
			Emoji{Name: "cigarette", Unicode: []int32{128684}, ShortNames: []string{"smoking"}},
			Emoji{Name: "coffin", Unicode: []int32{9904, 65039}, ShortNames: []string{"coffin"}},
			Emoji{Name: "headstone", Unicode: []int32{129702}, ShortNames: []string{"headstone"}},
			Emoji{Name: "funeral urn", Unicode: []int32{9905, 65039}, ShortNames: []string{"funeral_urn"}},
			Emoji{Name: "nazar amulet", Unicode: []int32{129535}, ShortNames: []string{"nazar_amulet"}},
			Emoji{Name: "hamsa", Unicode: []int32{129708}, ShortNames: []string{"hamsa"}},
			Emoji{Name: "moai", Unicode: []int32{128511}, ShortNames: []string{"moyai"}},
			Emoji{Name: "placard", Unicode: []int32{129703}, ShortNames: []string{"placard"}},
			Emoji{Name: "identification card", Unicode: []int32{129706}, ShortNames: []string{"identification_card"}},
			Emoji{Name: "ATM sign", Unicode: []int32{127975}, ShortNames: []string{"atm"}},
			Emoji{Name: "litter in bin sign", Unicode: []int32{128686}, ShortNames: []string{"put_litter_in_its_place"}},
			Emoji{Name: "potable water", Unicode: []int32{128688}, ShortNames: []string{"potable_water"}},
			Emoji{Name: "wheelchair symbol", Unicode: []int32{9855}, ShortNames: []string{"wheelchair"}},
			Emoji{Name: "men’s room", Unicode: []int32{128697}, ShortNames: []string{"mens"}},
			Emoji{Name: "women’s room", Unicode: []int32{128698}, ShortNames: []string{"womens"}},
			Emoji{Name: "restroom", Unicode: []int32{128699}, ShortNames: []string{"restroom"}},
			Emoji{Name: "baby symbol", Unicode: []int32{128700}, ShortNames: []string{"baby_symbol"}},
			Emoji{Name: "water closet", Unicode: []int32{128702}, ShortNames: []string{"wc"}},
			Emoji{Name: "passport control", Unicode: []int32{128706}, ShortNames: []string{"passport_control"}},
			Emoji{Name: "customs", Unicode: []int32{128707}, ShortNames: []string{"customs"}},
			Emoji{Name: "baggage claim", Unicode: []int32{128708}, ShortNames: []string{"baggage_claim"}},
			Emoji{Name: "left luggage", Unicode: []int32{128709}, ShortNames: []string{"left_luggage"}},
			Emoji{Name: "warning", Unicode: []int32{9888, 65039}, ShortNames: []string{"warning"}},
			Emoji{Name: "children crossing", Unicode: []int32{128696}, ShortNames: []string{"children_crossing"}},
			Emoji{Name: "no entry", Unicode: []int32{9940}, ShortNames: []string{"no_entry"}},
			Emoji{Name: "prohibited", Unicode: []int32{128683}, ShortNames: []string{"no_entry_sign"}},
			Emoji{Name: "no bicycles", Unicode: []int32{128691}, ShortNames: []string{"no_bicycles"}},
			Emoji{Name: "no smoking", Unicode: []int32{128685}, ShortNames: []string{"no_smoking"}},
			Emoji{Name: "no littering", Unicode: []int32{128687}, ShortNames: []string{"do_not_litter"}},
			Emoji{Name: "non-potable water", Unicode: []int32{128689}, ShortNames: []string{"non-potable_water"}},
			Emoji{Name: "no pedestrians", Unicode: []int32{128695}, ShortNames: []string{"no_pedestrians"}},
			Emoji{Name: "no mobile phones", Unicode: []int32{128245}, ShortNames: []string{"no_mobile_phones"}},
			Emoji{Name: "no one under eighteen", Unicode: []int32{128286}, ShortNames: []string{"underage"}},
			Emoji{Name: "radioactive", Unicode: []int32{9762, 65039}, ShortNames: []string{"radioactive"}},
			Emoji{Name: "biohazard", Unicode: []int32{9763, 65039}, ShortNames: []string{"biohazard"}},
			Emoji{Name: "up arrow", Unicode: []int32{11014, 65039}, ShortNames: []string{"arrow_up"}},
			Emoji{Name: "up-right arrow", Unicode: []int32{8599, 65039}, ShortNames: []string{"arrow_upper_right"}},
			Emoji{Name: "right arrow", Unicode: []int32{10145, 65039}, ShortNames: []string{"arrow_right"}},
			Emoji{Name: "down-right arrow", Unicode: []int32{8600, 65039}, ShortNames: []string{"arrow_lower_right"}},
			Emoji{Name: "down arrow", Unicode: []int32{11015, 65039}, ShortNames: []string{"arrow_down"}},
			Emoji{Name: "down-left arrow", Unicode: []int32{8601, 65039}, ShortNames: []string{"arrow_lower_left"}},
			Emoji{Name: "left arrow", Unicode: []int32{11013, 65039}, ShortNames: []string{"arrow_left"}},
			Emoji{Name: "up-left arrow", Unicode: []int32{8598, 65039}, ShortNames: []string{"arrow_upper_left"}},
			Emoji{Name: "up-down arrow", Unicode: []int32{8597, 65039}, ShortNames: []string{"arrow_up_down"}},
			Emoji{Name: "left-right arrow", Unicode: []int32{8596, 65039}, ShortNames: []string{"left_right_arrow"}},
			Emoji{Name: "right arrow curving left", Unicode: []int32{8617, 65039}, ShortNames: []string{"leftwards_arrow_with_hook"}},
			Emoji{Name: "left arrow curving right", Unicode: []int32{8618, 65039}, ShortNames: []string{"arrow_right_hook"}},
			Emoji{Name: "right arrow curving up", Unicode: []int32{10548, 65039}, ShortNames: []string{"arrow_heading_up"}},
			Emoji{Name: "right arrow curving down", Unicode: []int32{10549, 65039}, ShortNames: []string{"arrow_heading_down"}},
			Emoji{Name: "clockwise vertical arrows", Unicode: []int32{128259}, ShortNames: []string{"arrows_clockwise"}},
			Emoji{Name: "counterclockwise arrows button", Unicode: []int32{128260}, ShortNames: []string{"arrows_counterclockwise"}},
			Emoji{Name: "BACK arrow", Unicode: []int32{128281}, ShortNames: []string{"back"}},
			Emoji{Name: "END arrow", Unicode: []int32{128282}, ShortNames: []string{"end"}},
			Emoji{Name: "ON! arrow", Unicode: []int32{128283}, ShortNames: []string{"on"}},
			Emoji{Name: "SOON arrow", Unicode: []int32{128284}, ShortNames: []string{"soon"}},
			Emoji{Name: "TOP arrow", Unicode: []int32{128285}, ShortNames: []string{"top"}},
			Emoji{Name: "place of worship", Unicode: []int32{128720}, ShortNames: []string{"place_of_worship"}},
			Emoji{Name: "atom symbol", Unicode: []int32{9883, 65039}, ShortNames: []string{"atom_symbol"}},
			Emoji{Name: "om", Unicode: []int32{128329, 65039}, ShortNames: []string{"om"}},
			Emoji{Name: "star of David", Unicode: []int32{10017, 65039}, ShortNames: []string{"star_of_david"}},
			Emoji{Name: "wheel of dharma", Unicode: []int32{9784, 65039}, ShortNames: []string{"wheel_of_dharma"}},
			Emoji{Name: "yin yang", Unicode: []int32{9775, 65039}, ShortNames: []string{"yin_yang"}},
			Emoji{Name: "latin cross", Unicode: []int32{10013, 65039}, ShortNames: []string{"latin_cross"}},
			Emoji{Name: "orthodox cross", Unicode: []int32{9766, 65039}, ShortNames: []string{"orthodox_cross"}},
			Emoji{Name: "star and crescent", Unicode: []int32{9770, 65039}, ShortNames: []string{"star_and_crescent"}},
			Emoji{Name: "peace symbol", Unicode: []int32{9774, 65039}, ShortNames: []string{"peace_symbol"}},
			Emoji{Name: "menorah", Unicode: []int32{128334}, ShortNames: []string{"menorah"}},
			Emoji{Name: "dotted six-pointed star", Unicode: []int32{128303}, ShortNames: []string{"six_pointed_star"}},
			Emoji{Name: "khanda", Unicode: []int32{129711}, ShortNames: []string{"khanda"}},
			Emoji{Name: "Aries", Unicode: []int32{9800}, ShortNames: []string{"aries"}},
			Emoji{Name: "Taurus", Unicode: []int32{9801}, ShortNames: []string{"taurus"}},
			Emoji{Name: "Gemini", Unicode: []int32{9802}, ShortNames: []string{"gemini"}},
			Emoji{Name: "Cancer", Unicode: []int32{9803}, ShortNames: []string{"cancer"}},
			Emoji{Name: "Leo", Unicode: []int32{9804}, ShortNames: []string{"leo"}},
			Emoji{Name: "Virgo", Unicode: []int32{9805}, ShortNames: []string{"virgo"}},
			Emoji{Name: "Libra", Unicode: []int32{9806}, ShortNames: []string{"libra"}},
			Emoji{Name: "Scorpio", Unicode: []int32{9807}, ShortNames: []string{"scorpius"}},
			Emoji{Name: "Sagittarius", Unicode: []int32{9808}, ShortNames: []string{"sagittarius"}},
			Emoji{Name: "Capricorn", Unicode: []int32{9809}, ShortNames: []string{"capricorn"}},
			Emoji{Name: "Aquarius", Unicode: []int32{9810}, ShortNames: []string{"aquarius"}},
			Emoji{Name: "Pisces", Unicode: []int32{9811}, ShortNames: []string{"pisces"}},
			Emoji{Name: "Ophiuchus", Unicode: []int32{9934}, ShortNames: []string{"ophiuchus"}},
			Emoji{Name: "shuffle tracks button", Unicode: []int32{128256}, ShortNames: []string{"twisted_rightwards_arrows"}},
			Emoji{Name: "repeat button", Unicode: []int32{128257}, ShortNames: []string{"repeat"}},
			Emoji{Name: "repeat single button", Unicode: []int32{128258}, ShortNames: []string{"repeat_one"}},
			Emoji{Name: "play button", Unicode: []int32{9654, 65039}, ShortNames: []string{"arrow_forward"}},
			Emoji{Name: "fast-forward button", Unicode: []int32{9193}, ShortNames: []string{"fast_forward"}},
			Emoji{Name: "next track button", Unicode: []int32{9197, 65039}, ShortNames: []string{"next_track_button"}},
			Emoji{Name: "play or pause button", Unicode: []int32{9199, 65039}, ShortNames: []string{"play_or_pause_button"}},
			Emoji{Name: "reverse button", Unicode: []int32{9664, 65039}, ShortNames: []string{"arrow_backward"}},
			Emoji{Name: "fast reverse button", Unicode: []int32{9194}, ShortNames: []string{"rewind"}},
			Emoji{Name: "last track button", Unicode: []int32{9198, 65039}, ShortNames: []string{"previous_track_button"}},
			Emoji{Name: "upwards button", Unicode: []int32{128316}, ShortNames: []string{"arrow_up_small"}},
			Emoji{Name: "fast up button", Unicode: []int32{9195}, ShortNames: []string{"arrow_double_up"}},
			Emoji{Name: "downwards button", Unicode: []int32{128317}, ShortNames: []string{"arrow_down_small"}},
			Emoji{Name: "fast down button", Unicode: []int32{9196}, ShortNames: []string{"arrow_double_down"}},
			Emoji{Name: "pause button", Unicode: []int32{9208, 65039}, ShortNames: []string{"pause_button"}},
			Emoji{Name: "stop button", Unicode: []int32{9209, 65039}, ShortNames: []string{"stop_button"}},
			Emoji{Name: "record button", Unicode: []int32{9210, 65039}, ShortNames: []string{"record_button"}},
			Emoji{Name: "eject button", Unicode: []int32{9167, 65039}, ShortNames: []string{"eject_button"}},
			Emoji{Name: "cinema", Unicode: []int32{127910}, ShortNames: []string{"cinema"}},
			Emoji{Name: "dim button", Unicode: []int32{128261}, ShortNames: []string{"low_brightness"}},
			Emoji{Name: "bright button", Unicode: []int32{128262}, ShortNames: []string{"high_brightness"}},
			Emoji{Name: "antenna bars", Unicode: []int32{128246}, ShortNames: []string{"signal_strength"}},
			Emoji{Name: "wireless", Unicode: []int32{128732}, ShortNames: []string{"wireless"}},
			Emoji{Name: "vibration mode", Unicode: []int32{128243}, ShortNames: []string{"vibration_mode"}},
			Emoji{Name: "mobile phone off", Unicode: []int32{128244}, ShortNames: []string{"mobile_phone_off"}},
			Emoji{Name: "female sign", Unicode: []int32{9792, 65039}, ShortNames: []string{"female_sign"}},
			Emoji{Name: "male sign", Unicode: []int32{9794, 65039}, ShortNames: []string{"male_sign"}},
			Emoji{Name: "transgender symbol", Unicode: []int32{9895, 65039}, ShortNames: []string{"transgender_symbol"}},
			Emoji{Name: "multiply", Unicode: []int32{10006, 65039}, ShortNames: []string{"heavy_multiplication_x"}},
			Emoji{Name: "plus", Unicode: []int32{10133}, ShortNames: []string{"heavy_plus_sign"}},
			Emoji{Name: "minus", Unicode: []int32{10134}, ShortNames: []string{"heavy_minus_sign"}},
			Emoji{Name: "divide", Unicode: []int32{10135}, ShortNames: []string{"heavy_division_sign"}},
			Emoji{Name: "heavy equals sign", Unicode: []int32{129008}, ShortNames: []string{"heavy_equals_sign"}},
			Emoji{Name: "infinity", Unicode: []int32{9854, 65039}, ShortNames: []string{"infinity"}},
			Emoji{Name: "double exclamation mark", Unicode: []int32{8252, 65039}, ShortNames: []string{"bangbang"}},
			Emoji{Name: "exclamation question mark", Unicode: []int32{8265, 65039}, ShortNames: []string{"interrobang"}},
			Emoji{Name: "red question mark", Unicode: []int32{10067}, ShortNames: []string{"question"}},
			Emoji{Name: "white question mark", Unicode: []int32{10068}, ShortNames: []string{"grey_question"}},
			Emoji{Name: "white exclamation mark", Unicode: []int32{10069}, ShortNames: []string{"grey_exclamation"}},
			Emoji{Name: "red exclamation mark", Unicode: []int32{10071}, ShortNames: []string{"exclamation", "heavy_exclamation_mark"}},
			Emoji{Name: "wavy dash", Unicode: []int32{12336, 65039}, ShortNames: []string{"wavy_dash"}},
			Emoji{Name: "currency exchange", Unicode: []int32{128177}, ShortNames: []string{"currency_exchange"}},
			Emoji{Name: "heavy dollar sign", Unicode: []int32{128178}, ShortNames: []string{"heavy_dollar_sign"}},
			Emoji{Name: "medical symbol", Unicode: []int32{9877, 65039}, ShortNames: []string{"medical_symbol"}},
			Emoji{Name: "recycling symbol", Unicode: []int32{9851, 65039}, ShortNames: []string{"recycle"}},
			Emoji{Name: "fleur-de-lis", Unicode: []int32{9884, 65039}, ShortNames: []string{"fleur_de_lis"}},
			Emoji{Name: "trident emblem", Unicode: []int32{128305}, ShortNames: []string{"trident"}},
			Emoji{Name: "name badge", Unicode: []int32{128219}, ShortNames: []string{"name_badge"}},
			Emoji{Name: "Japanese symbol for beginner", Unicode: []int32{128304}, ShortNames: []string{"beginner"}},
			Emoji{Name: "hollow red circle", Unicode: []int32{11093}, ShortNames: []string{"o"}},
			Emoji{Name: "check mark button", Unicode: []int32{9989}, ShortNames: []string{"white_check_mark"}},
			Emoji{Name: "check box with check", Unicode: []int32{9745, 65039}, ShortNames: []string{"ballot_box_with_check"}},
			Emoji{Name: "check mark", Unicode: []int32{10004, 65039}, ShortNames: []string{"heavy_check_mark"}},
			Emoji{Name: "cross mark", Unicode: []int32{10060}, ShortNames: []string{"x"}},
			Emoji{Name: "cross mark button", Unicode: []int32{10062}, ShortNames: []string{"negative_squared_cross_mark"}},
			Emoji{Name: "curly loop", Unicode: []int32{10160}, ShortNames: []string{"curly_loop"}},
			Emoji{Name: "double curly loop", Unicode: []int32{10175}, ShortNames: []string{"loop"}},
			Emoji{Name: "part alternation mark", Unicode: []int32{12349, 65039}, ShortNames: []string{"part_alternation_mark"}},
			Emoji{Name: "eight-spoked asterisk", Unicode: []int32{10035, 65039}, ShortNames: []string{"eight_spoked_asterisk"}},
			Emoji{Name: "eight-pointed star", Unicode: []int32{10036, 65039}, ShortNames: []string{"eight_pointed_black_star"}},
			Emoji{Name: "sparkle", Unicode: []int32{10055, 65039}, ShortNames: []string{"sparkle"}},
			Emoji{Name: "copyright", Unicode: []int32{169, 65039}, ShortNames: []string{"copyright"}},
			Emoji{Name: "registered", Unicode: []int32{174, 65039}, ShortNames: []string{"registered"}},
			Emoji{Name: "trade mark", Unicode: []int32{8482, 65039}, ShortNames: []string{"tm"}},
			Emoji{Name: "keycap: #", Unicode: []int32{35, 65039, 8419}, ShortNames: []string{"hash"}},
			Emoji{Name: "keycap: *", Unicode: []int32{42, 65039, 8419}, ShortNames: []string{"asterisk"}},
			Emoji{Name: "keycap: 0", Unicode: []int32{48, 65039, 8419}, ShortNames: []string{"zero"}},
			Emoji{Name: "keycap: 1", Unicode: []int32{49, 65039, 8419}, ShortNames: []string{"one"}},
			Emoji{Name: "keycap: 2", Unicode: []int32{50, 65039, 8419}, ShortNames: []string{"two"}},
			Emoji{Name: "keycap: 3", Unicode: []int32{51, 65039, 8419}, ShortNames: []string{"three"}},
			Emoji{Name: "keycap: 4", Unicode: []int32{52, 65039, 8419}, ShortNames: []string{"four"}},
			Emoji{Name: "keycap: 5", Unicode: []int32{53, 65039, 8419}, ShortNames: []string{"five"}},
			Emoji{Name: "keycap: 6", Unicode: []int32{54, 65039, 8419}, ShortNames: []string{"six"}},
			Emoji{Name: "keycap: 7", Unicode: []int32{55, 65039, 8419}, ShortNames: []string{"seven"}},
			Emoji{Name: "keycap: 8", Unicode: []int32{56, 65039, 8419}, ShortNames: []string{"eight"}},
			Emoji{Name: "keycap: 9", Unicode: []int32{57, 65039, 8419}, ShortNames: []string{"nine"}},
			Emoji{Name: "keycap: 10", Unicode: []int32{128287}, ShortNames: []string{"keycap_ten"}},
			Emoji{Name: "input latin uppercase", Unicode: []int32{128288}, ShortNames: []string{"capital_abcd"}},
			Emoji{Name: "input latin lowercase", Unicode: []int32{128289}, ShortNames: []string{"abcd"}},
			Emoji{Name: "input numbers", Unicode: []int32{128290}, ShortNames: []string{"1234"}},
			Emoji{Name: "input symbols", Unicode: []int32{128291}, ShortNames: []string{"symbols"}},
			Emoji{Name: "input latin letters", Unicode: []int32{128292}, ShortNames: []string{"abc"}},
			Emoji{Name: "A button (blood type)", Unicode: []int32{127344, 65039}, ShortNames: []string{"a"}},
			Emoji{Name: "AB button (blood type)", Unicode: []int32{127374}, ShortNames: []string{"ab"}},
			Emoji{Name: "B button (blood type)", Unicode: []int32{127345, 65039}, ShortNames: []string{"b"}},
			Emoji{Name: "CL button", Unicode: []int32{127377}, ShortNames: []string{"cl"}},
			Emoji{Name: "COOL button", Unicode: []int32{127378}, ShortNames: []string{"cool"}},
			Emoji{Name: "FREE button", Unicode: []int32{127379}, ShortNames: []string{"free"}},
			Emoji{Name: "information", Unicode: []int32{8505, 65039}, ShortNames: []string{"information_source"}},
			Emoji{Name: "ID button", Unicode: []int32{127380}, ShortNames: []string{"id"}},
			Emoji{Name: "circled M", Unicode: []int32{9410, 65039}, ShortNames: []string{"m"}},
			Emoji{Name: "NEW button", Unicode: []int32{127381}, ShortNames: []string{"new"}},
			Emoji{Name: "NG button", Unicode: []int32{127382}, ShortNames: []string{"ng"}},
			Emoji{Name: "O button (blood type)", Unicode: []int32{127358, 65039}, ShortNames: []string{"o2"}},
			Emoji{Name: "OK button", Unicode: []int32{127383}, ShortNames: []string{"ok"}},
			Emoji{Name: "P button", Unicode: []int32{127359, 65039}, ShortNames: []string{"parking"}},
			Emoji{Name: "SOS button", Unicode: []int32{127384}, ShortNames: []string{"sos"}},
			Emoji{Name: "UP! button", Unicode: []int32{127385}, ShortNames: []string{"up"}},
			Emoji{Name: "VS button", Unicode: []int32{127386}, ShortNames: []string{"vs"}},
			Emoji{Name: "Japanese “here” button", Unicode: []int32{127489}, ShortNames: []string{"koko"}},
			Emoji{Name: "Japanese “service charge” button", Unicode: []int32{127490, 65039}, ShortNames: []string{"sa"}},
			Emoji{Name: "Japanese “monthly amount” button", Unicode: []int32{127543, 65039}, ShortNames: []string{"u6708"}},
			Emoji{Name: "Japanese “not free of charge” button", Unicode: []int32{127542}, ShortNames: []string{"u6709"}},
			Emoji{Name: "Japanese “reserved” button", Unicode: []int32{127535}, ShortNames: []string{"u6307"}},
			Emoji{Name: "Japanese “bargain” button", Unicode: []int32{127568}, ShortNames: []string{"ideograph_advantage"}},
			Emoji{Name: "Japanese “discount” button", Unicode: []int32{127545}, ShortNames: []string{"u5272"}},
			Emoji{Name: "Japanese “free of charge” button", Unicode: []int32{127514}, ShortNames: []string{"u7121"}},
			Emoji{Name: "Japanese “prohibited” button", Unicode: []int32{127538}, ShortNames: []string{"u7981"}},
			Emoji{Name: "Japanese “acceptable” button", Unicode: []int32{127569}, ShortNames: []string{"accept"}},
			Emoji{Name: "Japanese “application” button", Unicode: []int32{127544}, ShortNames: []string{"u7533"}},
			Emoji{Name: "Japanese “passing grade” button", Unicode: []int32{127540}, ShortNames: []string{"u5408"}},
			Emoji{Name: "Japanese “vacancy” button", Unicode: []int32{127539}, ShortNames: []string{"u7a7a"}},
			Emoji{Name: "Japanese “congratulations” button", Unicode: []int32{12951, 65039}, ShortNames: []string{"congratulations"}},
			Emoji{Name: "Japanese “secret” button", Unicode: []int32{12953, 65039}, ShortNames: []string{"secret"}},
			Emoji{Name: "Japanese “open for business” button", Unicode: []int32{127546}, ShortNames: []string{"u55b6"}},
			Emoji{Name: "Japanese “no vacancy” button", Unicode: []int32{127541}, ShortNames: []string{"u6e80"}},
			Emoji{Name: "red circle", Unicode: []int32{128308}, ShortNames: []string{"red_circle"}},
			Emoji{Name: "orange circle", Unicode: []int32{128992}, ShortNames: []string{"orange_circle"}},
			Emoji{Name: "yellow circle", Unicode: []int32{128993}, ShortNames: []string{"yellow_circle"}},
			Emoji{Name: "green circle", Unicode: []int32{128994}, ShortNames: []string{"green_circle"}},
			Emoji{Name: "blue circle", Unicode: []int32{128309}, ShortNames: []string{"large_blue_circle"}},
			Emoji{Name: "purple circle", Unicode: []int32{128995}, ShortNames: []string{"purple_circle"}},
			Emoji{Name: "brown circle", Unicode: []int32{128996}, ShortNames: []string{"brown_circle"}},
			Emoji{Name: "black circle", Unicode: []int32{9899}, ShortNames: []string{"black_circle"}},
			Emoji{Name: "white circle", Unicode: []int32{9898}, ShortNames: []string{"white_circle"}},
			Emoji{Name: "red square", Unicode: []int32{128997}, ShortNames: []string{"red_square"}},
			Emoji{Name: "orange square", Unicode: []int32{128999}, ShortNames: []string{"orange_square"}},
			Emoji{Name: "yellow square", Unicode: []int32{129000}, ShortNames: []string{"yellow_square"}},
			Emoji{Name: "green square", Unicode: []int32{129001}, ShortNames: []string{"green_square"}},
			Emoji{Name: "blue square", Unicode: []int32{128998}, ShortNames: []string{"blue_square"}},
			Emoji{Name: "purple square", Unicode: []int32{129002}, ShortNames: []string{"purple_square"}},
			Emoji{Name: "brown square", Unicode: []int32{129003}, ShortNames: []string{"brown_square"}},
			Emoji{Name: "black large square", Unicode: []int32{11035}, ShortNames: []string{"black_large_square"}},
			Emoji{Name: "white large square", Unicode: []int32{11036}, ShortNames: []string{"white_large_square"}},
			Emoji{Name: "black medium square", Unicode: []int32{9724, 65039}, ShortNames: []string{"black_medium_square"}},
			Emoji{Name: "white medium square", Unicode: []int32{9723, 65039}, ShortNames: []string{"white_medium_square"}},
			Emoji{Name: "black medium-small square", Unicode: []int32{9726}, ShortNames: []string{"black_medium_small_square"}},
			Emoji{Name: "white medium-small square", Unicode: []int32{9725}, ShortNames: []string{"white_medium_small_square"}},
			Emoji{Name: "black small square", Unicode: []int32{9642, 65039}, ShortNames: []string{"black_small_square"}},
			Emoji{Name: "white small square", Unicode: []int32{9643, 65039}, ShortNames: []string{"white_small_square"}},
			Emoji{Name: "large orange diamond", Unicode: []int32{128310}, ShortNames: []string{"large_orange_diamond"}},
			Emoji{Name: "large blue diamond", Unicode: []int32{128311}, ShortNames: []string{"large_blue_diamond"}},
			Emoji{Name: "small orange diamond", Unicode: []int32{128312}, ShortNames: []string{"small_orange_diamond"}},
			Emoji{Name: "small blue diamond", Unicode: []int32{128313}, ShortNames: []string{"small_blue_diamond"}},
			Emoji{Name: "red triangle pointed up", Unicode: []int32{128314}, ShortNames: []string{"small_red_triangle"}},
			Emoji{Name: "red triangle pointed down", Unicode: []int32{128315}, ShortNames: []string{"small_red_triangle_down"}},
			Emoji{Name: "diamond with a dot", Unicode: []int32{128160}, ShortNames: []string{"diamond_shape_with_a_dot_inside"}},
			Emoji{Name: "radio button", Unicode: []int32{128280}, ShortNames: []string{"radio_button"}},
			Emoji{Name: "white square button", Unicode: []int32{128307}, ShortNames: []string{"white_square_button"}},
			Emoji{Name: "black square button", Unicode: []int32{128306}, ShortNames: []string{"black_square_button"}},
			Emoji{Name: "chequered flag", Unicode: []int32{127937}, ShortNames: []string{"checkered_flag"}},
			Emoji{Name: "triangular flag", Unicode: []int32{128681}, ShortNames: []string{"triangular_flag_on_post"}},
			Emoji{Name: "crossed flags", Unicode: []int32{127884}, ShortNames: []string{"crossed_flags"}},
			Emoji{Name: "black flag", Unicode: []int32{127988}, ShortNames: []string{"black_flag"}},
			Emoji{Name: "white flag", Unicode: []int32{127987, 65039}, ShortNames: []string{"white_flag"}},
			Emoji{Name: "rainbow flag", Unicode: []int32{127987, 65039, 8205, 127752}, ShortNames: []string{"rainbow_flag"}},
			Emoji{Name: "transgender flag", Unicode: []int32{127987, 65039, 8205, 9895, 65039}, ShortNames: []string{"transgender_flag"}},
			Emoji{Name: "pirate flag", Unicode: []int32{127988, 8205, 9760, 65039}, ShortNames: []string{"pirate_flag"}},
			Emoji{Name: "flag: Ascension Island", Unicode: []int32{127462, 127464}, ShortNames: []string{"ascension_island"}},
			Emoji{Name: "flag: Andorra", Unicode: []int32{127462, 127465}, ShortNames: []string{"andorra"}},
			Emoji{Name: "flag: United Arab Emirates", Unicode: []int32{127462, 127466}, ShortNames: []string{"united_arab_emirates"}},
			Emoji{Name: "flag: Afghanistan", Unicode: []int32{127462, 127467}, ShortNames: []string{"afghanistan"}},
			Emoji{Name: "flag: Antigua & Barbuda", Unicode: []int32{127462, 127468}, ShortNames: []string{"antigua_barbuda"}},
			Emoji{Name: "flag: Anguilla", Unicode: []int32{127462, 127470}, ShortNames: []string{"anguilla"}},
			Emoji{Name: "flag: Albania", Unicode: []int32{127462, 127473}, ShortNames: []string{"albania"}},
			Emoji{Name: "flag: Armenia", Unicode: []int32{127462, 127474}, ShortNames: []string{"armenia"}},
			Emoji{Name: "flag: Angola", Unicode: []int32{127462, 127476}, ShortNames: []string{"angola"}},
			Emoji{Name: "flag: Antarctica", Unicode: []int32{127462, 127478}, ShortNames: []string{"antarctica"}},
			Emoji{Name: "flag: Argentina", Unicode: []int32{127462, 127479}, ShortNames: []string{"argentina"}},
			Emoji{Name: "flag: American Samoa", Unicode: []int32{127462, 127480}, ShortNames: []string{"american_samoa"}},
			Emoji{Name: "flag: Austria", Unicode: []int32{127462, 127481}, ShortNames: []string{"austria"}},
			Emoji{Name: "flag: Australia", Unicode: []int32{127462, 127482}, ShortNames: []string{"australia"}},
			Emoji{Name: "flag: Aruba", Unicode: []int32{127462, 127484}, ShortNames: []string{"aruba"}},
			Emoji{Name: "flag: Åland Islands", Unicode: []int32{127462, 127485}, ShortNames: []string{"aland_islands"}},
			Emoji{Name: "flag: Azerbaijan", Unicode: []int32{127462, 127487}, ShortNames: []string{"azerbaijan"}},
			Emoji{Name: "flag: Bosnia & Herzegovina", Unicode: []int32{127463, 127462}, ShortNames: []string{"bosnia_herzegovina"}},
			Emoji{Name: "flag: Barbados", Unicode: []int32{127463, 127463}, ShortNames: []string{"barbados"}},
			Emoji{Name: "flag: Bangladesh", Unicode: []int32{127463, 127465}, ShortNames: []string{"bangladesh"}},
			Emoji{Name: "flag: Belgium", Unicode: []int32{127463, 127466}, ShortNames: []string{"belgium"}},
			Emoji{Name: "flag: Burkina Faso", Unicode: []int32{127463, 127467}, ShortNames: []string{"burkina_faso"}},
			Emoji{Name: "flag: Bulgaria", Unicode: []int32{127463, 127468}, ShortNames: []string{"bulgaria"}},
			Emoji{Name: "flag: Bahrain", Unicode: []int32{127463, 127469}, ShortNames: []string{"bahrain"}},
			Emoji{Name: "flag: Burundi", Unicode: []int32{127463, 127470}, ShortNames: []string{"burundi"}},
			Emoji{Name: "flag: Benin", Unicode: []int32{127463, 127471}, ShortNames: []string{"benin"}},
			Emoji{Name: "flag: St. Barthélemy", Unicode: []int32{127463, 127473}, ShortNames: []string{"st_barthelemy"}},
			Emoji{Name: "flag: Bermuda", Unicode: []int32{127463, 127474}, ShortNames: []string{"bermuda"}},
			Emoji{Name: "flag: Brunei", Unicode: []int32{127463, 127475}, ShortNames: []string{"brunei"}},
			Emoji{Name: "flag: Bolivia", Unicode: []int32{127463, 127476}, ShortNames: []string{"bolivia"}},
			Emoji{Name: "flag: Caribbean Netherlands", Unicode: []int32{127463, 127478}, ShortNames: []string{"caribbean_netherlands"}},
			Emoji{Name: "flag: Brazil", Unicode: []int32{127463, 127479}, ShortNames: []string{"brazil"}},
			Emoji{Name: "flag: Bahamas", Unicode: []int32{127463, 127480}, ShortNames: []string{"bahamas"}},
			Emoji{Name: "flag: Bhutan", Unicode: []int32{127463, 127481}, ShortNames: []string{"bhutan"}},
			Emoji{Name: "flag: Bouvet Island", Unicode: []int32{127463, 127483}, ShortNames: []string{"bouvet_island"}},
			Emoji{Name: "flag: Botswana", Unicode: []int32{127463, 127484}, ShortNames: []string{"botswana"}},
			Emoji{Name: "flag: Belarus", Unicode: []int32{127463, 127486}, ShortNames: []string{"belarus"}},
			Emoji{Name: "flag: Belize", Unicode: []int32{127463, 127487}, ShortNames: []string{"belize"}},
			Emoji{Name: "flag: Canada", Unicode: []int32{127464, 127462}, ShortNames: []string{"canada"}},
			Emoji{Name: "flag: Cocos (Keeling) Islands", Unicode: []int32{127464, 127464}, ShortNames: []string{"cocos_islands"}},
			Emoji{Name: "flag: Congo - Kinshasa", Unicode: []int32{127464, 127465}, ShortNames: []string{"congo_kinshasa"}},
			Emoji{Name: "flag: Central African Republic", Unicode: []int32{127464, 127467}, ShortNames: []string{"central_african_republic"}},
			Emoji{Name: "flag: Congo - Brazzaville", Unicode: []int32{127464, 127468}, ShortNames: []string{"congo_brazzaville"}},
			Emoji{Name: "flag: Switzerland", Unicode: []int32{127464, 127469}, ShortNames: []string{"switzerland"}},
			Emoji{Name: "flag: Côte d’Ivoire", Unicode: []int32{127464, 127470}, ShortNames: []string{"cote_divoire"}},
			Emoji{Name: "flag: Cook Islands", Unicode: []int32{127464, 127472}, ShortNames: []string{"cook_islands"}},
			Emoji{Name: "flag: Chile", Unicode: []int32{127464, 127473}, ShortNames: []string{"chile"}},
			Emoji{Name: "flag: Cameroon", Unicode: []int32{127464, 127474}, ShortNames: []string{"cameroon"}},
			Emoji{Name: "flag: China", Unicode: []int32{127464, 127475}, ShortNames: []string{"cn"}},
			Emoji{Name: "flag: Colombia", Unicode: []int32{127464, 127476}, ShortNames: []string{"colombia"}},
			Emoji{Name: "flag: Clipperton Island", Unicode: []int32{127464, 127477}, ShortNames: []string{"clipperton_island"}},
			Emoji{Name: "flag: Costa Rica", Unicode: []int32{127464, 127479}, ShortNames: []string{"costa_rica"}},
			Emoji{Name: "flag: Cuba", Unicode: []int32{127464, 127482}, ShortNames: []string{"cuba"}},
			Emoji{Name: "flag: Cape Verde", Unicode: []int32{127464, 127483}, ShortNames: []string{"cape_verde"}},
			Emoji{Name: "flag: Curaçao", Unicode: []int32{127464, 127484}, ShortNames: []string{"curacao"}},
			Emoji{Name: "flag: Christmas Island", Unicode: []int32{127464, 127485}, ShortNames: []string{"christmas_island"}},
			Emoji{Name: "flag: Cyprus", Unicode: []int32{127464, 127486}, ShortNames: []string{"cyprus"}},
			Emoji{Name: "flag: Czechia", Unicode: []int32{127464, 127487}, ShortNames: []string{"czech_republic"}},
			Emoji{Name: "flag: Germany", Unicode: []int32{127465, 127466}, ShortNames: []string{"de"}},
			Emoji{Name: "flag: Diego Garcia", Unicode: []int32{127465, 127468}, ShortNames: []string{"diego_garcia"}},
			Emoji{Name: "flag: Djibouti", Unicode: []int32{127465, 127471}, ShortNames: []string{"djibouti"}},
			Emoji{Name: "flag: Denmark", Unicode: []int32{127465, 127472}, ShortNames: []string{"denmark"}},
			Emoji{Name: "flag: Dominica", Unicode: []int32{127465, 127474}, ShortNames: []string{"dominica"}},
			Emoji{Name: "flag: Dominican Republic", Unicode: []int32{127465, 127476}, ShortNames: []string{"dominican_republic"}},
			Emoji{Name: "flag: Algeria", Unicode: []int32{127465, 127487}, ShortNames: []string{"algeria"}},
			Emoji{Name: "flag: Ceuta & Melilla", Unicode: []int32{127466, 127462}, ShortNames: []string{"ceuta_melilla"}},
			Emoji{Name: "flag: Ecuador", Unicode: []int32{127466, 127464}, ShortNames: []string{"ecuador"}},
			Emoji{Name: "flag: Estonia", Unicode: []int32{127466, 127466}, ShortNames: []string{"estonia"}},
			Emoji{Name: "flag: Egypt", Unicode: []int32{127466, 127468}, ShortNames: []string{"egypt"}},
			Emoji{Name: "flag: Western Sahara", Unicode: []int32{127466, 127469}, ShortNames: []string{"western_sahara"}},
			Emoji{Name: "flag: Eritrea", Unicode: []int32{127466, 127479}, ShortNames: []string{"eritrea"}},
			Emoji{Name: "flag: Spain", Unicode: []int32{127466, 127480}, ShortNames: []string{"es"}},
			Emoji{Name: "flag: Ethiopia", Unicode: []int32{127466, 127481}, ShortNames: []string{"ethiopia"}},
			Emoji{Name: "flag: European Union", Unicode: []int32{127466, 127482}, ShortNames: []string{"eu", "european_union"}},
			Emoji{Name: "flag: Finland", Unicode: []int32{127467, 127470}, ShortNames: []string{"finland"}},
			Emoji{Name: "flag: Fiji", Unicode: []int32{127467, 127471}, ShortNames: []string{"fiji"}},
			Emoji{Name: "flag: Falkland Islands", Unicode: []int32{127467, 127472}, ShortNames: []string{"falkland_islands"}},
			Emoji{Name: "flag: Micronesia", Unicode: []int32{127467, 127474}, ShortNames: []string{"micronesia"}},
			Emoji{Name: "flag: Faroe Islands", Unicode: []int32{127467, 127476}, ShortNames: []string{"faroe_islands"}},
			Emoji{Name: "flag: France", Unicode: []int32{127467, 127479}, ShortNames: []string{"fr"}},
			Emoji{Name: "flag: Gabon", Unicode: []int32{127468, 127462}, ShortNames: []string{"gabon"}},
			Emoji{Name: "flag: United Kingdom", Unicode: []int32{127468, 127463}, ShortNames: []string{"gb", "uk"}},
			Emoji{Name: "flag: Grenada", Unicode: []int32{127468, 127465}, ShortNames: []string{"grenada"}},
			Emoji{Name: "flag: Georgia", Unicode: []int32{127468, 127466}, ShortNames: []string{"georgia"}},
			Emoji{Name: "flag: French Guiana", Unicode: []int32{127468, 127467}, ShortNames: []string{"french_guiana"}},
			Emoji{Name: "flag: Guernsey", Unicode: []int32{127468, 127468}, ShortNames: []string{"guernsey"}},
			Emoji{Name: "flag: Ghana", Unicode: []int32{127468, 127469}, ShortNames: []string{"ghana"}},
			Emoji{Name: "flag: Gibraltar", Unicode: []int32{127468, 127470}, ShortNames: []string{"gibraltar"}},
			Emoji{Name: "flag: Greenland", Unicode: []int32{127468, 127473}, ShortNames: []string{"greenland"}},
			Emoji{Name: "flag: Gambia", Unicode: []int32{127468, 127474}, ShortNames: []string{"gambia"}},
			Emoji{Name: "flag: Guinea", Unicode: []int32{127468, 127475}, ShortNames: []string{"guinea"}},
			Emoji{Name: "flag: Guadeloupe", Unicode: []int32{127468, 127477}, ShortNames: []string{"guadeloupe"}},
			Emoji{Name: "flag: Equatorial Guinea", Unicode: []int32{127468, 127478}, ShortNames: []string{"equatorial_guinea"}},
			Emoji{Name: "flag: Greece", Unicode: []int32{127468, 127479}, ShortNames: []string{"greece"}},
			Emoji{Name: "flag: South Georgia & South Sandwich Islands", Unicode: []int32{127468, 127480}, ShortNames: []string{"south_georgia_south_sandwich_islands"}},
			Emoji{Name: "flag: Guatemala", Unicode: []int32{127468, 127481}, ShortNames: []string{"guatemala"}},
			Emoji{Name: "flag: Guam", Unicode: []int32{127468, 127482}, ShortNames: []string{"guam"}},
			Emoji{Name: "flag: Guinea-Bissau", Unicode: []int32{127468, 127484}, ShortNames: []string{"guinea_bissau"}},
			Emoji{Name: "flag: Guyana", Unicode: []int32{127468, 127486}, ShortNames: []string{"guyana"}},
			Emoji{Name: "flag: Hong Kong SAR China", Unicode: []int32{127469, 127472}, ShortNames: []string{"hong_kong"}},
			Emoji{Name: "flag: Heard & McDonald Islands", Unicode: []int32{127469, 127474}, ShortNames: []string{"heard_mcdonald_islands"}},
			Emoji{Name: "flag: Honduras", Unicode: []int32{127469, 127475}, ShortNames: []string{"honduras"}},
			Emoji{Name: "flag: Croatia", Unicode: []int32{127469, 127479}, ShortNames: []string{"croatia"}},
			Emoji{Name: "flag: Haiti", Unicode: []int32{127469, 127481}, ShortNames: []string{"haiti"}},
			Emoji{Name: "flag: Hungary", Unicode: []int32{127469, 127482}, ShortNames: []string{"hungary"}},
			Emoji{Name: "flag: Canary Islands", Unicode: []int32{127470, 127464}, ShortNames: []string{"canary_islands"}},
			Emoji{Name: "flag: Indonesia", Unicode: []int32{127470, 127465}, ShortNames: []string{"indonesia"}},
			Emoji{Name: "flag: Ireland", Unicode: []int32{127470, 127466}, ShortNames: []string{"ireland"}},
			Emoji{Name: "flag: Israel", Unicode: []int32{127470, 127473}, ShortNames: []string{"israel"}},
			Emoji{Name: "flag: Isle of Man", Unicode: []int32{127470, 127474}, ShortNames: []string{"isle_of_man"}},
			Emoji{Name: "flag: India", Unicode: []int32{127470, 127475}, ShortNames: []string{"india"}},
			Emoji{Name: "flag: British Indian Ocean Territory", Unicode: []int32{127470, 127476}, ShortNames: []string{"british_indian_ocean_territory"}},
			Emoji{Name: "flag: Iraq", Unicode: []int32{127470, 127478}, ShortNames: []string{"iraq"}},
			Emoji{Name: "flag: Iran", Unicode: []int32{127470, 127479}, ShortNames: []string{"iran"}},
			Emoji{Name: "flag: Iceland", Unicode: []int32{127470, 127480}, ShortNames: []string{"iceland"}},
			Emoji{Name: "flag: Italy", Unicode: []int32{127470, 127481}, ShortNames: []string{"it"}},
			Emoji{Name: "flag: Jersey", Unicode: []int32{127471, 127466}, ShortNames: []string{"jersey"}},
			Emoji{Name: "flag: Jamaica", Unicode: []int32{127471, 127474}, ShortNames: []string{"jamaica"}},
			Emoji{Name: "flag: Jordan", Unicode: []int32{127471, 127476}, ShortNames: []string{"jordan"}},
			Emoji{Name: "flag: Japan", Unicode: []int32{127471, 127477}, ShortNames: []string{"jp"}},
			Emoji{Name: "flag: Kenya", Unicode: []int32{127472, 127466}, ShortNames: []string{"kenya"}},
			Emoji{Name: "flag: Kyrgyzstan", Unicode: []int32{127472, 127468}, ShortNames: []string{"kyrgyzstan"}},
			Emoji{Name: "flag: Cambodia", Unicode: []int32{127472, 127469}, ShortNames: []string{"cambodia"}},
			Emoji{Name: "flag: Kiribati", Unicode: []int32{127472, 127470}, ShortNames: []string{"kiribati"}},
			Emoji{Name: "flag: Comoros", Unicode: []int32{127472, 127474}, ShortNames: []string{"comoros"}},
			Emoji{Name: "flag: St. Kitts & Nevis", Unicode: []int32{127472, 127475}, ShortNames: []string{"st_kitts_nevis"}},
			Emoji{Name: "flag: North Korea", Unicode: []int32{127472, 127477}, ShortNames: []string{"north_korea"}},
			Emoji{Name: "flag: South Korea", Unicode: []int32{127472, 127479}, ShortNames: []string{"kr"}},
			Emoji{Name: "flag: Kuwait", Unicode: []int32{127472, 127484}, ShortNames: []string{"kuwait"}},
			Emoji{Name: "flag: Cayman Islands", Unicode: []int32{127472, 127486}, ShortNames: []string{"cayman_islands"}},
			Emoji{Name: "flag: Kazakhstan", Unicode: []int32{127472, 127487}, ShortNames: []string{"kazakhstan"}},
			Emoji{Name: "flag: Laos", Unicode: []int32{127473, 127462}, ShortNames: []string{"laos"}},
			Emoji{Name: "flag: Lebanon", Unicode: []int32{127473, 127463}, ShortNames: []string{"lebanon"}},
			Emoji{Name: "flag: St. Lucia", Unicode: []int32{127473, 127464}, ShortNames: []string{"st_lucia"}},
			Emoji{Name: "flag: Liechtenstein", Unicode: []int32{127473, 127470}, ShortNames: []string{"liechtenstein"}},
			Emoji{Name: "flag: Sri Lanka", Unicode: []int32{127473, 127472}, ShortNames: []string{"sri_lanka"}},
			Emoji{Name: "flag: Liberia", Unicode: []int32{127473, 127479}, ShortNames: []string{"liberia"}},
			Emoji{Name: "flag: Lesotho", Unicode: []int32{127473, 127480}, ShortNames: []string{"lesotho"}},
			Emoji{Name: "flag: Lithuania", Unicode: []int32{127473, 127481}, ShortNames: []string{"lithuania"}},
			Emoji{Name: "flag: Luxembourg", Unicode: []int32{127473, 127482}, ShortNames: []string{"luxembourg"}},
			Emoji{Name: "flag: Latvia", Unicode: []int32{127473, 127483}, ShortNames: []string{"latvia"}},
			Emoji{Name: "flag: Libya", Unicode: []int32{127473, 127486}, ShortNames: []string{"libya"}},
			Emoji{Name: "flag: Morocco", Unicode: []int32{127474, 127462}, ShortNames: []string{"morocco"}},
			Emoji{Name: "flag: Monaco", Unicode: []int32{127474, 127464}, ShortNames: []string{"monaco"}},
			Emoji{Name: "flag: Moldova", Unicode: []int32{127474, 127465}, ShortNames: []string{"moldova"}},
			Emoji{Name: "flag: Montenegro", Unicode: []int32{127474, 127466}, ShortNames: []string{"montenegro"}},
			Emoji{Name: "flag: St. Martin", Unicode: []int32{127474, 127467}, ShortNames: []string{"st_martin"}},
			Emoji{Name: "flag: Madagascar", Unicode: []int32{127474, 127468}, ShortNames: []string{"madagascar"}},
			Emoji{Name: "flag: Marshall Islands", Unicode: []int32{127474, 127469}, ShortNames: []string{"marshall_islands"}},
			Emoji{Name: "flag: North Macedonia", Unicode: []int32{127474, 127472}, ShortNames: []string{"macedonia"}},
			Emoji{Name: "flag: Mali", Unicode: []int32{127474, 127473}, ShortNames: []string{"mali"}},
			Emoji{Name: "flag: Myanmar (Burma)", Unicode: []int32{127474, 127474}, ShortNames: []string{"myanmar"}},
			Emoji{Name: "flag: Mongolia", Unicode: []int32{127474, 127475}, ShortNames: []string{"mongolia"}},
			Emoji{Name: "flag: Macao SAR China", Unicode: []int32{127474, 127476}, ShortNames: []string{"macau"}},
			Emoji{Name: "flag: Northern Mariana Islands", Unicode: []int32{127474, 127477}, ShortNames: []string{"northern_mariana_islands"}},
			Emoji{Name: "flag: Martinique", Unicode: []int32{127474, 127478}, ShortNames: []string{"martinique"}},
			Emoji{Name: "flag: Mauritania", Unicode: []int32{127474, 127479}, ShortNames: []string{"mauritania"}},
			Emoji{Name: "flag: Montserrat", Unicode: []int32{127474, 127480}, ShortNames: []string{"montserrat"}},
			Emoji{Name: "flag: Malta", Unicode: []int32{127474, 127481}, ShortNames: []string{"malta"}},
			Emoji{Name: "flag: Mauritius", Unicode: []int32{127474, 127482}, ShortNames: []string{"mauritius"}},
			Emoji{Name: "flag: Maldives", Unicode: []int32{127474, 127483}, ShortNames: []string{"maldives"}},
			Emoji{Name: "flag: Malawi", Unicode: []int32{127474, 127484}, ShortNames: []string{"malawi"}},
			Emoji{Name: "flag: Mexico", Unicode: []int32{127474, 127485}, ShortNames: []string{"mexico"}},
			Emoji{Name: "flag: Malaysia", Unicode: []int32{127474, 127486}, ShortNames: []string{"malaysia"}},
			Emoji{Name: "flag: Mozambique", Unicode: []int32{127474, 127487}, ShortNames: []string{"mozambique"}},
			Emoji{Name: "flag: Namibia", Unicode: []int32{127475, 127462}, ShortNames: []string{"namibia"}},
			Emoji{Name: "flag: New Caledonia", Unicode: []int32{127475, 127464}, ShortNames: []string{"new_caledonia"}},
			Emoji{Name: "flag: Niger", Unicode: []int32{127475, 127466}, ShortNames: []string{"niger"}},
			Emoji{Name: "flag: Norfolk Island", Unicode: []int32{127475, 127467}, ShortNames: []string{"norfolk_island"}},
			Emoji{Name: "flag: Nigeria", Unicode: []int32{127475, 127468}, ShortNames: []string{"nigeria"}},
			Emoji{Name: "flag: Nicaragua", Unicode: []int32{127475, 127470}, ShortNames: []string{"nicaragua"}},
			Emoji{Name: "flag: Netherlands", Unicode: []int32{127475, 127473}, ShortNames: []string{"netherlands"}},
			Emoji{Name: "flag: Norway", Unicode: []int32{127475, 127476}, ShortNames: []string{"norway"}},
			Emoji{Name: "flag: Nepal", Unicode: []int32{127475, 127477}, ShortNames: []string{"nepal"}},
			Emoji{Name: "flag: Nauru", Unicode: []int32{127475, 127479}, ShortNames: []string{"nauru"}},
			Emoji{Name: "flag: Niue", Unicode: []int32{127475, 127482}, ShortNames: []string{"niue"}},
			Emoji{Name: "flag: New Zealand", Unicode: []int32{127475, 127487}, ShortNames: []string{"new_zealand"}},
			Emoji{Name: "flag: Oman", Unicode: []int32{127476, 127474}, ShortNames: []string{"oman"}},
			Emoji{Name: "flag: Panama", Unicode: []int32{127477, 127462}, ShortNames: []string{"panama"}},
			Emoji{Name: "flag: Peru", Unicode: []int32{127477, 127466}, ShortNames: []string{"peru"}},
			Emoji{Name: "flag: French Polynesia", Unicode: []int32{127477, 127467}, ShortNames: []string{"french_polynesia"}},
			Emoji{Name: "flag: Papua New Guinea", Unicode: []int32{127477, 127468}, ShortNames: []string{"papua_new_guinea"}},
			Emoji{Name: "flag: Philippines", Unicode: []int32{127477, 127469}, ShortNames: []string{"philippines"}},
			Emoji{Name: "flag: Pakistan", Unicode: []int32{127477, 127472}, ShortNames: []string{"pakistan"}},
			Emoji{Name: "flag: Poland", Unicode: []int32{127477, 127473}, ShortNames: []string{"poland"}},
			Emoji{Name: "flag: St. Pierre & Miquelon", Unicode: []int32{127477, 127474}, ShortNames: []string{"st_pierre_miquelon"}},
			Emoji{Name: "flag: Pitcairn Islands", Unicode: []int32{127477, 127475}, ShortNames: []string{"pitcairn_islands"}},
			Emoji{Name: "flag: Puerto Rico", Unicode: []int32{127477, 127479}, ShortNames: []string{"puerto_rico"}},
			Emoji{Name: "flag: Palestinian Territories", Unicode: []int32{127477, 127480}, ShortNames: []string{"palestinian_territories"}},
			Emoji{Name: "flag: Portugal", Unicode: []int32{127477, 127481}, ShortNames: []string{"portugal"}},
			Emoji{Name: "flag: Palau", Unicode: []int32{127477, 127484}, ShortNames: []string{"palau"}},
			Emoji{Name: "flag: Paraguay", Unicode: []int32{127477, 127486}, ShortNames: []string{"paraguay"}},
			Emoji{Name: "flag: Qatar", Unicode: []int32{127478, 127462}, ShortNames: []string{"qatar"}},
			Emoji{Name: "flag: Réunion", Unicode: []int32{127479, 127466}, ShortNames: []string{"reunion"}},
			Emoji{Name: "flag: Romania", Unicode: []int32{127479, 127476}, ShortNames: []string{"romania"}},
			Emoji{Name: "flag: Serbia", Unicode: []int32{127479, 127480}, ShortNames: []string{"serbia"}},
			Emoji{Name: "flag: Russia", Unicode: []int32{127479, 127482}, ShortNames: []string{"ru"}},
			Emoji{Name: "flag: Rwanda", Unicode: []int32{127479, 127484}, ShortNames: []string{"rwanda"}},
			Emoji{Name: "flag: Saudi Arabia", Unicode: []int32{127480, 127462}, ShortNames: []string{"saudi_arabia"}},
			Emoji{Name: "flag: Solomon Islands", Unicode: []int32{127480, 127463}, ShortNames: []string{"solomon_islands"}},
			Emoji{Name: "flag: Seychelles", Unicode: []int32{127480, 127464}, ShortNames: []string{"seychelles"}},
			Emoji{Name: "flag: Sudan", Unicode: []int32{127480, 127465}, ShortNames: []string{"sudan"}},
			Emoji{Name: "flag: Sweden", Unicode: []int32{127480, 127466}, ShortNames: []string{"sweden"}},
			Emoji{Name: "flag: Singapore", Unicode: []int32{127480, 127468}, ShortNames: []string{"singapore"}},
			Emoji{Name: "flag: St. Helena", Unicode: []int32{127480, 127469}, ShortNames: []string{"st_helena"}},
			Emoji{Name: "flag: Slovenia", Unicode: []int32{127480, 127470}, ShortNames: []string{"slovenia"}},
			Emoji{Name: "flag: Svalbard & Jan Mayen", Unicode: []int32{127480, 127471}, ShortNames: []string{"svalbard_jan_mayen"}},
			Emoji{Name: "flag: Slovakia", Unicode: []int32{127480, 127472}, ShortNames: []string{"slovakia"}},
			Emoji{Name: "flag: Sierra Leone", Unicode: []int32{127480, 127473}, ShortNames: []string{"sierra_leone"}},
			Emoji{Name: "flag: San Marino", Unicode: []int32{127480, 127474}, ShortNames: []string{"san_marino"}},
			Emoji{Name: "flag: Senegal", Unicode: []int32{127480, 127475}, ShortNames: []string{"senegal"}},
			Emoji{Name: "flag: Somalia", Unicode: []int32{127480, 127476}, ShortNames: []string{"somalia"}},
			Emoji{Name: "flag: Suriname", Unicode: []int32{127480, 127479}, ShortNames: []string{"suriname"}},
			Emoji{Name: "flag: South Sudan", Unicode: []int32{127480, 127480}, ShortNames: []string{"south_sudan"}},
			Emoji{Name: "flag: São Tomé & Príncipe", Unicode: []int32{127480, 127481}, ShortNames: []string{"sao_tome_principe"}},
			Emoji{Name: "flag: El Salvador", Unicode: []int32{127480, 127483}, ShortNames: []string{"el_salvador"}},
			Emoji{Name: "flag: Sint Maarten", Unicode: []int32{127480, 127485}, ShortNames: []string{"sint_maarten"}},
			Emoji{Name: "flag: Syria", Unicode: []int32{127480, 127486}, ShortNames: []string{"syria"}},
			Emoji{Name: "flag: Eswatini", Unicode: []int32{127480, 127487}, ShortNames: []string{"swaziland"}},
			Emoji{Name: "flag: Tristan da Cunha", Unicode: []int32{127481, 127462}, ShortNames: []string{"tristan_da_cunha"}},
			Emoji{Name: "flag: Turks & Caicos Islands", Unicode: []int32{127481, 127464}, ShortNames: []string{"turks_caicos_islands"}},
			Emoji{Name: "flag: Chad", Unicode: []int32{127481, 127465}, ShortNames: []string{"chad"}},
			Emoji{Name: "flag: French Southern Territories", Unicode: []int32{127481, 127467}, ShortNames: []string{"french_southern_territories"}},
			Emoji{Name: "flag: Togo", Unicode: []int32{127481, 127468}, ShortNames: []string{"togo"}},
			Emoji{Name: "flag: Thailand", Unicode: []int32{127481, 127469}, ShortNames: []string{"thailand"}},
			Emoji{Name: "flag: Tajikistan", Unicode: []int32{127481, 127471}, ShortNames: []string{"tajikistan"}},
			Emoji{Name: "flag: Tokelau", Unicode: []int32{127481, 127472}, ShortNames: []string{"tokelau"}},
			Emoji{Name: "flag: Timor-Leste", Unicode: []int32{127481, 127473}, ShortNames: []string{"timor_leste"}},
			Emoji{Name: "flag: Turkmenistan", Unicode: []int32{127481, 127474}, ShortNames: []string{"turkmenistan"}},
			Emoji{Name: "flag: Tunisia", Unicode: []int32{127481, 127475}, ShortNames: []string{"tunisia"}},
			Emoji{Name: "flag: Tonga", Unicode: []int32{127481, 127476}, ShortNames: []string{"tonga"}},
			Emoji{Name: "flag: Turkey", Unicode: []int32{127481, 127479}, ShortNames: []string{"tr"}},
			Emoji{Name: "flag: Trinidad & Tobago", Unicode: []int32{127481, 127481}, ShortNames: []string{"trinidad_tobago"}},
			Emoji{Name: "flag: Tuvalu", Unicode: []int32{127481, 127483}, ShortNames: []string{"tuvalu"}},
			Emoji{Name: "flag: Taiwan", Unicode: []int32{127481, 127484}, ShortNames: []string{"taiwan"}},
			Emoji{Name: "flag: Tanzania", Unicode: []int32{127481, 127487}, ShortNames: []string{"tanzania"}},
			Emoji{Name: "flag: Ukraine", Unicode: []int32{127482, 127462}, ShortNames: []string{"ukraine"}},
			Emoji{Name: "flag: Uganda", Unicode: []int32{127482, 127468}, ShortNames: []string{"uganda"}},
			Emoji{Name: "flag: U.S. Outlying Islands", Unicode: []int32{127482, 127474}, ShortNames: []string{"us_outlying_islands"}},
			Emoji{Name: "flag: United Nations", Unicode: []int32{127482, 127475}, ShortNames: []string{"united_nations"}},
			Emoji{Name: "flag: United States", Unicode: []int32{127482, 127480}, ShortNames: []string{"us"}},
			Emoji{Name: "flag: Uruguay", Unicode: []int32{127482, 127486}, ShortNames: []string{"uruguay"}},
			Emoji{Name: "flag: Uzbekistan", Unicode: []int32{127482, 127487}, ShortNames: []string{"uzbekistan"}},
			Emoji{Name: "flag: Vatican City", Unicode: []int32{127483, 127462}, ShortNames: []string{"vatican_city"}},
			Emoji{Name: "flag: St. Vincent & Grenadines", Unicode: []int32{127483, 127464}, ShortNames: []string{"st_vincent_grenadines"}},
			Emoji{Name: "flag: Venezuela", Unicode: []int32{127483, 127466}, ShortNames: []string{"venezuela"}},
			Emoji{Name: "flag: British Virgin Islands", Unicode: []int32{127483, 127468}, ShortNames: []string{"british_virgin_islands"}},
			Emoji{Name: "flag: U.S. Virgin Islands", Unicode: []int32{127483, 127470}, ShortNames: []string{"us_virgin_islands"}},
			Emoji{Name: "flag: Vietnam", Unicode: []int32{127483, 127475}, ShortNames: []string{"vietnam"}},
			Emoji{Name: "flag: Vanuatu", Unicode: []int32{127483, 127482}, ShortNames: []string{"vanuatu"}},
			Emoji{Name: "flag: Wallis & Futuna", Unicode: []int32{127484, 127467}, ShortNames: []string{"wallis_futuna"}},
			Emoji{Name: "flag: Samoa", Unicode: []int32{127484, 127480}, ShortNames: []string{"samoa"}},
			Emoji{Name: "flag: Kosovo", Unicode: []int32{127485, 127472}, ShortNames: []string{"kosovo"}},
			Emoji{Name: "flag: Yemen", Unicode: []int32{127486, 127466}, ShortNames: []string{"yemen"}},
			Emoji{Name: "flag: Mayotte", Unicode: []int32{127486, 127481}, ShortNames: []string{"mayotte"}},
			Emoji{Name: "flag: South Africa", Unicode: []int32{127487, 127462}, ShortNames: []string{"south_africa"}},
			Emoji{Name: "flag: Zambia", Unicode: []int32{127487, 127474}, ShortNames: []string{"zambia"}},
			Emoji{Name: "flag: Zimbabwe", Unicode: []int32{127487, 127484}, ShortNames: []string{"zimbabwe"}},
			Emoji{Name: "flag: England", Unicode: []int32{127988, 917607, 917602, 917605, 917614, 917607, 917631}, ShortNames: []string{"england"}},
			Emoji{Name: "flag: Scotland", Unicode: []int32{127988, 917607, 917602, 917619, 917603, 917620, 917631}, ShortNames: []string{"scotland"}},
			Emoji{Name: "flag: Wales", Unicode: []int32{127988, 917607, 917602, 917623, 917612, 917619, 917631}, ShortNames: []string{"wales"}},
        )
	})
	m := github.Clone()
	for _, opt := range opts {
		opt(m)
	}
	return m
}
